@@ -173,21 +173,13 @@ proc ::maint::OpenClose {} {
   ttk::frame $w.dm
   ttk::labelframe $w.dm.delete -text [tr DeleteFlag]
   ttk::labelframe $w.dm.mark -text [tr Flag]
-  ttk::labelframe $w.dm.spell -text [tr Spellchecking]
-  ttk::labelframe $w.dm.db -text [tr DatabaseOps]
   grid $w.dm.delete -row 0 -column 0 -sticky snwe -padx "0 10" -pady "0 10"
   grid $w.dm.mark -row 0 -column 1 -sticky snwe -pady "0 10"
-  grid $w.dm.spell -row 1 -column 0 -sticky snwe -padx "0 10"
-  grid $w.dm.db -row 1 -column 1 -sticky snwe
+  grid columnconfigure $w.dm.mark 0 -weight 1
+  grid columnconfigure $w.dm.mark 1 -weight 1
   grid columnconfigure $w.dm 0 -weight 1
   grid columnconfigure $w.dm 1 -weight 1
 
-  foreach grid {dm.mark dm.spell dm.db} cols {2 2 2} {
-    for {set i 0} {$i < $cols} {incr i} {
-      grid columnconfigure $w.$grid $i -weight 1
-    }
-  }
-  
   ttk::label $w.dm.delete.vdelete
   ttk::menubutton $w.dm.mark.title -menu $w.dm.mark.title.m
   menu $w.dm.mark.title.m -font $font
@@ -222,44 +214,6 @@ proc ::maint::OpenClose {} {
   grid columnconfigure $w.dm.delete 0 -weight 1
   grid columnconfigure $w.dm.delete 1 -weight 1
 
-  
-  ttk::button $w.dm.spell.player -textvar ::tr(Players...) -style Small.TButton \
-      -command "openSpellCheckWin Player $w"
-  ttk::button $w.dm.spell.event -textvar ::tr(Events...) -style Small.TButton \
-      -command "openSpellCheckWin Event $w"
-  ttk::button $w.dm.spell.site -textvar ::tr(Sites...) -style Small.TButton \
-      -command "openSpellCheckWin Site $w"
-  ttk::button $w.dm.spell.round -textvar ::tr(Rounds...) -style Small.TButton \
-      -command "openSpellCheckWin Round $w"
-  grid $w.dm.spell.player -row 0 -column 0 -sticky we -padx "0 5" -pady "0 5"
-  grid $w.dm.spell.event -row 0 -column 1 -sticky we -pady "0 5"
-  grid $w.dm.spell.site -row 1 -column 0 -sticky we -padx "0 5" -pady "0 5"
-  grid $w.dm.spell.round -row 1 -column 1 -sticky we -pady "0 5"
-
-  bind $w <Alt-p> "$w.dm.spell.player invoke"
-  bind $w <Alt-e> "$w.dm.spell.event invoke"
-  bind $w <Alt-s> "$w.dm.spell.site invoke"
-  bind $w <Alt-r> "$w.dm.spell.round invoke"
-
-  ttk::button $w.dm.db.eco -style Small.TButton -textvar ::tr(ReclassifyGames...) -command classifyAllGames
-  ttk::button $w.dm.db.compact -style Small.TButton -textvar ::tr(CompactDatabase...) -command compactDB
-  ttk::button $w.dm.db.elo -style Small.TButton -textvar ::tr(AddEloRatings...) -command allocateRatings
-  ttk::button $w.dm.db.dups -style Small.TButton -textvar ::tr(DeleteTwins...) -command "markTwins $w"
-  ttk::button $w.dm.db.cleaner -style Small.TButton -textvar ::tr(Cleaner...) -command cleanerWin
-  ttk::button $w.dm.db.strip -style Small.TButton -textvar ::tr(StripTags...) -command stripTags
-
-  foreach i {eco compact elo dups cleaner strip} {
-    $w.dm.db.$i configure -style Small.TButton
-  }
-  bind $w <Alt-d> "$w.dm.db.dups invoke"
-  
-  grid $w.dm.db.eco -row 0 -column 0 -sticky we -padx "0 5" -pady "0 5"
-  grid $w.dm.db.elo -row 0 -column 1 -sticky we -pady "0 5"
-  grid $w.dm.db.dups -row 1 -column 0 -sticky we -padx "0 5" -pady "0 5"
-  grid $w.dm.db.strip -row 1 -column 1 -sticky we -pady "0 5"
-  grid $w.dm.db.compact -row 2 -column 0 -sticky we -padx "0 5" -pady "0 5"
-  grid $w.dm.db.cleaner -row 2 -column 1 -sticky we -pady "0 5"
-
   grid $w.title -sticky news
   grid $w.stats -pady 5 -sticky news
   grid $w.dbdesc -sticky news
@@ -356,7 +310,7 @@ proc ::maint::Refresh {} {
   $w.customFlags.edit configure -state disabled
 
   set state [expr {$state eq "disabled" || $ng == 0 ? "disabled" : "normal"}]
-  foreach frame {dm.delete dm.mark dm.spell dm.db} {
+  foreach frame {dm.delete dm.mark} {
     foreach widget [winfo children $w.$frame] {
 	  if {[winfo class $widget] eq "TLabel"} { continue }
 	  $widget configure -state $state
@@ -368,10 +322,6 @@ proc ::maint::Refresh {} {
      $w.dm.mark.onCurrent configure -state disabled
      $w.dm.mark.offCurrent configure -state disabled
   }
-  if {$state eq "normal" && ![baseIsCompactable]} {
-    $w.dm.db.compact configure -state disabled
-    $w.dm.db.cleaner configure -state disabled
-  }
 }
 
 # markTwins:
@@ -466,7 +416,7 @@ proc markTwins {{parent .}} {
       focus .
       destroy .twinSettings
       if {$result > 0} {
-        ::notify::DatabaseChanged
+        ::notify::DatabaseModified [sc_base current]
         set gn [sc_filter first]
         ::game::Load $gn
         updateTwinChecker
@@ -693,10 +643,9 @@ proc updateTwinChecker {} {
       pack $f.title.label $f.title.d $f.title.note -side left
       ttk::label $f.tmt -font font_Small -text "" -anchor w
       pack $f.tmt -side bottom -fill x
-      autoscrollframe $f.t text $f.t.text \
-          -height 16 -width 40 -background white \
-          -takefocus 0 -wrap word
-      $f.t.text tag configure h -background lightSteelBlue
+      autoscrollText y $f.t $f.t.text Treeview
+      $f.t.text configure -height 16 -width 40 -takefocus 0 -wrap word -state normal
+      $f.t.text tag configure h -background DodgerBlue1
       pack $f.t -side top -fill both -expand yes
     }
     $w.f.left.title.note configure -text [concat "(\"1\"" $::tr(TwinCheckUndelete)]
@@ -1000,7 +949,7 @@ proc stripTags {} {
   
   # Find extra PGN tags:
   progressWindow "Scid" "Searching for extra PGN tags..." $::tr(Cancel)
-  set err [catch {sc_base tag list} result]
+  set err [catch {sc_base taglist $::curr_db} result]
   closeProgressWindow
   if {$err} {
     ERROR::MessageBox
@@ -1029,65 +978,66 @@ proc stripTags {} {
   pack [ttk::frame $w.b] -side bottom -fill x
   
   set row 0
+  unset -nocomplain ::stripTagChoice
   foreach tag [lsort [array names stripTagCount]] {
-    set count $stripTagCount($tag)
-    ttk::radiobutton $w.f.t$tag -text "$tag  " -variable stripTagChoice -value $tag
-    ttk::label $w.f.c$tag -text [::utils::thousands $count]
-    if {$row == 0} { set stripTagChoice $tag }
+    set ::stripTagChoice($tag) 0
+    ttk::checkbutton $w.f.t$tag -text "$tag" -variable stripTagChoice($tag) -command "
+      foreach {tag selected} \[array get ::stripTagChoice\] {
+        if {\$selected} {
+          $w.b.strip configure -state normal
+          return
+        }
+      }
+      $w.b.strip configure -state disabled
+    "
+    ttk::label $w.f.c$tag -text "  [::utils::thousands $stripTagCount($tag)]"
     grid $w.f.t$tag -row $row -column 0 -sticky w
     grid $w.f.c$tag -row $row -column 1 -sticky e
     incr row
   }
-  ttk::button $w.b.find -text $::tr(SetFilter) -command findStripTags
-  ttk::button $w.b.strip -text $::tr(StripTag...) -command {
-    set removed [doStripTags .striptags]
-    set stripTagCount($stripTagChoice) \
-        [expr {$stripTagCount($stripTagChoice) - $removed} ]
-    .striptags.f.c$stripTagChoice configure -text \
-        [::utils::thousands $stripTagCount($stripTagChoice)]
-  }
+  ttk::button $w.b.strip -text $::tr(StripTag...) -state disabled -command "doStripTags $w"
   ttk::button $w.b.cancel -text $::tr(Cancel) \
       -command "catch {grab release $w}; destroy $w"
-  packdlgbuttons $w.b.cancel $w.b.strip $w.b.find
+  packdlgbuttons $w.b.cancel $w.b.strip
   wm resizable $w 0 0
   update
   catch {grab $w}
 }
 
-proc doStripTags {{parent .}} {
-  global stripTagChoice
-  set msg "Do you really want to remove all occurrences of the PGN tag"
-  append msg " \"$stripTagChoice\" from this database?"
-  set result [tk_messageBox -title "Scid" -parent $parent \
-      -icon question -type yesno -message $msg]
-  if {$result == "no"} { return 0 }
-  progressWindow "Scid" "Removing the PGN tag $stripTagChoice..." $::tr(Cancel)
-  set err [catch {sc_base tag strip $stripTagChoice} result]
-  closeProgressWindow
-  if {$err} {
-    ERROR::MessageBox
-    return 0
+proc doStripTags {topwin} {
+  set msg "Do you really want to remove all occurrences of the PGN tags:\n"
+  set tags {}
+  foreach {tag selected} [array get ::stripTagChoice] {
+    if {$selected} {
+      append msg "  $tag\n"
+      lappend tags $tag
+    }
   }
-  set count 0
-  set count $result
-  set result "Removed $result instances of \"$stripTagChoice\"."
+  append msg "from this database?"
+  set result [tk_messageBox -title "Scid" -parent $topwin \
+      -icon question -type yesno -message $msg]
+  if {$result == "no"} {
+    return
+  }
+  destroy $topwin
+  progressWindow "Scid" "Removing PGN tags..." $::tr(Stop)
+  set err [catch {sc_base strip $::curr_db {*}$tags} result]
+  closeProgressWindow
+  if {$err && $::errorCode != $::ERROR::UserCancel} {
+    ERROR::MessageBox
+    if {$result == 0} {
+      return
+    }
+  }
+  set result "Modified $result games."
   append result "\n\n"
   append result "To save space and maintain database efficiency, it is a "
   append result "good idea to compact the game file after removing tags."
-  tk_messageBox -title "Scid" -parent $parent -type ok -icon info \
-      -message $result
-  return $count
+  tk_messageBox -title "Scid" -type ok -icon info -message $result
+  ::notify::GameChanged
+  ::notify::DatabaseModified $::curr_db
 }
 
-proc findStripTags {} {
-  global stripTagChoice
-  progressWindow "Scid" "Finding games with the PGN tag $stripTagChoice..." $::tr(Cancel) 
-  set err [catch {sc_base tag find $stripTagChoice} result]
-  closeProgressWindow
-  ::notify::DatabaseModified $::curr_db dbfilter
-}
-
-
 # cleanerWin:
 #   Open a dialog so the user can choose several maintenance tasks
 #   in one action.
@@ -1231,7 +1181,9 @@ proc doCleaner {} {
     mtoolAdd $t "$count: $::tr(DeleteTwins)..."
     incr count
     if {$twinSettings(undelete) == "Yes"} {
-      sc_base gameflag [sc_base current] all unset del
+      if {[catch {sc_base gameflag [sc_base current] all unset del}]} {
+        $t insert end "   [ERROR::getErrorMsg]\n"
+      }
     }
     if {[catch {sc_base duplicates [sc_base current] \
             -colors $twinSettings(colors) \
