@@ -163,14 +163,14 @@ proc ::htext::updateRate {w rate} {
 proc ::htext::init {w} {
   set cyan "\#007000"
   set maroon "\#990000"
-  set green "darkgreen"
+  set green "green"
   
   set ::htext::updates($w) 100
   $w tag configure black -foreground black
   $w tag configure white -foreground white
   $w tag configure red -foreground red
-  $w tag configure blue -foreground blue
-  $w tag configure darkblue -foreground darkBlue
+  $w tag configure blue -foreground RoyalBlue3
+  $w tag configure darkblue -foreground DodgerBlue3
   $w tag configure green -foreground $green
   $w tag configure cyan -foreground $cyan
   $w tag configure yellow -foreground yellow
@@ -212,21 +212,18 @@ proc ::htext::init {w} {
   $w tag configure menu -font font_Bold -foreground $cyan
   
   # PGN-window-specific tags:
-  $w tag configure tag -foreground $::pgnColor(Header)
-  if { $::pgn::boldMainLine } {
-    $w tag configure nag -foreground $::pgnColor(Nag) -font font_Regular
-    $w tag configure var -foreground $::pgnColor(Var) -font font_Regular
-  } else {
-    $w tag configure nag -foreground $::pgnColor(Nag)
+  $w tag configure var -font font_Regular
+  $w tag configure nag -font font_Regular
+  if { $::pgnColor(Var) ne "" } {
     $w tag configure var -foreground $::pgnColor(Var)
-	 ### TODO
-    ### $w tag configure var -foreground $::pgnColor(Var) -font font_Figurine_Var
-
   }
-  $w tag configure ip1 -lmargin1 25 -lmargin2 25
-  $w tag configure ip2 -lmargin1 50 -lmargin2 50
-  $w tag configure ip3 -lmargin1 75 -lmargin2 75
-  $w tag configure ip4 -lmargin1 100 -lmargin2 100
+  $w tag configure nag -foreground $::pgnColor(Nag)
+
+  set lmargin 0
+  for {set i 1} {$i <= 19} {incr i} {
+    incr lmargin 25
+    $w tag configure "ip$i" -lmargin1 $lmargin -lmargin2 $lmargin
+  }
 }
 
 proc ::htext::isStartTag {tagName} {
@@ -332,9 +329,9 @@ proc ::htext::display {w helptext {section ""} {fixed 1}} {
         set tagName "run"
         $w tag bind "$runTag" <ButtonRelease-1> "catch {$runName}"
         $w tag bind $runTag <Any-Enter> \
-            "$w tag configure \"$runTag\" -foreground yellow
-        $w tag configure \"$runTag\" -background darkBlue
-        $w configure -cursor hand2"
+            "$w tag configure \"$runTag\" -foreground white
+             $w tag configure \"$runTag\" -background DodgerBlue4
+             $w configure -cursor hand2"
         $w tag bind $runTag <Any-Leave> \
             "$w tag configure \"$runTag\" -foreground {}
         $w tag configure \"$runTag\" -background {}
@@ -359,16 +356,16 @@ proc ::htext::display {w helptext {section ""} {fixed 1}} {
         set playerTag $tagName
         set playerName [string range $playerTag 3 end]
         set tagName "pi"
-        $w tag configure "$playerTag" -foreground darkBlue
+        $w tag configure "$playerTag" -foreground DodgerBlue3
         $w tag bind "$playerTag" <ButtonRelease-1> "::pinfo::playerInfo \"$playerName\""
         $w tag bind $playerTag <Any-Enter> \
-            "$w tag configure \"$playerTag\" -foreground yellow
-        $w tag configure \"$playerTag\" -background darkBlue
-        $w configure -cursor hand2"
+           "$w tag configure \"$playerTag\" -foreground white
+            $w tag configure \"$playerTag\" -background DodgerBlue4
+            $w configure -cursor hand2"
         $w tag bind $playerTag <Any-Leave> \
-            "$w tag configure \"$playerTag\" -foreground darkBlue
-        $w tag configure \"$playerTag\" -background {}
-        $w configure -cursor {}"
+           "$w tag configure \"$playerTag\" -foreground DodgerBlue3
+            $w tag configure \"$playerTag\" -background {}
+            $w configure -cursor {}"
       } elseif {[strIsPrefix "g_" $tagName]} {
         # Check if it is a game-load tag:
         set gameTag $tagName
@@ -379,9 +376,9 @@ proc ::htext::display {w helptext {section ""} {fixed 1}} {
         $w tag bind $gameTag <ButtonPress-$::MB3> \
             "::gbrowser::new [sc_base current] $gnum"
         $w tag bind $gameTag <Any-Enter> \
-            "$w tag configure $gameTag -foreground yellow
-        $w tag configure $gameTag -background darkBlue
-        $w configure -cursor hand2"
+            "$w tag configure $gameTag -foreground white
+             $w tag configure $gameTag -background DodgerBlue4
+             $w configure -cursor hand2"
         $w tag bind $gameTag <Any-Leave> \
             "$w tag configure $gameTag -foreground {}
         $w tag configure $gameTag -background {}
@@ -484,6 +481,10 @@ proc ::htext::display {w helptext {section ""} {fixed 1}} {
     # Check if it is an image or button tag:
     if {[strIsPrefix "img " $tagName]} {
       set imgName [string range $tagName 4 end]
+      #flags are not loaded on start, so check if a flag needs to load
+      if { $imgName ne [info commands $imgName] && [string range $imgName 0 3] eq "flag" } {
+        set imgName [getFlagImage [string range $imgName [expr [string length $imgName] - 3] end] yes]
+      }
       set winName $w.$imgName
       while {[winfo exists $winName]} { append winName a }
       ttk::label $winName -image $imgName -relief flat -borderwidth 0 -background white
