@@ -1,6 +1,5 @@
 # portbr.tcl:
 # Scid in Brazilian Portuguese.
-# Translated by Gilberto de Almeida Peres.
 
 proc setLanguage_B {} {
 
@@ -88,10 +87,11 @@ menuText B EditCopyBoard "Copia posio" 6 \
   {Copia o tabuleiro corrente em notao FEN para a rea de transferncia} 
 menuText B EditPasteBoard "Colar Posicao" 12 \
   {Configura a posicao inicial a partir da area de transferencia}
+menuText B ConfigureScid "Preferencias..." 0 {Configurar todas as opcoes para o SCID}
 
 # Game menu:
 menuText B Game "Jogo" 0
-menuText B GameNew "Limpar Jogo" 0 \
+menuText B GameNew "Novo Jogo" 0 \
   {Limpa o jogo corrente, descartando qualquer alteracao}
 menuText B GameFirst "Primeiro Jogo" 5 {Carrega o primeiro jogo filtrado}
 menuText B GamePrev "Jogo Anterior" 5 {Carrega o jogo anterior}
@@ -145,13 +145,12 @@ menuText B WindowsCorrChess "Janela de Correspondencia" 0 {Abre/Fecha a janela d
 
 # Tools menu:
 menuText B Tools "Ferramentas" 0
+menuText B ToolsConfigureEngines "Configurar Engines" 10 {Gerencia configuracao dos engines}
 menuText B ToolsAnalysis "Analisador #1..." 0 \
   {Inicia ou para o 1o. Analisador}
 menuText B ToolsAnalysis2 "Analisador #2..." 17 \
   {Inicia ou para o 2o. Analisador}
 menuText B ToolsCross "Tabela de Cruzamento" 0 {Mostra a tabela de cruzamentos do torneio para o jogo corrente}
-menuText B ToolsEmail "Gerenciador de e-mails" 0 \
-  {Abre/fecha a janela do gerenciador de e-mails}
 menuText B ToolsFilterGraph "Grfico de filtro" 7 \
   {Abre/Fecha a janela do grfico de filtro} 
 menuText B ToolsAbsFilterGraph "Grafico de Filtro Absoluto" 7 {Abre/Fecha a janela do grafico de filtro por valor absoluto}
@@ -169,7 +168,7 @@ menuText B ToolsTrainTactics "Tticas"  0 {Exerccios de ttica}
 menuText B ToolsTrainCalvar "Clculo de Variantes"  0 {Treinamento de clculo de variantes}
 menuText B ToolsTrainFindBestMove "Procurar melhor movimento"  0 {Procura o melhor movimento}
 menuText B ToolsTrainFics "Jogar na internet"  0 {Jogar em  freechess.org}
-menuText B ToolsEngineTournament "Torneio de motores de Xadrez"  0 {Inicia um torneio entre motores de Xadrez}
+menuText B ToolsEngineTournament "Torneio de Engines de Xadrez"  0 {Inicia um torneio entre engines de Xadrez}
 menuText B ToolsBookTuning "Sintonizar Livro" 0 {Sintonizar livro de aberturas}
 menuText B ToolsConnectHardware "Conectar Hardware" 0 {Conectar hardware externo}
 menuText B ToolsConnectHardwareConfigure "Configurar..." 0 {Configurar hardware e conexo externa}
@@ -208,29 +207,11 @@ menuText B ToolsStartEngine1 "Iniciar engine 1" 0  {Inicia engine 1}
 menuText B ToolsStartEngine2 "Iniciar engine 2" 0  {Inicia engine 2}
 menuText B ToolsCaptureBoard "Capturar posicao atual..." 5  {Salva uma imagem da posicao atual.}
 menuText B Play "Jogar" 0
-menuText B CorrespondenceChess "Xadrez por correspondncia" 0 {Funes para jogar xadrez por correspondncia usando eMail e Xfcc}
-menuText B CCConfigure "Configurar..." 0 {Configura ferramentas externas e configurao geral}
-menuText B CCConfigRelay "Observar jogos..." 10 {Configura jogos para observar}
-menuText B CCOpenDB "Abrir base..." 0 {Abre a base de correspondncia padro}
-menuText B CCRetrieve "Recupera jogos" 0 {Recupera jogos via (Xfcc-)}
-menuText B CCInbox "Processa caixa de entrada" 0 {Processa todos os arquivos na caixa de entrada do Scid}
-menuText B CCSend "Enviar movimento" 0 {Envia seu movimento via eMail ou (Xfcc-)}
 menuText B CCResign "Resignar" 0 {Aceita a derrota (no via eMail)}
 menuText B CCClaimDraw "Declarar empate" 0 {Envia o movimento e declara empate (no via eMail)}
-menuText B CCOfferDraw "Oferecer empate" 0 {Envia o movimento e oferece empate (no via eMail)}
-menuText B CCAcceptDraw "Aceitar empate" 0 {Aceita uma oferta de empate (no via eMail)}
-menuText B CCNewMailGame "Novo jogo por eMail..." 0 {Inicia um novo jogo por eMail}
-menuText B CCMailMove "Enviar movimento..." 0 {Envia movimento ao oponente via eMaail}
-menuText B CCGamePage "Pgina do jogo..." 0 {Chama o jogo atravs do browser}
-menuText B CCEditCopy "Copiar Lista de Jogos para a base de cpia" 0 {Copia os jogos no formato CSV para a base de cpia}
 
 # Options menu:
 menuText B Options "Opcoes" 0
-menuText B OptionsBoard "Tabuleiro" 0 {Opes de aparncia do tabuleiro} 
-menuText B OptionsBoardSize "Tamanho do Tabuleiro" 0 {Muda o tamanho do tabuleiro}
-menuText B OptionsBoardPieces "Estilo de Pecas no Tabuleiro" 10 \
-  {Muda o estilo das pecas mostradas no tabuleiro}
-menuText B OptionsBoardColors "Cores..." 0 {Muda as cores do tabuleiro}
 menuText B OptionsBoardGraphics "Casas..." 0 {Seleciona texturas para as casas}
 translate B OptionsBGW {Seleciona texturas para as casas}
 translate B OptionsBoardGraphicsText {Seleciona arquivos grficos para as casas brancas e pretas:}
@@ -251,8 +232,6 @@ menuText B OptionsMovesHighlightLastMoveWidth "Espessura" 0 {Espessura da linha}
 menuText B OptionsMovesHighlightLastMoveColor "Cor" 0 {Cor da linha}
 menuText B OptionsMovesHighlightLastMoveArrow "seta de inclusao" 0 {Seta de Inclusao Destacada}
 menuText B OptionsMoves "Movimentos" 0 {Opcoes para entrada dos movimentos}
-menuText B OptionsMovesAsk "Perguntar antes de substituir movimentos" 0 \
-  {Pergunta antes de substituir movimentos existentes}
 menuText B OptionsMovesAnimate "Tempo de animao" 1 \
   {Define a quantidade de tempo usada para animar os movimentos} 
 menuText B OptionsMovesDelay "Tempo de atraso p/ Jogo automatico..." 1 \
@@ -268,51 +247,34 @@ menuText B OptionsMovesKey "Auto completar" 0 \
 menuText B OptionsMovesShowVarArrows "Mostrar Setas para variantes" 0 {Liga/Desliga as setas que mostram movimentos em variantes}
 menuText B OptionsMovesGlossOfDanger "Codigos de Cor para Perigo" 0 {Liga/Desliga os codigos de cor para perigo}
 menuText B OptionsNumbers "Formato de Numeros" 0 {Selecione o formato usado para numeros}
-menuText B OptionsStartup "Iniciar" 1 \
-  {Seleciona janelas que serao abertas ao iniciar o programa}
 menuText B OptionsTheme "Tema" 0 {Muda a aparncia da interface}
 menuText B OptionsWindows "Janelas" 0 {Opcoes para Janelas}
-menuText B OptionsWindowsIconify "Auto-iconizar" 5 \
-  {Iconizar todas as janelas quando a janela principal eh iconizada}
-menuText B OptionsWindowsRaise "Manter no topo" 0 \
-  {Mantem no topo certas janelas (ex. barras de progresso) sempre que sao obscurecidas por outras}
-menuText B OptionsSounds "Sons..." 2 {Configura sons para anunciar os movimentos} 
+menuText B OptionsSounds "Sons" 2 {Configura sons para anunciar os movimentos} 
+menuText B OptionsResources "Recursos..." 0 {Escolher pastas e arquivos de recursos}
 menuText B OptionsWindowsDock "Estacionar janelas" 0 {Estaciona as janelas}
 menuText B OptionsWindowsSaveLayout "Salvar layout" 0 {Salva o layout das janelas}
 menuText B OptionsWindowsRestoreLayout "Restaurar layout" 0 {Restaura layout}
 menuText B OptionsWindowsShowGameInfo "Mostrar Informaes do Jogo" 0 {Mostra informaes do jogo}
 menuText B OptionsWindowsAutoLoadLayout "Carregar primeiro layout na entrada" 0 {Carrega automaticamente o primeiro layout ao entrar na aplicao}
-menuText B OptionsToolbar "Barra de Ferramentas da Janela Principal" 12 \
-  {Exibe/Oculta a barra de ferramentas da janela principal}
-menuText B OptionsECO "Carregar arquivo ECO..." 7 {Carrega o arquivo com a classificacao ECO}
-menuText B OptionsSpell "Carregar arquivo de verificacao ortografica..." 6 \
+menuText B OptionsECO "Carregar arquivo ECO" 7 {Carrega o arquivo com a classificacao ECO}
+menuText B OptionsSpell "Carregar arquivo de verificacao ortografica" 6 \
   {Carrega o arquivo de verificacao ortografica do Scid}
-menuText B OptionsTable "Diretorio de tabelas de base..." 0 \
+menuText B OptionsTable "Diretorio de tabelas de base" 0 \
   {Selecione um arquivo de tabela de base; todas as tabelas nesse diretorio serao usadas}
 menuText B OptionsRecent "Arquivos recentes..." 0 \
   {Muda o nmero de arquivos recentes no menu Arquivo} 
-menuText B OptionsBooksDir "Diretrio de Livros..." 0 {Define o diretrio para os livros de aberturas}
-menuText B OptionsTacticsBasesDir "Diretrio de bases..." 0 {Define o diretrio para as bases de treinamento de tticas}
-# ====== TODO To be translated ======
-menuText B OptionsPhotosDir "Photos directory..." 0 {Sets the photos bases directory}
-# ====== TODO To be translated ======
-menuText B OptionsThemeDir "Load Theme(s)..."  0 { Load a GUI theme package file }
+menuText B OptionsBooksDir "Diretrio de Livros" 0 {Define o diretrio para os livros de aberturas}
+menuText B OptionsTacticsBasesDir "Diretrio de bases" 0 {Define o diretrio para as bases de treinamento de tticas}
+menuText B OptionsPhotosDir "Diretorio de Fotos" 0 {Define o diretorio base de fotos}
+menuText B OptionsThemeDir "Carregar Tema(s)"  0 {Carrega arquivo de tema para a tela}
 menuText B OptionsSave "Salvar Configuracao" 0 \
   "Salva a configuracao no arquivo $::optionsFile"
 menuText B OptionsAutoSave "Salva Opcoes ao sair" 0 \
   {Salva automaticamente todas as opcoes quando sair do Scid}
-# ====== TODO To be translated ======
-menuText B OptionsMenuColor "Setup Menu Colors..." 0 { }
-# ====== TODO To be translated ======
-translate B MenuColorForeground "Textcolor"
-# ====== TODO To be translated ======
-translate B MenuColorBackground "Background"
-# ====== TODO To be translated ======
-translate B MenuColorSelect "Select"
 
 # Help menu:
 menuText B Help "Ajuda" 0
-menuText B HelpContents "Contents" 0 {Show the help contents page} 
+menuText B HelpContents "Conteudo" 0 {Mostra a pagina de conteudo da ajuda}
 menuText B HelpIndex "Indice" 0 {Indice da Ajuda}
 menuText B HelpGuide "Consulta Rapida" 0 {Mostra a pagina de consulta rapida}
 menuText B HelpHints "Dicas" 0 {Mostra a pagina de dicas}
@@ -343,11 +305,12 @@ translate B Cancel {Cancelar}
 translate B Continue {Continuar}
 translate B Clear {Limpar}
 translate B Close {Fechar}
-translate B Contents {Contedo} 
+translate B Contents {Conteudo} 
 translate B Defaults {Defaults}
 translate B Delete {Deletar}
 translate B Graph {Grafico}
 translate B Help {Ajuda}
+translate B Hide {Ocultar}
 translate B Import {Importar}
 translate B Index {Indice}
 translate B LoadGame {Carrega jogo}
@@ -362,7 +325,7 @@ translate B Stop {Parar}
 translate B Store {Guardar}
 translate B Update {Atualizar}
 translate B ChangeOrient {Muda orientacao da janela}
-translate B ShowIcons {Mostrar cones} 
+translate B ShowIcons {Mostrar Icones} 
 translate B None {Nenhum}
 translate B First {Primeiro}
 translate B Current {Atual}
@@ -401,8 +364,7 @@ translate B Month {Mes}
 translate B Months {Janeiro Fevereiro Marco Abril Maio Junho Julho Agosto Setembro Outubro Novembro Dezembro}
 translate B Days {Dom Seg Ter Qua Qui Sex Sab}
 translate B YearToToday {Anos ate hoje}
-# ====== TODO To be translated ======
-translate B YearToTodayTooltip {Set date from 1 year back to today}
+translate B YearToTodayTooltip {Define a data para 1 ano atrs}
 translate B Result {Resultado}
 translate B Round {Rodada}
 translate B Length {Tamanho}
@@ -448,6 +410,7 @@ translate B PInfoMostBlack {Aberturas mais comuns com as Pretas}
 translate B PInfoRating {Historico de Rating}
 translate B PInfoBio {Biografia}
 translate B PInfoEditRatings {Editar Ratings} 
+translate B PInfoEloFile {Arquivo}
 
 # Tablebase information:
 translate B Draw {Empate}
@@ -466,26 +429,19 @@ translate B WinningMoves {Movimentos vencedores}
 translate B DrawingMoves {Movimentos para empate} 
 translate B LosingMoves {Movimentos perdedores} 
 translate B UnknownMoves {Movimentos com resultado desconhecido} 
-# ====== TODO To be translated ======
-translate B SideLongest {Side    Longest    %     %     %\n}
-# ====== TODO To be translated ======
-translate B toNoveMate {to move   mate    Win  Draw  Loss\n}
-# ====== TODO To be translated ======
-translate B NoSummary {\nNo summary for this tablebase.}
-# ====== TODO To be translated ======
-translate B MutualZugzwang {Mutual zugzwangs: }
-# ====== TODO To be translated ======
-translate B SelectetZugzwang {\nSelected zugzwang positions:}
-# ====== TODO To be translated ======
-translate B WdrawBloss {White draws, Black loses:}
-# ====== TODO To be translated ======
-translate B BdrawWloss {Black draws, White loses:}
-# ====== TODO To be translated ======
-translate B AllLoss {" Whoever moves loses:     " }
+translate B SideLongest {Lado    Mov. p/    %     %     %\n}
+translate B toNoveMate {a mover   mate      V     E     D\n}
+translate B NoSummary {\nSem resumo para esta tablebase.}
+translate B MutualZugzwang {Zugzwangs Nutuos: }
+translate B SelectetZugzwang {\nPosicoes de zugzwang selecionadas:}
+translate B WdrawBloss {Branca empata, Preta perde:}
+translate B BdrawWloss {Preta empata, Branca perde:}
+translate B AllLoss {" Quem mover perde   :     " }
 
 # Tip of the day:
 translate B Tip {Dica}
 translate B TipAtStartup {Dica ao iniciar}
+translate B TipConvertPGN {Voce pode obter melhor desempenho convertendo seus arquivos PGN}
 
 # Tree window menus: ***
 menuText B TreeFile "Arquivo" 0
@@ -642,6 +598,8 @@ menuText B GraphOptionsWhite "Branco" 0
 menuText B GraphOptionsBlack "Preto" 0
 menuText B GraphOptionsBoth "Ambos" 0
 menuText B GraphOptionsPInfo "Informacao do Jogador" 0
+menuText B GraphOptionsEloFile "Elo do arquivo de rating" 0
+menuText B GraphOptionsEloDB "Elo da base de dados" 0
 translate B GraphFilterTitle "Grfico de filtro: frequencia por 1000 jogos" 
 translate B GraphAbsFilterTitle "Grfico de filtro: frequencia dos jogos"
 translate B ConfigureFilter {Configurar Eixos X para Ano, Rating e Movimentos}
@@ -673,7 +631,7 @@ translate B BlundersThreshold {Limite}
 translate B ScoreAllMoves {Analise todos os movimentos}
 translate B LowPriority {Baixa prioridade da CPU} 
 translate B ClickHereToSeeMoves {Clique aqui para ver os movimentos}
-translate B ConfigureInformant {Configurar Informante}
+translate B ConfigureInformant {Informante}
 translate B Informant!? {Movimento interessante}
 translate B Informant? {Movimento pobre}
 translate B Informant?? {Erro crasso}
@@ -681,7 +639,7 @@ translate B Informant?! {Movimento duvidoso}
 translate B Informant+= {Branca tem alguma vantagem}
 translate B Informant+/- {Branca tem vantagem moderada}
 translate B Informant+- {Branca tem vantagem decisiva}
-translate B Informant++- {O jogo  considerado como ganho}
+translate B Informant+-- {O jogo  considerado como ganho}
 translate B Book {Livro}
 translate B OtherBookMoves {Livro do oponente}
 translate B OtherBookMovesTooltip {Movimentos para os quais o oponente tem resposta}
@@ -697,12 +655,28 @@ translate B EngineTime {Data}
 translate B EngineNew {Novo}
 translate B EngineEdit {Editar}
 translate B EngineRequired {Campos em negrito so obrigatrios; os demais so opcionais}
-
-# Stats window menus:
-menuText B StatsFile "Arquivo" 0
-menuText B StatsFilePrint "Imprimir para arquivo..." 0
-menuText B StatsFileClose "Fecha janela" 0
-menuText B StatsOpt "Opcoes" 0
+# ====== TODO To be translated ======
+translate B EngineProtocol {Communication protocol}
+# ====== TODO To be translated ======
+translate B EngineNotation {Notation of the moves}
+# ====== TODO To be translated ======
+translate B EngineFlipEvaluation {Flip evaluation perspective}
+# ====== TODO To be translated ======
+translate B EngineShowLog {Show communication log}
+# ====== TODO To be translated ======
+translate B EngineNetworkd {Accept remote connections}
+# ====== TODO To be translated ======
+translate B EngineSelect {Select the current engine}
+# ====== TODO To be translated ======
+translate B EngineAddLocal {Add a local engine}
+# ====== TODO To be translated ======
+translate B EngineAddRemote {Add a remote engine}
+# ====== TODO To be translated ======
+translate B EngineReload {Reload the current engine}
+# ====== TODO To be translated ======
+translate B EngineClone {Create a copy of the current engine}
+# ====== TODO To be translated ======
+translate B EngineDelete {Delete the current engine}
 
 # PGN window menus:
 menuText B PgnFile "Arquivo" 0
@@ -983,6 +957,8 @@ translate B WhiteClearAdvantage {Branca tem clara vantagem}
 translate B BlackClearAdvantage {Preta tem clara vantagem} 
 translate B WhiteSlightAdvantage {Branca tem alguma vantagem} 
 translate B BlackSlightAdvantage {Preta tem alguma vantagem} 
+translate B WhiteCrushing {Branca tem enorme vantagem}
+translate B BlackCrushing {Preta tem enorme vantagem}
 translate B Equality {Igualdade} 
 translate B Unclear {No claro} 
 translate B Diagram {Diagrama} 
@@ -1289,6 +1265,7 @@ translate B ExportStripMarks {Remover cdigos de marca de casa/seta dos comentrio
 # Goto game/move dialogs:
 translate B LoadGameNumber {Entre o numero do jogo a ser carregado:}
 translate B GotoMoveNumber {Ir p/ o lance no.:}
+translate B CopyAllGames {Copiar todos os jogos}
 
 # Copy games dialog:
 translate B CopyGames {Copiar jogos}
@@ -1331,6 +1308,7 @@ translate B SoundsAnnounceOptions {Opes de anuncio de movimentos}
 translate B SoundsAnnounceNew {Anuncia novos movimentos quando eles so feitos} 
 translate B SoundsAnnounceForward {Anuncia movimentos quando avanar um movimento} 
 translate B SoundsAnnounceBack {Anuncia movimentos quando retroceder um movimento} 
+translate B SoundsSoundDisabled {O Scid no conseguiu encontrar o pacote de udio Snack na inicializao;\nSound est desativado.}
 
 # Upgrading databases:
 translate B Upgrading {Atualizando}
@@ -1567,6 +1545,14 @@ translate B FICSConnect {Conectar}
 translate B FICSdefaultuservars {Usar variaveis default}
 translate B FICSObserveconfirm {Voce quer observar o jogo}
 translate B FICSpremove {Habilita Pre-movimento}
+translate B FICSObserve {Observar}
+translate B FICSRatedGames {Jogos com rating}
+translate B FICSUnratedGames {Jogos sem rating}
+translate B FICSRated {Com rating}
+translate B FICSUnrated {Sem rating}
+translate B FICSRegisteredPlayer {Apenas jogador registrado}
+translate B FICSFreePlayer {Apenas jogador gratuito}
+translate B FICSNetError {Erro de rede\nNao pode conectar }
 translate B GameReview {Rever jogo}
 translate B GameReviewTimeExtended {Tempo estendido}
 translate B GameReviewMargin {Mergem de erro}
@@ -1586,72 +1572,11 @@ translate B GameReviewNotEngineMoveButGoodMove {No  o movimento do engine, mas
 translate B GameReviewMoveNotGood {Este movimento no  bom; seu score e}
 translate B GameReviewMovesPlayedLike {Movimentos semelhantes}
 translate B GameReviewMovesPlayedEngine {Movimentos semelhantes aos do engine}
-translate B CCDlgConfigureWindowTitle {Configurar Xadrez por correspondencia}
 translate B CCDlgCGeneraloptions {Opes Gerais}
-translate B CCDlgDefaultDB {Base default:}
-translate B CCDlgInbox {Caixa de Entrada (caminho):}
-translate B CCDlgOutbox {Caixa de Saida (caminho):}
-translate B CCDlgXfcc {Configuraao do Xfcc:}
-translate B CCDlgExternalProtocol {Tratamento de protocolo externo (ex. Xfcc)}
-translate B CCDlgFetchTool {Ferramenta de busca:}
-translate B CCDlgSendTool {Ferramenta de envio:}
-translate B CCDlgEmailCommunication {Comunicao por eMail}
-translate B CCDlgMailPrg {Programa de Mail:}
-translate B CCDlgBCCAddr {Endereo Cpia Oculta:}
-translate B CCDlgMailerMode {Modo:}
-translate B CCDlgThunderbirdEg {ex. Thunderbird, Mozilla Mail, Icedove...}
-translate B CCDlgMailUrlEg {ex. Evolution}
-translate B CCDlgClawsEg {ex. Sylpheed Claws}
-translate B CCDlgmailxEg {ex. mailx, mutt, nail...}
-translate B CCDlgAttachementPar {Parametro de anexos:}
-translate B CCDlgInternalXfcc {Usar suporte internal Xfcc}
-translate B CCDlgConfirmXfcc {Confirmar movimentos}
-translate B CCDlgSubjectPar {Parametro de Assunto:}
-translate B CCDlgDeleteBoxes {Esvaziar caixas de entrada e sada}
-translate B CCDlgDeleteBoxesText {Voce quer realmente esvaziar as caixas de Entrada e Saida usadas para o Xadrez por correspondncia? Esta operao exige uma novaa sincronizao para mostrar o ultimo estado dos seus jogos}
-translate B CCDlgConfirmMove {Confirmar movimento}
-translate B CCDlgConfirmMoveText {Se voce confirmar, o movimento indicado a seguir e os comentrios sero enviados para o servidor:}
-translate B CCDlgDBGameToLong {Linha principal inconsistente}
-translate B CCDlgDBGameToLongError {A linha principal na sua base  maior do que o jogo que est na caixa de entrada. Se a caixa de entrada contem jogos correntes, isto  logo aps uma sincronizao, alguns movimentos foram adicionados erroneamente  linha principal na base.\nNeste caso, por favor, diminua a linha principal para (no maximo) movimentos\n}
-translate B CCDlgStartEmail {Iniciar novo jogo por eMail}
-translate B CCDlgYourName {Seu nome:}
-translate B CCDlgYourMail {Seu eMail:}
-translate B CCDlgOpponentName {Nome do Oponente:}
-translate B CCDlgOpponentMail {eMail do Oponente:}
-translate B CCDlgGameID {ID do jogo (unico):}
-translate B CCDlgTitNoOutbox {Scid: Caixa de Saida}
-translate B CCDlgTitNoInbox {Scid: Caixa de Entrada}
-translate B CCDlgTitNoGames {Scid: Nenhum jogo por correspondncia}
-translate B CCErrInboxDir {Diretorio da Caixa de Entrada:}
-translate B CCErrOutboxDir {Diretorio da Caixa de Saida:}
-translate B CCErrDirNotUsable {no existe ou no est acessivel!\nPor favor, verifique e corrija a configurao.}
-translate B CCErrNoGames {no contem nenhum jogo!\nPor favor, localize-os primeiro.}
-translate B CCDlgTitNoCCDB {Scid: Nenhuma base de correspondncia}
-translate B CCErrNoCCDB {Nenhuma base do tipo 'Correspondencia' est aberta. Por favor, abra uma antes de usar as funcoes do xadrez por correspondencia.}
-translate B CCFetchBtn {Busca jogos no servidor e processa a Caixa de Entrada}
-translate B CCPrevBtn {Ir para o jogo anterior}
-translate B CCNextBtn {Ir para o proximo jogo}
-translate B CCSendBtn {Enviar movimento}
-translate B CCEmptyBtn {Esvaziar caixas de entrada e saida}
-translate B CCHelpBtn {Ajuda sobre icones e indicadores de estado.\nPara ajuda geral, use a tecla F1!}
-translate B CCDlgServerName {Nome do Servidor:}
 translate B CCDlgLoginName  {Login Name:}
 translate B CCDlgPassword   {Senha:}
 translate B CCDlgShowPassword {Mostra a Senha}
-translate B CCDlgURL        {Xfcc-URL:}
-translate B CCDlgRatingType {Tipo de Rating:}
-translate B CCDlgDuplicateGame {ID de jogo no nico}
-translate B CCDlgDuplicateGameError {Este jogo existe mais de uma vez em sua base. Exclua todas as duplicatas e compacte seu arquivo de jogos (Arquivo/Manuteno/Compactar Base).}
-translate B CCDlgSortOption {Ordenando:}
-translate B CCDlgListOnlyOwnMove {Somente jogos nos quais tenho o movimento}
-translate B CCOrderClassicTxt {Local, Evento, Rodada, Resultado, Branca, Preta}
-translate B CCOrderMyTimeTxt {Meu Relgio}
-translate B CCOrderTimePerMoveTxt {Tempo por movimento at o prximo controle de tempo}
-translate B CCOrderStartDate {Data de Inicio}
-translate B CCOrderOppTimeTxt {Relogio do Oponente}
 
-translate B CCDlgConfigRelay {Observar jogos}
-translate B CCDlgConfigRelayHelp {Consulta a pagina de jogos em http://www.iccf-webchess.com e mostra o jogo a ser observado.  Se voce enxergar o tabuleiro, copie a URL do seu navegador para a lista abaixo. Apenas uma URL por linha!\nExemplo: http://www.iccf-webchess.com/MakeAMove.aspx?id=266452}
 
 translate B ExtHWConfigConnection {Configurar hardware externo}
 translate B ExtHWPort {Porta}
@@ -1678,74 +1603,52 @@ translate B DockLeft {Mover para a esquerda}
 translate B DockRight {Mover para a direita}
 translate B Undock {Desacoplar}
 translate B ChangeIcon {Alterar icone...}
-# ====== TODO To be translated ======
-translate B NewGameListWindow {New Game List Window}
-# ====== TODO To be translated ======
-translate B LoadatStartup {Load at startup}
-# ====== TODO To be translated ======
-translate B ShowHideDB {Show/Hide databases}
-# ====== TODO To be translated ======
-translate B ChangeFilter {Change filter}
-# ====== TODO To be translated ======
-translate B ChangeLayout {Load/Save/Change sorting criteria and column layout}
-# ====== TODO To be translated ======
-translate B ShowHideStatistic {Show/Hide statistics}
-# ====== TODO To be translated ======
-translate B BoardFilter {Show only games that matches the current board position}
-# ====== TODO To be translated ======
-translate B CopyGameTo {Copy Game to}
-# ====== TODO To be translated ======
-translate B FindBar {Find Bar}
-# ====== TODO To be translated ======
-translate B FindCurrentGame {Find current game}
-# ====== TODO To be translated ======
-translate B DeleteGame {Delete game}
-# ====== TODO To be translated ======
-translate B UndeleteGame {Undelete game}
-# ====== TODO To be translated ======
-translate B ResetSort {Reset sort}
-# ====== TODO To be translated ======
-translate B ConvertNullMove {Convert null moves to comments}
-# ====== TODO To be translated ======
-translate B SetupBoard {Setup Board}
-# ====== TODO To be translated ======
-translate B Rotate {Rotate}
-# ====== TODO To be translated ======
-translate B SwitchColors {Switch colors}
-# ====== TODO To be translated ======
-translate B FlipBoard {Flip Board}
-# ====== TODO To be translated ======
-translate B ImportPGN {Import PGN game}
-# ====== TODO To be translated ======
-translate B ImportingFiles {Importing PGN files in}
-# ====== TODO To be translated ======
-translate B ImportingFrom {Importing from}
-# ====== TODO To be translated ======
-translate B ImportingIn {Import games in}
-# ====== TODO To be translated ======
-translate B UseLastTag {Use last\ngame's tags}
-# ====== TODO To be translated ======
-translate B Random {Random}
-# ====== TODO To be translated ======
-translate B BackToMainline {Go back to mainline}
-# ====== TODO To be translated ======
-translate B LeaveVariant {Leave variant}
-# ====== TODO To be translated ======
-translate B Autoplay {Autoplay}
-# ====== TODO To be translated ======
-translate B ShowHideCoords {Show/Hide Coord.}
-# ====== TODO To be translated ======
-translate B ShowHideMaterial {Show/Hide Material}
-# ====== TODO To be translated ======
-translate B FullScreen {Full Screen}
-# ====== TODO To be translated ======
-translate B FilterStatistic {Filter Statistics}
-# ====== TODO To be translated ======
-translate B MakeCorrections {Make Corrections}
-# ====== TODO To be translated ======
-translate B Surnames {Surnames}
-# ====== TODO To be translated ======
-translate B Ambiguous {Ambiguous}
+translate B NewGameListWindow {Lista de Novos Jogos}
+translate B LoadatStartup {Carregar ao inicializar}
+translate B ShowHideDB {Exibe/Oculta base de dados}
+translate B ChangeFilter {Altera filtro}
+translate B ChangeLayout {Carrega/Salva/Altera criterio de ordenacao e layout das colunas}
+translate B ShowHideStatistic {Exibe/Oculta Estatisticas}
+translate B BoardFilter {Mostra apenas jogos que atendam a posicao atual no tabuleiro}
+translate B CopyGameTo {Copiar jogo para}
+translate B FindBar {Barra de Pesquisa}
+translate B FindCurrentGame {Pesquisar jogo atual}
+translate B DeleteGame {Excluir jogo}
+translate B UndeleteGame {Recuperar jogo deletado}
+translate B ResetSort {Reiniciar ordenacao}
+translate B ConvertNullMove {Converter movimentos nullos para comentarios}
+translate B SetupBoard {Definir tabuleiro}
+translate B Rotate {Rotacionar}
+translate B SwitchColors {Trocar cores}
+translate B FlipBoard {Virar o tabuleiro}
+translate B ImportPGN {Importar jogo em PGN}
+translate B ImportingFiles {Importar arquivos PGN para}
+translate B ImportingFrom {Importando de}
+translate B ImportingIn {Importar jogos para}
+translate B UseLastTag {Usar ultimas\ntags do jogo}
+translate B Random {Aleatorio}
+translate B BackToMainline {Voltar para linha principal}
+translate B LeaveVariant {Deixar variante}
+translate B Autoplay {Jogo automatico}
+translate B ShowHideCoords {Exibir/Ocultar Coord.}
+translate B ShowHideMaterial {Exibir/Ocultar Material}
+translate B FullScreen {Tela Cheia}
+translate B FilterStatistic {Estatisticas de Filtro}
+translate B MakeCorrections {Fazer Correcoes}
+translate B Surnames {Sobrenomes}
+translate B Ambiguous {Ambiguo}
+translate B OptionsToolbar "Barra de Ferramentas da Janela Principal"
+translate B OptionsBoard "Tabuleiro"
+translate B OptionsMenuColor "Define Cores dos Menus"
+translate B OptionsBoardSize "Tamanho do Tabuleiro"
+translate B OptionsBoardPieces "Estilo de Pecas no Tabuleiro"
+translate B OptionsInternationalization "Internacionalizacao"
+translate B MenuColorForeground "Cor do Texto"
+translate B MenuColorBackground "Cor de Fundo"
+translate B MenuColorSelect "Selecionar"
+translate B OptionsTablebaseDir "Selecione at 4 pastas tabela base de finais:"
+translate B BestMoveArrow "Seta de melhor movimento"
+translate B NewLocalEngine "+ Novo engine ..."
 }
 
 # end of portbr.tcl
