@@ -94,6 +94,8 @@ menuText S EditCopyBoard "Copiar posicin" 8 \
   {Copia el tablero actual en notacin FEN al portapapeles}
 menuText S EditPasteBoard "Pegar tablero inicial" 6 \
   {Coloca el tablero inicial en el portapapeles}
+# ====== TODO To be translated ======
+menuText S ConfigureScid "Preferences..." 0 {Configure all options for SCID}
 
 # Game menu:
 menuText S Game "Partida" 0
@@ -159,13 +161,13 @@ menuText S WindowsCorrChess "Ventana de Correo" 0 {Abrir/Cerrar la ventra de Cor
 
 # Tools menu:
 menuText S Tools "Herramientas" 0
+# ====== TODO To be translated ======
+menuText S ToolsConfigureEngines "Configure Engines" 10 {Manage engines' configuration}
 menuText S ToolsAnalysis "Motor de anlisis #1..." 0 \
   {Inicia/para el anlisis del motor de ajedrez #1}
 menuText S ToolsAnalysis2 "Motor de anlisis #2..." 18 \
   {Inicia/para el anlisis del motor de ajedrez #2}
 menuText S ToolsCross "Tabla cruzada" 0 {Muestra la tabla cruzada para esta partida}
-menuText S ToolsEmail "Administrador de Email" 0 \
-  {Abre/cierra la ventana del administrador de Email}
 menuText S ToolsFilterGraph "Filtro grfico" 7 \
   {Abre/cierra la ventana del filtro grfico}
 menuText S ToolsAbsFilterGraph "Filtro grfico Abs." 7 {Abrir/Cerrar la ventana de filtro grfico para valores absolutos}
@@ -226,41 +228,12 @@ menuText S ToolsStartEngine1 "Empezar motor 1" 0  {Empieza el motor 1}
 menuText S ToolsStartEngine2 "Empezar motor 2" 0  {Empieza el motor 2}
 menuText S ToolsCaptureBoard "Capturar Tablero Actual..." 0  {Guardar el tablero actual como imagen.}
 menuText S Play "Jugar" 0
-menuText S CorrespondenceChess "Ajedrez por correo" 0 \
-  {Funciones para ajedrez por correo basado en email y Xfcc}
-menuText S CCConfigure "Configurar..." 0 \
-  {Configura herramientas externas y configuracin general}
-menuText S CCConfigRelay "Configurar observaciones..." 10 {Configurar partidas para ser observadas}
-menuText S CCOpenDB "Abrir base de datos..." 0 \
-  {Abrir la base de correo por defecto}
-menuText S CCRetrieve "Reparar partidas" 0 \
-  {Repara partidas va ayuda externa (Xfcc)}
-menuText S CCInbox "Procesar correo entrante" 0 \
-  {Procesa todos los ficheros en correo entrante de Scid (Inbox)}
-menuText S CCSend "Enviar movimiento" 0 \
-  {Envia tu movimiento via eMail o ayuda externa (Xfcc)}
 menuText S CCResign "Abandonar" 0 {Abandona}
 menuText S CCClaimDraw "Reclamar tablas" 0 \
   {Envia un movimiento y reclama tablas}
-menuText S CCOfferDraw "Ofrecer tablas" 0 \
-  {Envia un movimiento y ofrecer tablas}
-menuText S CCAcceptDraw "Aceptar tablas" 0 {Acepta un ofrecimiento de tablas}
-menuText S CCNewMailGame "Nueva partida email..." 0 \
-  {Empeza una nueva partida por email}
-menuText S CCMailMove "Enviar jugada via email..." 0 \
-  {Enva el movimiento via email al oponente}
-menuText S CCGamePage "Pgina de la partida..." 0 \
-  {Abre la partida desde el navegador}
-menuText S CCEditCopy "Copiar lista de partidas a Clipbase" 0 \
-  {Copia las partidas como una lista CSV a Clipbase}
 
 # Options menu:
 menuText S Options "Opciones" 0
-menuText S OptionsBoard "Tablero" 0 {Opciones sobre el aspecto del tablero}
-menuText S OptionsBoardSize "Tamao del tablero" 0 {Cambia el tamao del tablero}
-menuText S OptionsBoardPieces "Estilo de piezas" 10 \
-  {Cambia el estilo de piezas del tablero}
-menuText S OptionsBoardColors "Colores..." 0 {Cambia los colores del tablero}
 menuText S OptionsBoardGraphics "Escaques..." 0 {Elige texturas para escaques}
 translate S OptionsBGW {Elegir textura para escaques}
 translate S OptionsBoardGraphicsText {Elegir fichero grfico para escaques blancos y negros}
@@ -285,8 +258,6 @@ menuText S OptionsMovesHighlightLastMoveColor "Color" 0 {Color de lnea}
 # ====== TODO To be translated ======
 menuText S OptionsMovesHighlightLastMoveArrow "include Arrow" 0 {Include Arrow with Highlight}
 menuText S OptionsMoves "Movimientos" 0 {Opciones de la entrada de movimientos}
-menuText S OptionsMovesAsk "Preguntar antes de reemplazar movimientos" 0 \
-  {Pregunta antes de sobreescribir cualquier movimiento existente}
 menuText S OptionsMovesAnimate "Velocidad de la animacin" 1 \
   {Pone el tiempo usado para animar las jugadas}
 menuText S OptionsMovesDelay "Demora del automovimiento..." 0 \
@@ -307,16 +278,12 @@ menuText S OptionsMovesShowVarArrows "Mostrar flechas para las variaciones" 0 \
 menuText S OptionsMovesGlossOfDanger "Color Coded Gloss of Danger" 0 {Turn on/off color coded gloss of danger}
 menuText S OptionsNumbers "Formato de nmeros" 11 \
   {Selecciona el formato de nmeros}
-menuText S OptionsStartup "Inicio" 3 \
-  {Selecciona las ventanas que se abren al comenzar}
 menuText S OptionsTheme "Tema" 0 {Cambia el aspecto del interfaz}
 menuText S OptionsWindows "Ventanas" 0 {Opciones de ventana}
-menuText S OptionsWindowsIconify "Autominimizar" 4 \
-  {Minimiza todas las ventanas cuando la ventana principal es minimizada}
-menuText S OptionsWindowsRaise "Poner a la vista automticamente" 0 \
-  {Hace visibles ciertas ventanas (ej. barras de progreso) siempre que sean tapadas}
-menuText S OptionsSounds "Sonidos..." 2 \
+menuText S OptionsSounds "Sonidos" 2 \
   {Configura el sonido del anuncio de las jugadas}
+# ====== TODO To be translated ======
+menuText S OptionsResources "Resources..." 0 {Choose resource files and folders}
 menuText S OptionsWindowsDock "Ventanas en dique" 0 {Ventanas en dique}
 menuText S OptionsWindowsSaveLayout "Salvar disposicin" 0 {Salva la disposicin}
 menuText S OptionsWindowsRestoreLayout "Restaurar disposicin" 0 \
@@ -325,36 +292,26 @@ menuText S OptionsWindowsShowGameInfo "Mostrar informacin de la partida" 0 \
   {Muestrar informacin de la partida}
 menuText S OptionsWindowsAutoLoadLayout "Auto cargar primera disposicin" 0 \
   {Autocarga la primera disposicin al iniciar}
-menuText S OptionsToolbar "Barra de herramientas ventana principal" 9 \
-  {Muestra/oculta la barra de herramientas de la ventana principal}
-menuText S OptionsECO "Cargar archivo ECO..." 7 \
+menuText S OptionsECO "Cargar archivo ECO" 7 \
   {Cargar el archivo de clasificacin ECO}
-menuText S OptionsSpell "Cargar archivo de comprobacin ortogrfica..." 2 \
+menuText S OptionsSpell "Cargar archivo de comprobacin ortogrfica" 2 \
   {Carga el archivo de comprobacin ortogrfica Scid}
-menuText S OptionsTable "Directorio de las tablas de finales (TB)..." 19 \
+menuText S OptionsTable "Directorio de las tablas de finales (TB)" 19 \
   {Selecciona el directorio de tablas finales; todas las TB de ese directorio sern usadas}
 menuText S OptionsRecent "Archivos recientes..." 9 \
   {Cambia el nmero de archivos recientes mostrados en el men Archivo}
-menuText S OptionsBooksDir "Carpeta de libros de aperturas..." 0 \
+menuText S OptionsBooksDir "Carpeta de libros de aperturas" 0 \
   {Fija la carpeta de los libros de aperturas (Books)}
-menuText S OptionsTacticsBasesDir "Carpeta de bases de datos..." 0 \
+menuText S OptionsTacticsBasesDir "Carpeta de bases de datos" 0 \
   {Fija la carpeta de la base de entrenamiento tctico}
 # ====== TODO To be translated ======
-menuText S OptionsPhotosDir "Photos directory..." 0 {Sets the photos bases directory}
+menuText S OptionsPhotosDir "Photos directory" 0 {Sets the photos bases directory}
 # ====== TODO To be translated ======
-menuText S OptionsThemeDir "Load Theme(s)..."  0 { Load a GUI theme package file }
+menuText S OptionsThemeDir "Theme(s) File:"  0 { Load a GUI theme package file }
 menuText S OptionsSave "Guardar opciones" 0 \
   "Guarda todas las opciones en el fichero $::optionsFile"
 menuText S OptionsAutoSave "Autoguardar opciones al salir" 0 \
   {Guarda automticamente todas las opciones cuando se sale de Scid}
-# ====== TODO To be translated ======
-menuText S OptionsMenuColor "Setup Menu Colors..." 0 { }
-# ====== TODO To be translated ======
-translate S MenuColorForeground "Textcolor"
-# ====== TODO To be translated ======
-translate S MenuColorBackground "Background"
-# ====== TODO To be translated ======
-translate S MenuColorSelect "Select"
 
 # Help menu:
 menuText S Help "Ayuda" 1
@@ -395,6 +352,8 @@ translate S Defaults {Por defecto}
 translate S Delete {Borrar}
 translate S Graph {Grfico}
 translate S Help {Ayuda}
+# ====== TODO To be translated ======
+translate S Hide {Hide}
 translate S Import {Importar}
 translate S Index {ndice}
 translate S LoadGame {Cargar partida}
@@ -495,6 +454,8 @@ translate S PInfoMostBlack {Aperturas ms comunes con negras}
 translate S PInfoRating {Historial de clasificacin}
 translate S PInfoBio {Biografa}
 translate S PInfoEditRatings {Editar Elos}
+# ====== TODO To be translated ======
+translate S PInfoEloFile {File}
 
 # Tablebase information:
 translate S Draw {Tablas}
@@ -533,6 +494,8 @@ translate S AllLoss {" Whoever moves loses:     " }
 # Tip of the day:
 translate S Tip {Sugerencia}
 translate S TipAtStartup {Sugerencia al iniciar}
+# ====== TODO To be translated ======
+translate S TipConvertPGN {You can get better performance by converting PGN files}
 
 # Tree window menus:
 menuText S TreeFile "Archivo" 0
@@ -701,6 +664,10 @@ menuText S GraphOptionsWhite "Blancas" 0
 menuText S GraphOptionsBlack "Negras" 0
 menuText S GraphOptionsBoth "Ambos" 0
 menuText S GraphOptionsPInfo "Jugador Informacin jugador" 0
+# ====== TODO To be translated ======
+menuText S GraphOptionsEloFile "Elo from rating file" 0
+# ====== TODO To be translated ======
+menuText S GraphOptionsEloDB "Elo from database" 0
 translate S GraphFilterTitle "Filtro grfico: frecuencia por 1000 partidas"
 translate S GraphAbsFilterTitle "Filtro grfico: frecuencia de las partidas"
 translate S ConfigureFilter {Configurar Eje-X para Ao, Rating y Movimientos}
@@ -732,7 +699,7 @@ translate S BlundersThreshold {Umbral del error }
 translate S ScoreAllMoves {Puntuar todos los movimientos}
 translate S LowPriority {Baja prioridad del procesador}
 translate S ClickHereToSeeMoves {Pulsa aqu para ver movimientos}
-translate S ConfigureInformant {Configurar informaciones}
+translate S ConfigureInformant {Informaciones}
 translate S Informant!? {Movimiento interesante}
 translate S Informant? {Movimiento malo}
 translate S Informant?? {Desastroso}
@@ -740,7 +707,7 @@ translate S Informant?! {Movimiento dudoso}
 translate S Informant+= {Blancas tienen una ligera ventaja}
 translate S Informant+/- {Blancas tienen ventaja}
 translate S Informant+- {Blancas tienen una ventaja decisiva}
-translate S Informant++- {La partida es considerada ganada}
+translate S Informant+-- {La partida es considerada ganada}
 translate S Book {Libro}
 translate S OtherBookMoves {Otros movimientos del libro}
 translate S OtherBookMovesTooltip {Movimientos para los que el oponente tiene una respuesta}
@@ -756,12 +723,28 @@ translate S EngineTime {Fecha}
 translate S EngineNew {Nuevo}
 translate S EngineEdit {Editar}
 translate S EngineRequired {Los campos en negrita son obligatorios; los dems opcionales}
-
-# Stats window menus:
-menuText S StatsFile "Archivo" 0
-menuText S StatsFilePrint "Imprimir en archivo..." 0
-menuText S StatsFileClose "Cerrar ventana" 0
-menuText S StatsOpt "Opciones" 0
+# ====== TODO To be translated ======
+translate S EngineProtocol {Communication protocol}
+# ====== TODO To be translated ======
+translate S EngineNotation {Notation of the moves}
+# ====== TODO To be translated ======
+translate S EngineFlipEvaluation {Flip evaluation perspective}
+# ====== TODO To be translated ======
+translate S EngineShowLog {Show communication log}
+# ====== TODO To be translated ======
+translate S EngineNetworkd {Accept remote connections}
+# ====== TODO To be translated ======
+translate S EngineSelect {Select the current engine}
+# ====== TODO To be translated ======
+translate S EngineAddLocal {Add a local engine}
+# ====== TODO To be translated ======
+translate S EngineAddRemote {Add a remote engine}
+# ====== TODO To be translated ======
+translate S EngineReload {Reload the current engine}
+# ====== TODO To be translated ======
+translate S EngineClone {Create a copy of the current engine}
+# ====== TODO To be translated ======
+translate S EngineDelete {Delete the current engine}
 
 # PGN window menus:
 menuText S PgnFile "Archivo" 0
@@ -1077,6 +1060,10 @@ translate S WhiteClearAdvantage {Las blancas tienen clara ventaja}
 translate S BlackClearAdvantage {Las negras tienen clara ventaja}
 translate S WhiteSlightAdvantage {Las blancas tienen ligera ventaja}
 translate S BlackSlightAdvantage {Las negras tienen ligera ventaja}
+# ====== TODO To be translated ======
+translate S WhiteCrushing {White has a crushing advantage}
+# ====== TODO To be translated ======
+translate S BlackCrushing {Black has a crushing advantage}
 translate S Equality {Igualdad}
 translate S Unclear {Incierto}
 translate S Diagram {Diagrama}
@@ -1383,6 +1370,8 @@ translate S ExportStripMarks {Quitar marca de cdigos de casilla/flecha de los co
 # Goto game/move dialogs:
 translate S LoadGameNumber {Escribe el nmero de la partida a cargar:}
 translate S GotoMoveNumber {Ir al movimiento nmero:}
+# ====== TODO To be translated ======
+translate S CopyAllGames {Copy all games to}
 
 # Copy games dialog:
 translate S CopyGames {Copiar partidas}
@@ -1424,6 +1413,7 @@ translate S SoundsAnnounceOptions {Opciones de anunciamiento de movimientos}
 translate S SoundsAnnounceNew {Anunciar nuevos movimientos cuando sean hechos}
 translate S SoundsAnnounceForward {Anunciar movimientos cuando avancemos un movimiento}
 translate S SoundsAnnounceBack {Anunciar movimiento cuando rectifiquemos o retrocedamos una jugada}
+translate S SoundsSoundDisabled {Scid no pudo encontrar el paquete de audio de Snack al inicio.\nEl sonido est desactivado.}
 
 # Upgrading databases:
 translate S Upgrading {Actualizacin}
@@ -1661,6 +1651,22 @@ translate S FICSdefaultuservars {Usa valores por defecto}
 translate S FICSObserveconfirm {Quieres observar la partida}
 # ====== TODO To be translated ======
 translate S FICSpremove {Enable premove}
+# ====== TODO To be translated ======
+translate S FICSObserve {Observe}
+# ====== TODO To be translated ======
+translate S FICSRatedGames {Rated Games}
+# ====== TODO To be translated ======
+translate S FICSUnratedGames {Unrated Games}
+# ====== TODO To be translated ======
+translate S FICSRated {Rated}
+# ====== TODO To be translated ======
+translate S FICSUnrated {Unrated}
+# ====== TODO To be translated ======
+translate S FICSRegisteredPlayer {Registered player only}
+# ====== TODO To be translated ======
+translate S FICSFreePlayer {Free player only}
+# ====== TODO To be translated ======
+translate S FICSNetError {Network error\nCan't connect to }
 translate S GameReview {Revisin de partida}
 translate S GameReviewTimeExtended {Tiempo extendido}
 translate S GameReviewMargin {Margen de error}
@@ -1680,72 +1686,11 @@ translate S GameReviewNotEngineMoveButGoodMove {No es el movimiento del motor, p
 translate S GameReviewMoveNotGood {Este movimiento no es bueno, la puntuacin es }
 translate S GameReviewMovesPlayedLike {Movimientos jugados como}
 translate S GameReviewMovesPlayedEngine {Movimientos jugados como motor}
-translate S CCDlgConfigureWindowTitle {Configurar Ajedrez por correo}
 translate S CCDlgCGeneraloptions {Opciones generales}
-translate S CCDlgDefaultDB {Base por defecto:}
-translate S CCDlgInbox {Entrante (Carpeta):}
-translate S CCDlgOutbox {Saliente (carpeta):}
-translate S CCDlgXfcc {Configuracin Xfcc:}
-translate S CCDlgExternalProtocol {Protocolo externo (e.g. Xfcc)}
-translate S CCDlgFetchTool {Herramienta de traer:}
-translate S CCDlgSendTool {Herramienta de envo:}
-translate S CCDlgEmailCommunication {Comunicacin email}
-translate S CCDlgMailPrg {Programa de correo:}
-translate S CCDlgBCCAddr {(B)CC Direccin:}
-translate S CCDlgMailerMode {Modo:}
-translate S CCDlgThunderbirdEg {p.e. Thunderbird, Mozilla Mail, Icedove...}
-translate S CCDlgMailUrlEg {p.e. Evolution}
-translate S CCDlgClawsEg {p.e. Sylpheed Claws}
-translate S CCDlgmailxEg {p.e. mailx, mutt, nail...}
-translate S CCDlgAttachementPar {Parmetro Adjunto (Attachment):}
-translate S CCDlgInternalXfcc {Usar soporte interno Xfcc}
-translate S CCDlgConfirmXfcc {Confirmar jugadas}
-translate S CCDlgSubjectPar {Parmetro Sujeto (Subject):}
-translate S CCDlgDeleteBoxes {Vaciar Entrante/Saliente}
-translate S CCDlgDeleteBoxesText {Quieres realmente vaciar tus carpetas Entrante y Saliente para Ajedrez por correspondencia? Esto requiere una nueva sincronizacin para mostrar el estado ltimo de tus partidas}
-translate S CCDlgConfirmMove {Confirmar jugada}
-translate S CCDlgConfirmMoveText {Si t confirmas, la siguiente jugada y comentario ser enviado al servidor:}
-translate S CCDlgDBGameToLong {Lnea principal inconsistente}
-translate S CCDlgDBGameToLongError {La lnea principal en tu base es ms larga que de la partida en la bandeja de entrada. Si la bandeja de entrada contiene la partida actual, algunos movimientos fueron aadidos a la lnea principal en la base errneamente.\nEn este caso acorte la lnea principal a la (max) jugada\n}
-translate S CCDlgStartEmail {Empezar nueva partida por email}
-translate S CCDlgYourName {Tu nombre:}
-translate S CCDlgYourMail {Tu direccin email:}
-translate S CCDlgOpponentName {Nombre de oponente:}
-translate S CCDlgOpponentMail {Direccin email de oponente:}
-translate S CCDlgGameID {Partida ID (nico):}
-translate S CCDlgTitNoOutbox {Scid: Salida del Correo de Ajedrez}
-translate S CCDlgTitNoInbox {Scid: Entrada del Correo de Ajedrez}
-translate S CCDlgTitNoGames {Scid: No hay partidas de Ajedrez por Correo}
-translate S CCErrInboxDir {Carpeta de entrada del Correo de Ajedrez (Entrante):}
-translate S CCErrOutboxDir {Carpeta de salida del Correo de Ajedrez (Saliente):}
-translate S CCErrDirNotUsable {No existe o no est accesible!\nPor favor, compruebe y corrija los parmetros.}
-translate S CCErrNoGames {No contiene ninguna partida!\nPor favor, trigala primero.}
-translate S CCDlgTitNoCCDB {Scid: No es una Base de Ajedrez por Correo}
-translate S CCErrNoCCDB {No hay una Base del tipo 'Correo' abierta. Por favor, abra una antes de usar funciones de ajedrez por correo.}
-translate S CCFetchBtn {Traer partidas desde el servidor y procesar correo entrante}
-translate S CCPrevBtn {Ir a partida anterior}
-translate S CCNextBtn {Ir a partida siguiente}
-translate S CCSendBtn {Enviar movimiento}
-translate S CCEmptyBtn {Correos entrante y saliente vacos}
-translate S CCHelpBtn {Ayuda en iconos e indicadores de estatus. \n Para ayuda general, pulse F1}
-translate S CCDlgServerName {Nombre del servidor:}
 translate S CCDlgLoginName  {Nombre de registro:}
 translate S CCDlgPassword   {Contrasea:}
 # ====== TODO To be translated ======
 translate S CCDlgShowPassword {Show password}
-translate S CCDlgURL        {Xfcc-URL:}
-translate S CCDlgRatingType {Tipo de puntuacin (Rating):}
-translate S CCDlgDuplicateGame {El ID de la partida no es nico}
-translate S CCDlgDuplicateGameError {Esta partida existe ms de una vez en tu base. Por favor, borra todos los duplicados y compacta tu fichero de partidas (Fichero/Mantenimiento/Compactar base de datos).}
-translate S CCDlgSortOption {Ordenando:}
-translate S CCDlgListOnlyOwnMove {Slo partidas que tienen el movimiento}
-translate S CCOrderClassicTxt {Lugar, Evento, Ronda, Resultado, Blancas, Negras}
-translate S CCOrderMyTimeTxt {Mi reloj}
-translate S CCOrderTimePerMoveTxt {Tiempo por movimiento falta el prximo control de tiempo}
-translate S CCOrderStartDate {Empezar fecha}
-translate S CCOrderOppTimeTxt {Reloj de los oponentes}
-translate S CCDlgConfigRelay {Configurar observaciones ICCF}
-translate S CCDlgConfigRelayHelp {Ir a las partidas de la pgina en http://www.iccf-webchess.com y mostrar la partida a ser observada. Si tu ves el tablero de ajedrez copia la URL desde tu explorador a la lista. !Una sola URL por lnea!\nExample: http://www.iccf-webchess.com/MakeAMove.aspx?id=266452}
 translate S ExtHWConfigConnection {Configurar hardware externo}
 translate S ExtHWPort {Puerto}
 translate S ExtHWEngineCmd {Comando del motor}
@@ -1839,6 +1784,24 @@ translate S MakeCorrections {Make Corrections}
 translate S Surnames {Surnames}
 # ====== TODO To be translated ======
 translate S Ambiguous {Ambiguous}
-
+translate S OptionsToolbar "Barra de herramientas ventana principal"
+translate S OptionsBoard "Tablero"
+# ====== TODO To be translated ======
+translate S OptionsMenuColor "Menu colors"
+translate S OptionsBoardSize "Tamao del tablero"
+translate S OptionsBoardPieces "Estilo de piezas"
+# ====== TODO To be translated ======
+translate S OptionsInternationalization "Internationalization"
+# ====== TODO To be translated ======
+translate S MenuColorForeground "Textcolor"
+# ====== TODO To be translated ======
+translate S MenuColorBackground "Background"
+# ====== TODO To be translated ======
+translate S MenuColorSelect "Select"
+translate S OptionsTablebaseDir "Seleccione hasta 4 carpetas de la tablas de finales:"
+# ====== TODO To be translated ======
+translate S BestMoveArrow "Best move arrow"
+# ====== TODO To be translated ======
+translate S NewLocalEngine "+ New engine ..."
 }
 # end of spanish.tcl
