@@ -122,6 +122,8 @@ menuText U EditCopyBoard "Kopioi asema" 0 \
   {Kopioi nykyinen asema leikepydlle FEN-muodossa}
 menuText U EditPasteBoard "Liit asema" 0 \
   {Liit leikepydll oleva FEN-teksti alkuasemaksi}
+# ====== TODO To be translated ======
+menuText U ConfigureScid "Preferences..." 0 {Configure all options for SCID}
 
 # Game menu:
 menuText U Game "Peli" 0
@@ -178,12 +180,13 @@ menuText U WindowsCorrChess "Kirjeshakki" 6 {Avaa/sulje kirjeshakki-ikkuna}
 
 # Tools menu:
 menuText U Tools "Tykalut" 1
+# ====== TODO To be translated ======
+menuText U ToolsConfigureEngines "Configure Engines" 10 {Manage engines' configuration}
 menuText U ToolsAnalysis "Analyysimoottori #1..." 18 \
   {Kynnist/pysyt analyysimoottori}
 menuText U ToolsAnalysis2 "Analyysimoottori #2..." 18 \
   {Kynnist/pysyt toinen analyysimoottori}
 menuText U ToolsCross "Ristitaulukko" 0 {Nyt turnauksen ristitaulukko tlle pelille}
-menuText U ToolsEmail "Email" 0 {Avaa/sulje email-shakin hallintaikkuna}
 menuText U ToolsFilterGraph "Suhteellinen graafi" 13 {Avaa/sulje suodatingraafi suhteellisilla arvoilla}
 menuText U ToolsAbsFilterGraph "Absoluuttinen graafi" 17 {Avaa/sulje suodatingraafi absoluuttisilla arvoilla}
 menuText U ToolsOpReport "Avausraportti" 0 {Luo nykyisest asemasta avausraportti}
@@ -242,35 +245,17 @@ menuText U ToolsCaptureBoard "Kuvakaappaus asemasta..." 1  {Tallenna asema kuvan
 menuText U Play "Pelaa" 0
 
 # --- Correspondence Chess
-menuText U CorrespondenceChess "Kirjeshakki" 0 {Toiminnot shkposti- ja Xfcc-pohjaista kirjeshakkia varten}
-menuText U CCConfigure "Asetukset" 0 {Mrit ohjelmat ja tee kirjeshakkiin liittyvt asetukset}
-menuText U CCConfigRelay "Seuraa pelej..." 12 {Seurattavien pelien asetukset}
-menuText U CCOpenDB "Avaa tietokanta" 1 {Avaa kirjeshakin oletustietokanta}
-menuText U CCRetrieve "Nouda pelit" 0 {Hae pelit ulkoisella (Xfcc-) avustajalla}
-menuText U CCInbox "Ksittele Saapuneet" 1 {Ksittele kaikki saapuneet tiedostot}
-menuText U CCSend "Lhet siirto" 2 {Lhet siirtosi shkpostina tai (Xfcc-) avustajalla}
 
 menuText U CCResign "Luovuta" 0 {Luovuta (ei shkposti)}
 menuText U CCClaimDraw "Vaadi tasapeli" 0 {Lhet siirto ja vaadi tasapeli (ei shkposti)}
-menuText U CCOfferDraw "Tarjoa tasapeli" 2 {Lhet siirto ja ehdota tasapeli (ei shkposti)}
-menuText U CCAcceptDraw "Hyvksy tasapeli" 1 {Hyvksy vastustajan tarjoama tasapeli (ei shkposti)}
 
-menuText U CCNewMailGame "Uusi shkpostipeli" 0 {Aloita uusi shkpostipeli}
-menuText U CCMailMove "Shkpostisiirto" 0 {Lhet siirto shkpostilla vastustajalle}
-menuText U CCGamePage "Pelisivusto" 0 {Avaa pelisivusto selaimessa}
 
 # menu in cc window:
-menuText U CCEditCopy "Kopioi pelilista leikekantaan" 0 {Kopioi pelit leikekantaan CSV-tiedostona (pilkuilla erotettu teksti)}
 
 #  B    GHiJKL    Q  TUV XYZ
 
 # Options menu:
 menuText U Options "Asetukset" 0
-menuText U OptionsBoard "Shakkilauta" 0 {Shakkilaudan ulkonkn liittyvt asetukset}
-menuText U OptionsBoardSize "Koko" 0 {Muuta laudan kokoa}
-menuText U OptionsBoardPieces "Nappulat" 0 {Muuta nappuloiden ulkomuotoa}
-menuText U OptionsBoardColors "Vrit" 0 {Vaihda laudan vrej}
-#Klimmek
 menuText U OptionsBoardGraphics "Ruudut" 0 {Valitse ruuduissa kytettv tekstuuri}
 translate U OptionsBGW {Valitse ruuduissa kytettv tekstuuri}
 translate U OptionsBoardGraphicsText {Valitse ruuduissa kytettv grafiikkatiedosto:}
@@ -291,8 +276,6 @@ menuText U OptionsMovesHighlightLastMoveWidth "Viiva" 0 {Laudalla nytettvn viiva
 menuText U OptionsMovesHighlightLastMoveColor "Vri" 0 {Laudalla nytettvn viivan vri}
 menuText U OptionsMovesHighlightLastMoveArrow "Sis. nuoli" 0 {Korostettuun siirtoon sisllytetn nuoli}
 menuText U OptionsMoves "Siirrot" 0 {Siirtojen syttmiseen liittyvt asetukset}
-menuText U OptionsMovesAsk "Kysy ennen korvaamista" 0 \
-  {Ohjelma kysyy luvan ennen kuin kirjoittaa vanhojen tietojen plle}
 menuText U OptionsMovesAnimate "Animaation nopeus" 1 \
   {Siirtojen animoinnin nopeus}
 menuText U OptionsMovesDelay "Toiston siirtonopeus" 1 \
@@ -309,20 +292,16 @@ menuText U OptionsMovesShowVarArrows "Muunnelmat nuolin" 0 {Nyt/l nyt muunnelmia
 # ====== TODO To be translated ======
 menuText U OptionsMovesGlossOfDanger "Color Coded Gloss of Danger" 0 {Turn on/off color coded gloss of danger}
 menuText U OptionsNumbers "Numerointi" 0 {Numeroformaatit, 1-3 desimaalipisteell, 4-6 -pilkulla}
-menuText U OptionsStartup "Kynnistys" 0 {Valitse lisikkunat, jotka avataan ohjelmaa kynnistettess}
 menuText U OptionsTheme "Teema" 0 {Valitse kyttliittymn teema}
 menuText U OptionsWindows "Ikkunat" 0 {Ikkunoiden asetukset}
-menuText U OptionsWindowsIconify "Pienenn automaattisesti" 0 \
-  {Pienenn mys muut ikkunat, kun pikkuna pienennetn}
-menuText U OptionsWindowsRaise "Nosta automaattisesti" 0 \
-  {Nosta ert ikkunat automaattisesti ylimmksi}
 menuText U OptionsSounds "net" 0 {Muokaa siirtoilmoitusni}
+# ====== TODO To be translated ======
+menuText U OptionsResources "Resources..." 0 {Choose resource files and folders}
 menuText U OptionsWindowsDock "Telakoi ikkunat" 0 {Telakoi irti olevat ikkunat (vaatii uudelleenkynnistyksen)}
 menuText U OptionsWindowsSaveLayout "Tallenna layout" 0 {Tallenna nimelle ikkunoiden ja tykalupalkkien sijainti}
 menuText U OptionsWindowsRestoreLayout "Palauta layout" 0 {Palauta tallennettu layout}
 menuText U OptionsWindowsShowGameInfo "Pelin tiedot" 0 {Nyt/piilota pelin tiedot (pelaajanimet, turnaus...)}
 menuText U OptionsWindowsAutoLoadLayout "Ensimminen layout automaattisesti" 0 {Lataa ensimminen tallennettu layout automaattisesti}
-menuText U OptionsToolbar "Tykalupalkki" 0 {Muokkaa pikkunan tykalupalkkia}
 menuText U OptionsECO "Lataa ECO-tiedosto" 7 {Lataa ECO avausluokittelu tiedostosta}
 menuText U OptionsSpell "Lataa oikeinkirjoitustiedosto" 0 \
   {Lataa Scidin oikeinkirjoitustiedosto}
@@ -332,20 +311,12 @@ menuText U OptionsRecent "Viimeaikaiset tiedostot" 0 {Kuinka monta tiedostoa nyt
 menuText U OptionsBooksDir "Avauskirjat" 0 {Hakemisto, jossa avauskirjat sijaitsevat}
 menuText U OptionsTacticsBasesDir "Taktiikkakannat" 0 {Hakemisto, jossa taktiikka (harjoitus) tietokannat sijaitsevat}
 # ====== TODO To be translated ======
-menuText U OptionsPhotosDir "Photos directory..." 0 {Sets the photos bases directory}
+menuText U OptionsPhotosDir "Photos directory" 0 {Sets the photos bases directory}
 # ====== TODO To be translated ======
-menuText U OptionsThemeDir "Load Theme(s)..."  0 { Load a GUI theme package file }
+menuText U OptionsThemeDir "Theme(s) File:"  0 { Load a GUI theme package file }
 menuText U OptionsSave "Tallenna asetukset" 0 "Tallenna kaikki asetukset tiedostoon $::optionsFile"
 menuText U OptionsAutoSave "Automaattinen asetusten tallennus" 0 \
   {Tallenna asetukset automaattisesti ohjelmasta poistuttaessa}
-# ====== TODO To be translated ======
-menuText U OptionsMenuColor "Setup Menu Colors..." 0 { }
-# ====== TODO To be translated ======
-translate U MenuColorForeground "Textcolor"
-# ====== TODO To be translated ======
-translate U MenuColorBackground "Background"
-# ====== TODO To be translated ======
-translate U MenuColorSelect "Select"
 
 # Help menu:
 menuText U Help "Ohje" 0
@@ -385,6 +356,8 @@ translate U Defaults {Oletukset}
 translate U Delete {Poista}
 translate U Graph {Graafi}
 translate U Help {Ohje}
+# ====== TODO To be translated ======
+translate U Hide {Hide}
 translate U Import {Tuo}
 translate U Index {Hakemisto}
 translate U LoadGame {Lataa peli}
@@ -485,6 +458,8 @@ translate U PInfoMostBlack {Yleisimmt avaukset: Musta}
 translate U PInfoRating {Vahvuuslukuhistoria}
 translate U PInfoBio {Biografia}
 translate U PInfoEditRatings {Muokkaa vahvuuslukuja}
+# ====== TODO To be translated ======
+translate U PInfoEloFile {File}
 
 # Tablebase information:
 translate U Draw {Tasapeli}
@@ -523,6 +498,8 @@ translate U AllLoss {" Whoever moves loses:     " }
 # Tip of the day:
 translate U Tip {Vihje}
 translate U TipAtStartup {Kynnistysvihje}
+# ====== TODO To be translated ======
+translate U TipConvertPGN {You can get better performance by converting PGN files}
 
 # Tree window menus:
 menuText U TreeFile "Tiedosto" 0
@@ -675,6 +652,10 @@ menuText U GraphOptionsWhite "Valkea" 0
 menuText U GraphOptionsBlack "Musta" 0
 menuText U GraphOptionsBoth "Molemmat" 1
 menuText U GraphOptionsPInfo "Pelaaja Info pelaaja" 0
+# ====== TODO To be translated ======
+menuText U GraphOptionsEloFile "Elo from rating file" 0
+# ====== TODO To be translated ======
+menuText U GraphOptionsEloDB "Elo from database" 0
 translate U GraphFilterTitle "Graafi: yleisyys per 1000 peli"
 translate U GraphAbsFilterTitle "graafi: pelien yleisyys"
 translate U ConfigureFilter "Muokkaa X-akseli; vuosi, vahvuus, siirrot"
@@ -706,7 +687,7 @@ translate U BlundersThreshold {Virhekynnys}
 translate U ScoreAllMoves {Pisteyt kaikki siirrot}
 translate U LowPriority {Matala CPUn kyttaste}
 translate U ClickHereToSeeMoves {Klikkaa nhdksesi siirrot}
-translate U ConfigureInformant {Tee Informant-asetukset}
+translate U ConfigureInformant {Informant-asetukset}
 translate U Informant!? {Mielenkiintoinen siirto}
 translate U Informant? {Heikko siirto}
 translate U Informant?? {Virhe}
@@ -714,7 +695,7 @@ translate U Informant?! {Epilyttv siirto}
 translate U Informant+= {Valkean pieni etu}
 translate U Informant+/- {Valkean etu}
 translate U Informant+- {Valkean ratkaiseva etu}
-translate U Informant++- {Voittoasema}
+translate U Informant+-- {Voittoasema}
   
 # Book window
 translate U Book {Kirja}
@@ -732,12 +713,28 @@ translate U EngineTime {Pvm}
 translate U EngineNew {Uusi}
 translate U EngineEdit {Muokkaa}
 translate U EngineRequired {Lihavoidut kentt ovat pakollisia}
-
-# Stats window menus:
-menuText U StatsFile "Tiedosto" 0
-menuText U StatsFilePrint "Tulosta tiedostoon..." 1
-menuText U StatsFileClose "Sulje ikkuna" 0
-menuText U StatsOpt "Asetukset" 0
+# ====== TODO To be translated ======
+translate U EngineProtocol {Communication protocol}
+# ====== TODO To be translated ======
+translate U EngineNotation {Notation of the moves}
+# ====== TODO To be translated ======
+translate U EngineFlipEvaluation {Flip evaluation perspective}
+# ====== TODO To be translated ======
+translate U EngineShowLog {Show communication log}
+# ====== TODO To be translated ======
+translate U EngineNetworkd {Accept remote connections}
+# ====== TODO To be translated ======
+translate U EngineSelect {Select the current engine}
+# ====== TODO To be translated ======
+translate U EngineAddLocal {Add a local engine}
+# ====== TODO To be translated ======
+translate U EngineAddRemote {Add a remote engine}
+# ====== TODO To be translated ======
+translate U EngineReload {Reload the current engine}
+# ====== TODO To be translated ======
+translate U EngineClone {Create a copy of the current engine}
+# ====== TODO To be translated ======
+translate U EngineDelete {Delete the current engine}
 
 # PGN window menus:
 menuText U PgnFile "Tiedosto" 0
@@ -1023,6 +1020,10 @@ translate U WhiteClearAdvantage {Valkealla on selv etu}
 translate U BlackClearAdvantage {Mustalla on selv etu}
 translate U WhiteSlightAdvantage {Valkealla on hieman etua}
 translate U BlackSlightAdvantage {Mustalla on hieman etua}
+# ====== TODO To be translated ======
+translate U WhiteCrushing {White has a crushing advantage}
+# ====== TODO To be translated ======
+translate U BlackCrushing {Black has a crushing advantage}
 translate U Equality {Tasa-asema}
 translate U Unclear {Epselv}
 translate U Diagram {Kaavio}
@@ -1330,6 +1331,8 @@ translate U ExportStripMarks {Poista ruutu-/nuolimerkit kommenteista?}
 # Goto game/move dialogs:
 translate U LoadGameNumber {Ladattavan pelin numero:}
 translate U GotoMoveNumber {Siirry siirtoon nro:}
+# ====== TODO To be translated ======
+translate U CopyAllGames {Copy all games to}
 
 # Copy games dialog:
 translate U CopyGames {Kopioi pelit}
@@ -1371,6 +1374,8 @@ translate U SoundsAnnounceOptions {Siirtoilmoitusasetukset}
 translate U SoundsAnnounceNew {Ilmoita uudet siirrot}
 translate U SoundsAnnounceForward {Ilmoita, kun siirrytn eteenpin yksi siirto}
 translate U SoundsAnnounceBack {Ilmoita, kun siirrytn taaksepin yksi siirto}
+# ====== TODO To be translated ======
+translate U SoundsSoundDisabled {Scid could not find the Snack audio package at startup;\nSound is disabled.}
 
 # Upgrading databases:
 translate U Upgrading {Pivitys}
@@ -1610,6 +1615,22 @@ translate U FICSConnect {yhdist}
 translate U FICSdefaultuservars {Kyt oletusmuuttujia}
 translate U FICSObserveconfirm {Haluatko seurata peli}
 translate U FICSpremove {Ennakkosiirto plle}
+# ====== TODO To be translated ======
+translate U FICSObserve {Observe}
+# ====== TODO To be translated ======
+translate U FICSRatedGames {Rated Games}
+# ====== TODO To be translated ======
+translate U FICSUnratedGames {Unrated Games}
+# ====== TODO To be translated ======
+translate U FICSRated {Rated}
+# ====== TODO To be translated ======
+translate U FICSUnrated {Unrated}
+# ====== TODO To be translated ======
+translate U FICSRegisteredPlayer {Registered player only}
+# ====== TODO To be translated ======
+translate U FICSFreePlayer {Free player only}
+# ====== TODO To be translated ======
+translate U FICSNetError {Network error\nCan't connect to }
 
 # Game review
 translate U GameReview {Pelin arvioiminen}
@@ -1633,80 +1654,19 @@ translate U GameReviewMovesPlayedLike {Siirrot kuin}
 translate U GameReviewMovesPlayedEngine {Siirrot kuin moottorilla}
 
 # Correspondence Chess Dialogs:
-translate U CCDlgConfigureWindowTitle {Kirjeshakkiasetukset}
 translate U CCDlgCGeneraloptions {Yleiset}
-translate U CCDlgDefaultDB {Oletustietokanta:}
-translate U CCDlgInbox {Inbox/Saapuneet (polku):}
-translate U CCDlgOutbox {Outbox/Lhtevt (polku):}
-translate U CCDlgXfcc {Xfcc-asetukset:}
-translate U CCDlgExternalProtocol {Ulkoisten protokollien ksittelij (esim. Xfcc)}
-translate U CCDlgFetchTool {Noutotykalu:}
-translate U CCDlgSendTool {Lhetystykalu:}
-translate U CCDlgEmailCommunication {eMail}
-translate U CCDlgMailPrg {eMail-ohjelma:}
-translate U CCDlgBCCAddr {(B)CC-osoite:}
-translate U CCDlgMailerMode {Moodi:}
-translate U CCDlgThunderbirdEg {esim. Thunderbird, Mozilla Mail, Icedove...}
-translate U CCDlgMailUrlEg {esim. Evolution}
-translate U CCDlgClawsEg {esim. Sylpheed Claws}
-translate U CCDlgmailxEg {esim. mailx, mutt, nail...}
-translate U CCDlgAttachementPar {Liiteparametrit:}
-translate U CCDlgInternalXfcc {Kyt sisnrakennettua tukea Xfcc:lle}
-translate U CCDlgConfirmXfcc {Vahvista siirrot}
-translate U CCDlgSubjectPar {Otsikko:}
-translate U CCDlgDeleteBoxes {Tyhjenn In-/Outbox}
-translate U CCDlgDeleteBoxesText {Haluatko varmasti tyhjent Saapuneet ja Lhetetyt?\nTyhjennykse jlkeen sinun tytyy synkronoida nhdksesi tmnhetkiset asemat.}
-translate U CCDlgConfirmMove {Vahvista siirto}
-translate U CCDlgConfirmMoveText {Jos vahvistat, seuraava siirto kommentteineen lhetetn palvelimelle:}
-translate U CCDlgDBGameToLong {Epyhteninen pmuunnelma}
-translate U CCDlgDBGameToLongError {Pmuunnelma on pidempi kuin peli Saapuneet-kansiossa (Inbox). Mikli Saapuneet on ajan tasalla, on pelin pmuunnelmaan listty vahingossa siirtoja.\nLyhenn pmuunnelma ainakin siirtoon \n}
 
 
-translate U CCDlgStartEmail {Aloita uusi eMail-peli}
-translate U CCDlgYourName {Nimi:}
-translate U CCDlgYourMail {eMail-osoite:}
-translate U CCDlgOpponentName {Vastustajan nimi:}
-translate U CCDlgOpponentMail {Vastustajan eMail-osoite:}
-translate U CCDlgGameID {Peli ID (yksilllinen):}
 
-translate U CCDlgTitNoOutbox {Scid: Kirjeshakki - Lhtevt (Outbox)}
-translate U CCDlgTitNoInbox {Scid: Kirjeshakki - Saapuneet (Inbox)}
-translate U CCDlgTitNoGames {Scid: Ei kirjeshakkipelej}
-translate U CCErrInboxDir {Kirjeshakki - Saapuneet-hakemisto:}
-translate U CCErrOutboxDir {Kirjeshakki - Lhtevt-hakemisto:}
-translate U CCErrDirNotUsable {ei ole olemassa tai siihen ei saada yhteytt!\nTarkista ja korjaa asetukset.}
-translate U CCErrNoGames {ei sill pelej!\nNouda pelit ensin.}
 
-translate U CCDlgTitNoCCDB {Scid: Ei kirjeshakkitietokantaa}
-translate U CCErrNoCCDB {Ei lydy avointa 'Kirjeshakki (Correspondence)' tyyppist tietokantaa. Avaa ainakin yksi kirjeshakkikanta ennen kirjeshakkitoimintojen kytt.}
 
-translate U CCFetchBtn {Nouda pelit serverilt ja prosessoi Saapuneet (Inbox)}
-translate U CCPrevBtn {Edelliseen peliin}
-translate U CCNextBtn {Seuraavaan peliin}
-translate U CCSendBtn {Lhet siirto}
-translate U CCEmptyBtn {Tyhjenn Saapuneet ja Lhetetyt}
-translate U CCHelpBtn {Apua kuvakkeiden ja statussanomien tulkintaan.\nYleisemp apua saa painamalla F1!}
 
-translate U CCDlgServerName {Serverin nimi:}
 translate U CCDlgLoginName  {Kyttjtunnus:}
 translate U CCDlgPassword   {Salasana:}
 # ====== TODO To be translated ======
 translate U CCDlgShowPassword {Show password}
-translate U CCDlgURL        {Xfcc-URL:}
-translate U CCDlgRatingType {Vahvuuslukutyyppi:}
 
-translate U CCDlgDuplicateGame {Ei-yksilllinen peli-ID}
-translate U CCDlgDuplicateGameError {Tm peli lytyy useammasta kuin yhdest tietokannastasi. Poista tuplat ja tiivist tietokantasi (Tiedosto/Yllpito/Tiivist kanta).}
 
-translate U CCDlgSortOption {Lajittelu:}
-translate U CCDlgListOnlyOwnMove {Vain ne, joissa olen siirtovuorossa}
-translate U CCOrderClassicTxt {Paika, Tapahtuma, Kierros, Tulos, Valkea, Musta}
-translate U CCOrderMyTimeTxt {Kelloni}
-translate U CCOrderTimePerMoveTxt {Aikaa per siirto ennen seuraavaa ajantarkastusta}
-translate U CCOrderStartDate {Aloituspvm.}
-translate U CCOrderOppTimeTxt {Vastustajan kello}
-translate U CCDlgConfigRelay {Seuraa pelej}
-translate U CCDlgConfigRelayHelp {Siirry sivulle http://www.iccf-webchess.com ja nyt seurattava peli.  Jos net shakkilaudan, kopioi osoite selaimestasi URL alla olevaan listaan. Vain yksi osoite per rivi!\nEsim: http://www.iccf-webchess.com/MakeAMove.aspx?id=266452}
 
 # Connect Hardware dialogs
 translate U ExtHWConfigConnection {Ulkoisten laitteiden asetukset}
@@ -1810,6 +1770,25 @@ translate U MakeCorrections {Make Corrections}
 translate U Surnames {Surnames}
 # ====== TODO To be translated ======
 translate U Ambiguous {Ambiguous}
-
+translate U OptionsToolbar "Tykalupalkki"
+translate U OptionsBoard "Shakkilauta"
+# ====== TODO To be translated ======
+translate U OptionsMenuColor "Menu colors"
+translate U OptionsBoardSize "Koko"
+translate U OptionsBoardPieces "Nappulat"
+# ====== TODO To be translated ======
+translate U OptionsInternationalization "Internationalization"
+# ====== TODO To be translated ======
+translate U MenuColorForeground "Textcolor"
+# ====== TODO To be translated ======
+translate U MenuColorBackground "Background"
+# ====== TODO To be translated ======
+translate U MenuColorSelect "Select"
+# ====== TODO To be translated ======
+translate U OptionsTablebaseDir "Select up to 4 table base folders:"
+# ====== TODO To be translated ======
+translate U BestMoveArrow "Best move arrow"
+# ====== TODO To be translated ======
+translate U NewLocalEngine "+ New engine ..."
 }
 # end of suomi.tcl
