@@ -77,7 +77,7 @@ proc moveEntry_Char {ch} {
         # case insensitive to allow for 'b' to match both pawn and
         # Bishop moves.
         set move [string tolower [lindex $moveEntry(List) 0]]
-        
+
         if {$moveEntry(AutoExpand) > 0  ||
             ![string compare [string tolower $moveEntry(Text)] $move]} {
             return [moveEntry_Complete]
@@ -108,6 +108,7 @@ proc updateMainGame {} {
     set gamePlayers(eloB)   [expr {$eloB == 0 ? "" : "($eloB)"}]
     set gamePlayers(clockW) ""
     set gamePlayers(clockB) ""
+    set gamePlayers(movetime) ""
 }
 
 # updateTitle:
@@ -162,23 +163,34 @@ proc updateStatusBar {} {
     # show [%clk] command (if we are not playing)
     set toMove  [sc_pos side]
     set comment [sc_pos getComment]
+    ::board::updateEvalBar .main.board [getScorefromComment $comment 10]
     if { ![gameclock::isRunning] } {
         set ::gamePlayers(clockW) ""
         set ::gamePlayers(clockB) ""
+        set ::gamePlayers(movetime) ""
         set clkExp {.*?\[%clk\s*(.*?)\s*\].*}
-        set prevCom [sc_pos getPrevComment]
-        if {$toMove == "white"} {
-            regexp $clkExp $comment -> ::gamePlayers(clockB)
-            regexp $clkExp $prevCom -> ::gamePlayers(clockW)
-        } else {
-            regexp $clkExp $comment -> ::gamePlayers(clockW)
-            regexp $clkExp $prevCom -> ::gamePlayers(clockB)
+        lassign [sc_pos getPrevComment] prevCom movetime
+        regexp $clkExp $comment -> ::gamePlayers(clockW)
+        regexp $clkExp $prevCom -> ::gamePlayers(clockB)
+        regexp $clkExp $movetime -> movetime
+        catch {
+            set movetime [expr {
+                [clock scan $movetime -format {%H:%M:%S}] - \
+                [clock scan $::gamePlayers(clockW) -format {%H:%M:%S}] }]
+            set ::gamePlayers(movetime) [format_clock_from_seconds $movetime]
         }
+        if {$toMove == "white"} {
+            set temp_swap $::gamePlayers(clockW)
+            set ::gamePlayers(clockW) $::gamePlayers(clockB)
+            set ::gamePlayers(clockB) $temp_swap
+        }
+        set ::gamePlayers(clockW) [format_clock $::gamePlayers(clockW)]
+        set ::gamePlayers(clockB) [format_clock $::gamePlayers(clockB)]
     }
 
     if {[info exists ::guessedAddMove]} {
         set ::gameLastMove [lindex $::guessedAddMove 1]
-        ::board::setInfoAlert .main.board [lindex $::guessedAddMove 0] "\[click to change\]" "blue" ".main.menuaddchoice"
+        ::board::setInfoAlert .main.board [lindex $::guessedAddMove 0] "\[click to change\]" "DodgerBlue3" ".main.menuaddchoice"
         unset ::guessedAddMove
         return
     }
@@ -189,20 +201,13 @@ proc updateStatusBar {} {
         foreach thisMove $moveEntry(List) {
             append msg "$thisMove "
         }
-        ::board::setInfoAlert .main.board "Enter Move:" "$msg" "blue" ""
+        ::board::setInfoAlert .main.board "Enter Move:" "$msg" "DodgerBlue3" ""
         return
     }
 
     # remove technical comments, notify only human readable ones
     regsub -all {\[%.*\]} $comment {} comment
 
-    if {$comment != ""} {
-        ::board::setInfoAlert .main.board "Comment:" "$comment" "green" "::makeCommentWin"
-        ::board::addInfo .main.board [sc_game info ECO]
-        return
-    }
-    
-
     set statusBar ""
     set move [sc_game info previousMoveNT]
     if {$move != ""} {
@@ -216,31 +221,49 @@ proc updateStatusBar {} {
         incr number -1
         append number ".."
       }
-      append statusBar "Last move"
+      append statusBar [tr LastMove]
       if {[sc_var level] != 0} { append statusBar " (var)" }
       append statusBar ": $number.$move"
-      ::board::setInfo .main.board "$statusBar"
+      set statusBar [list $statusBar {}]
+      if {$::gamePlayers(movetime) ne ""} {
+        lappend statusBar "   $::gamePlayers(movetime)" header
+      }
+      ::board::setInfo .main.board $statusBar
     } else {
       set msg "[sc_game info date] - [sc_game info event]"
-      ::board::setInfoAlert .main.board "[tr Event]:" $msg "blue" "::crosstab::Open"
+      ::board::setInfoAlert .main.board "[tr Event]:" $msg "DodgerBlue3" "::crosstab::Open"
+    }
+    set eco [sc_game info ECO]
+    ::board::addInfo .main.board $eco
+    if {$comment != ""} {
+        set headermsg ""
+        # If this is the first move, or both movetime and eco are empty,
+        # show only the comment.
+        if {$move eq "" || ($::gamePlayers(movetime) eq "" && $eco eq "")} {
+            set headermsg "[tr Comment]"
+        }
+        ::board::setInfoAlert .main.board $headermsg "$comment" "green" "::makeCommentWin"
     }
-    ::board::addInfo .main.board [sc_game info ECO]
 }
 
 proc updateMainToolbar {} {
   if {[sc_pos isAt start]} {
+    ::board::setButtonCmd .main.board leavevar ""
     ::board::setButtonCmd .main.board back ""
     catch { unset ::gameInfoBar(tb_BD_Start) }
   } else {
+    ::board::setButtonCmd .main.board leavevar "::move::ExitVarOrStart"
     ::board::setButtonCmd .main.board back "::move::Back"
     set ::gameInfoBar(tb_BD_Start) "::move::Start"
   }
   if {[sc_pos isAt end] || [sc_pos isAt vend]} {
     ::board::setButtonCmd .main.board forward ""
+    ::board::setButtonCmd .main.board endvar ""
     catch { unset ::gameInfoBar(tb_BD_End) }
     catch { unset ::gameInfoBar(tb_BD_Autoplay) }
   } else {
     ::board::setButtonCmd .main.board forward "::move::Forward"
+    ::board::setButtonCmd .main.board endvar "::move::EndVar"
     set ::gameInfoBar(tb_BD_End) "::move::End"
     set ::gameInfoBar(tb_BD_Autoplay) "startAutoplay"
   }
@@ -250,17 +273,167 @@ proc updateMainToolbar {} {
     catch { unset ::gameInfoBar(tb_BD_VarPromote) }
     catch { unset ::gameInfoBar(tb_BD_VarLeave) }
     catch { unset ::gameInfoBar(tb_BD_BackToMainline) }
+    ::board::setButtonImg .main.board leavevar tb_BD_BackStart
   } else {
     set ::gameInfoBar(tb_BD_VarDelete) { ::pgn::deleteVar }
     set ::gameInfoBar(tb_BD_VarPromote) { ::pgn::mainVar }
     set ::gameInfoBar(tb_BD_VarLeave) { ::move::ExitVar }
     set ::gameInfoBar(tb_BD_BackToMainline) { while {[sc_var level] != 0} {::move::ExitVar} }
+    ::board::setButtonImg .main.board leavevar tb_BD_exitvar
   }
 
   set ::gameInfoBar(tb_BD_SetupBoard) "setupBoard"
 }
 
+# Update the "tree" filter of databases that have a view (gamelist or tree windows)
+# which depends on the current position.
+proc ::updateTreeFilter {{base ""}} {
+    if { [info exists ::treeFilterUpdating_] } {
+        set ::treeFilterUpdating_ {}
+        ::progressBarCancel
+        return
+    }
 
+    set ::treeFilterUpdating_ {}
+    set ::treeFilterUpdatingBases_ [::windows::gamelist::listTreeBases $base]
+    lappend ::treeFilterUpdatingBases_ {*}[::tree::listTreeBases $base]
+    foreach elem [lsort -unique -index 0 $::treeFilterUpdatingBases_] {
+        lassign $elem base filter progressbar
+
+        set ::treeFilterUpdating_ [lsearch -all -inline -exact -index 0 $::treeFilterUpdatingBases_ $base]
+        if { [llength $::treeFilterUpdating_] == 0 } {
+            # canceled while updating another base
+            continue
+        }
+
+        #TODO: don't do a full database search if there is only one filter.
+        #set n_filters [llength [lsort -unique -index 1 $::treeFilterUpdating_]]
+
+        eval progressBarSet $progressbar
+        set err [catch {sc_filter search $base "tree" board}]
+        if {$err && $::errorCode != $::ERROR::UserCancel} {
+            ERROR::MessageBox
+        }
+        if { [llength $::treeFilterUpdating_] == 0 } {
+            # Restart if the position changed before the update finished.
+            after idle {
+                unset ::treeFilterUpdating_
+                ::updateTreeFilter
+            }
+            return
+        }
+        ::notify::DatabaseModified $base tree
+    }
+    unset ::treeFilterUpdating_
+}
+
+proc ::cancelUpdateTreeFilter {progressbar} {
+    if {![info exists ::treeFilterUpdating_]} {
+        return
+    }
+    set idx [lsearch -exact -index 2 $::treeFilterUpdating_ $progressbar]
+    if {$idx != -1} {
+        if {[llength $::treeFilterUpdating_] == 1} {
+            ::progressBarCancel
+        } else {
+            set ::treeFilterUpdating_ [lreplace $::treeFilterUpdating_ $idx $idx]
+        }
+    } else {
+        set idx [lsearch -exact -index 2 $::treeFilterUpdatingBases_ $progressbar]
+        if {$idx != -1} {
+            set ::treeFilterUpdatingBases_ [lreplace $::treeFilterUpdatingBases_ $idx $idx]
+        }
+    }
+}
+
+# Update the main eval bar to reflect the engine's evaluation.
+# If there is only one engine running, il will show that evaluation in the bar.
+# If there are multiple engines running, the eval bar will remain associated
+# with the first engine that send its evaluation until it stops running.
+proc ::updateMainEvalBar {engineID bestmove evaluation} {
+    if {! $::showEvalBar(.main) || ![winfo exists .main.board]} { return }
+
+    if {![info exists ::mainEvalBarEngineID_]} {
+        set ::mainEvalBarEngineID_ $engineID
+    }
+    if {$engineID == $::mainEvalBarEngineID_} {
+        ::board::updateEvalBar .main.board $evaluation
+        if {$::showMainEvalBarArrow} {
+            set bestmove [string map {"\u2654" K "\u2655" Q "\u2656" R "\u2657" B "\u2658" N} [::untrans $bestmove]]
+            catch { sc_game SANtoUCI $bestmove } moveUCI
+            ::board::mark::DrawBestMove .main.board $moveUCI
+        }
+        if {$bestmove eq "" && $evaluation eq ""} {
+            unset ::mainEvalBarEngineID_
+        }
+    }
+}
+
+# Create a menu containing:
+# - the engine currently associated with the evaluation bar
+# - engines open in enginewin windows
+# - the configured engines that can be started
+# - a command to add a new local engine
+# - a command to show/hide the best move arrow
+# - the command to hide the evaluation bar
+# Behavior:
+# - if the currently associated engine is selected, stop it
+# - if a different engine is selected, stop the current engine and start the new one.
+# Returns the name of the created menu.
+proc ::createMainEvalBarMenu {w} {
+    if {[winfo exists $w.evalbar_menu]} { destroy $w.evalbar_menu }
+    menu $w.evalbar_menu
+
+    set engines {}
+    set enginewins [enginewin::listEngines]
+    foreach {elem} $enginewins {
+        lassign $elem engID engName running
+        if {!$running} {
+            lappend engines [list $engID $engName]
+            continue
+        }
+        if {[info exists ::mainEvalBarEngineID_] && $engID == $::mainEvalBarEngineID_} {
+            set ::mainEvalBarCheckbutton 1
+            $w.evalbar_menu add checkbutton -variable ::mainEvalBarCheckbutton -label $engName -command {
+                ::enginewin::stop $::mainEvalBarEngineID_
+            }
+        } else {
+            $w.evalbar_menu add command -label $engName \
+                -command "set ::mainEvalBarEngineID_ \[::enginewin::start $engID\]"
+        }
+    }
+    foreach {engName} [enginecfg::names] {
+        if {[lsearch -exact -index 1 $enginewins $engName] == -1} {
+            lappend engines [list "" $engName]
+        }
+    }
+    $w.evalbar_menu add separator
+    foreach {elem} $engines {
+        lassign $elem engID engName
+        $w.evalbar_menu add command -label $engName -command [list apply {{engID engName} {
+            if {[info exists ::mainEvalBarEngineID_]} {
+                ::enginewin::stop $::mainEvalBarEngineID_
+            }
+            set ::mainEvalBarEngineID_ [::enginewin::start $engID $engName]
+        }} $engID $engName]
+    }
+
+    $w.evalbar_menu add command -label [tr NewLocalEngine] -command {
+        set newEngName [::enginecfg::dlgNewLocal]
+        if {$newEngName ne ""} {
+            ::enginewin::start "" $newEngName
+        }
+    }
+    $w.evalbar_menu add separator
+    $w.evalbar_menu add checkbutton -variable ::showMainEvalBarArrow -label [tr BestMoveArrow] -command {
+        ::board::mark::DrawBestMove ".main.board" ""
+    }
+    $w.evalbar_menu add separator
+    $w.evalbar_menu add command -label [tr Hide] \
+        -command { {*}$::gameInfoBar(tb_BD_Scorebar) }
+
+    return $w.evalbar_menu
+}
 
 proc toggleRotateBoard {} {
     ::board::flip .main.board
@@ -305,12 +478,12 @@ proc getNextMoves { {num 4} } {
 ################################################################################
 proc showVars {} {
     if {$::autoplayMode == 1} { return }
-    
+
     # No need to display an empty menu
     if {[sc_var count] == 0} {
         return
     }
-    
+
     if {[sc_var count] == 1 &&  [sc_game info nextMove] == ""} {
         # There is only one variation and no main line, so enter it
         sc_var moveInto 0
@@ -320,27 +493,31 @@ proc showVars {} {
 
     set w .variations
     if {[winfo exists $w]} { return }
-    
+
     set varList [sc_var list]
     set numVars [sc_var count]
-    
+
     # Present a menu of the possible variations
     toplevel $w
     ::setTitle $w $::tr(Variations)
     setWinLocation $w
     set h [expr $numVars + 1]
     if { $h> 19} { set h 19 }
-    listbox $w.lbVar -selectmode browse -height $h -width 20
-    pack $w.lbVar -expand yes -fill both -side top
-    
+    ttk::treeview $w.lbVar -columns {0} -show {} -selectmode browse
+    $w.lbVar configure -height $h
+    $w.lbVar column 0 -width 250
+    pack $w.lbVar -side left -fill both -expand 1
+
     #insert main line
     set move [sc_game info nextMove]
+    set j 0
     if {$move == ""} {
         set move "($::tr(empty))"
     } else  {
-        $w.lbVar insert end "0: [getNextMoves 5]"
+        $w.lbVar insert {} end -id $j -values [list "0: [getNextMoves 5]"]
+        incr j
     }
-    
+
     # insert variations
     for {set i 0} {$i < $numVars} {incr i} {
         set move [::trans [lindex $varList $i]]
@@ -352,7 +529,8 @@ proc showVars {} {
             sc_var exit
         }
         set str "[expr {$i + 1}]: $move"
-        $w.lbVar insert end $str
+        $w.lbVar insert {} end -id $j -values [list "$str"]
+        incr j
     }
     $w.lbVar selection set 0
     # bindings
@@ -360,21 +538,22 @@ proc showVars {} {
     bind .variations <Return> {catch { event generate .variations <Right> } }
     bind .variations <ButtonRelease-1> {catch { event generate .variations <Right> } }
     bind .variations <Right> {
-        set cur [.variations.lbVar curselection]
+        set cur [.variations.lbVar selection]
         destroy .variations
         if {$cur == 0} {
-            sc_move forward; updateBoard -animate
+            sc_move forward
         } else  {
-            sc_var moveInto [expr $cur - 1]; updateBoard -animate
+            sc_var moveInto [expr $cur - 1]
         }
+        ::notify::PosChanged "" -animate
     }
-    bind .variations <Up> { set cur [.variations.lbVar curselection] ; .variations.lbVar selection clear $cur
+    bind .variations <Up> { set cur [.variations.lbVar selection]
         set sel [expr $cur - 1]
         if {$sel < 0} { set sel 0 }
         .variations.lbVar selection set $sel ; .variations.lbVar see $sel}
-    bind .variations <Down> { set cur [.variations.lbVar curselection] ; .variations.lbVar selection clear $cur
+    bind .variations <Down> { set cur [.variations.lbVar selection]
+        if {[.variations.lbVar next $cur] == {} } { return }
         set sel [expr $cur + 1]
-        if {$sel >= [.variations.lbVar index end]} { set sel end }
         .variations.lbVar selection set $sel ; .variations.lbVar see $sel}
     bind .variations <Left> { destroy .variations }
     bind .variations <Escape> { catch { event generate .variations <Destroy> } }
@@ -389,7 +568,7 @@ proc showVars {} {
         focus .variations
         raise .variations
     }
-    
+
     # Needed or the main window loses the focus
     bind .variations <Destroy> { focus -force .main }
 
@@ -422,7 +601,7 @@ proc updateGameInfo {} {
     ::htext::display .main.gameInfo.text [sc_game info -hide $gameInfo(hideNextMove) \
             -material $gameInfo(showMaterial) \
             -cfull $gameInfo(fullComment) \
-            -fen $gameInfo(showFEN) -tb $gameInfo(showTB)]
+            -fen $gameInfo(showFEN)]
     if {$gameInfo(wrap)} {
         .main.gameInfo.text configure -wrap word
         .main.gameInfo.text tag configure wrap -lmargin2 10
@@ -461,12 +640,12 @@ proc togglePhotosSize {{toggle 1}} {
 proc readPhotoFile {fname} {
     set count 0
     set writespi 0
-    
+
     if {! [regsub {\.spf$} $fname {.spi} spi]} {
         # How does it happend?
         return
     }
-    
+
     # If SPI file was found then just source it and exit
     if { [file readable $spi]} {
         set count [array size ::unsafe::spffile]
@@ -480,15 +659,15 @@ proc readPhotoFile {fname} {
             set count 0
         }
     }
-    
+
     # Check for the absence of the SPI file and check for the write permissions
     if { ![file exists $spi] && ![catch {open $spi w} fd_spi]} {
         # SPI file will be written to disk by scid
         set writespi 1
     }
-    
+
     if {! [file readable $fname]} { return }
-    
+
     set fd [open $fname]
     while {[gets $fd line] >= 0} {
         # search for the string      photo "Player Name"
@@ -523,7 +702,7 @@ proc readPhotoFile {fname} {
         ::splash::add "Could not generate index file [file tail $spi]"
         ::splash::add "Use spf2spi script to generate [file tail $spi] file "
     }
-    
+
     if { $writespi } { close $fd_spi }
     close $fd
     return $count
@@ -589,7 +768,7 @@ proc trimEngineName { engine } {
         if {$spell_name != ""} { set engine $spell_name }
     }
     set engine [string tolower $engine]
-    
+
     if { [string first "deep " $engine] == 0 } {
         # strip "deep "
         set engine [string range $engine 5 end]
@@ -683,9 +862,6 @@ proc confirmReplaceMove {} {
     if {[winfo exists $::reviewgame::window]} {
         return "var"
     }
-    if {! $::askToReplaceMoves} {
-        return "replace"
-    }
 
     option add *Dialog.msg.wrapLength 4i interactive
     catch {tk_dialog .dialog "Scid: $::tr(ReplaceMove)?" \
@@ -721,7 +897,7 @@ proc addMove { sq1 sq2 {animate "-animate"}} {
     } else {
         set moveUCI [::board::san $sq2][::board::san $sq1]
     }
-    addMoveUCI $moveUCI "" $animate
+    addMoveUCI $moveUCI "var" $animate
 }
 
 proc addSanMove { {san} } {
@@ -735,7 +911,7 @@ proc addSanMove { {san} } {
 #   If the move is a promotion, getPromoPiece will be called
 #   to get the promotion piece from the user.
 #
-proc addMoveUCI {{moveUCI} {action ""} {animate "-animate"}} {
+proc addMoveUCI {{moveUCI} {action "var"} {animate "-animate"}} {
     set sq1 [::board::sq [string range $moveUCI 0 1] ]
     set sq2 [::board::sq [string range $moveUCI 2 3] ]
     if { [::fics::setPremove $sq1 $sq2] || ! [::fics::playerCanMove] || ! [::reviewgame::playerCanMove]} { return } ;# not player's turn
@@ -752,28 +928,13 @@ proc addMoveUCI {{moveUCI} {action ""} {animate "-animate"}} {
     }
 
     if {! $::annotateMode} {
-        if {[::move::Follow $moveUCI]} { return [updateBoard $animate] }
+        if {[::move::Follow $moveUCI]} {
+            ::notify::PosChanged "" $animate
+            return
+        }
     }
 
-
     if {![sc_pos isAt vend]} {
-        if {$action == ""} {
-            set replacedmove ""
-            set n [sc_var count]
-            if {$n == 0} {
-                sc_move forward
-                if {[sc_pos isAt vend]} {
-                    set replacedmove [sc_game info previousMoveNT]
-                }
-                sc_move back
-            }
-            if {$replacedmove != ""} {
-                set ::guessedAddMove [list "Replaced Move $replacedmove"]
-            } else {
-                set action "var"
-            }
-        }
-
         switch -- $action {
             mainline { set ::guessedAddMove [list "New Main Line"]}
             var      { set ::guessedAddMove [list "New Variation"]}
@@ -835,7 +996,7 @@ proc suggestMove {} {
 #   legal move to or from this square), and colors the squares
 #   to indicate the suggested move.
 #
-proc enterSquare { square } {	
+proc enterSquare { square } {
     global bestSq bestcolor selectedSq
     if {$selectedSq == -1} {
         set bestSq -1
@@ -843,7 +1004,7 @@ proc enterSquare { square } {
             set bestSq [sc_pos bestSquare $square]
             if {$bestSq != -1} {
                 ::board::colorSquare .main.board $square $bestcolor
-                ::board::colorSquare .main.board $bestSq $bestcolor        
+                ::board::colorSquare .main.board $bestSq $bestcolor
             }
         }
     }
@@ -857,7 +1018,7 @@ proc leaveSquare { square } {
     global selectedSq bestSq
     if {$selectedSq == -1} {
         ::board::colorSquare .main.board $bestSq
-        ::board::colorSquare .main.board $square  
+        ::board::colorSquare .main.board $square
     }
 }
 
@@ -867,15 +1028,15 @@ proc leaveSquare { square } {
 #
 proc pressSquare { square } {
     global selectedSq highcolor
-    
+
     if { ![::fics::playerCanMove] || ![::reviewgame::playerCanMove] } { return } ;# not player's turn
-    
+
     # if training with calculations of var is on, just log the event
     if { [winfo exists .calvarWin] } {
         ::calvar::pressSquare $square
         return
     }
-    
+
     if {$selectedSq == -1} {
         set selectedSq $square
         ::board::colorSquare .main.board $square $highcolor
@@ -906,9 +1067,9 @@ proc pressSquare { square } {
 #
 proc releaseSquare { w x y } {
     if { [winfo exists .calvarWin] } { return }
-    
+
     global selectedSq bestSq
-    
+
     ::board::setDragSquare $w -1
     set square [::board::getSquare $w $x $y]
     if {$square < 0} {
@@ -939,35 +1100,6 @@ proc releaseSquare { w x y } {
     }
 }
 
-
-# backSquare:
-#    Handles the retracting of a move (when the right mouse button is
-#    clicked on a square). Recolors squares to normal color also.
-#    If the move is the last in the game or variation, is is removed
-#    by truncating the game after retracting the move.
-#
-proc backSquare {} {
-    global selectedSq bestSq
-    set lastMoveInLine 0
-    if {[sc_pos isAt vend]} {
-        set lastMoveInLine 1
-    }
-    sc_move back
-    
-    # RMB used to delete the move if it was the last in a line. Removed it as there is no undo.
-    # if {[sc_pos isAt vstart] && [sc_var level] != 0} {
-    # ::pgn::deleteVar [sc_var number]
-    # } elseif {$lastMoveInLine} {
-    # sc_game truncate
-    # }
-    
-    set selectedSq -1
-    set bestSq -1
-    # update the board without -pgn option because of poor performance with long games
-    updateBoard -animate
-    ::utils::sound::AnnounceBack
-}
-
 # addMarker:
 #   add/delete square markers and arrows to the current position
 #
@@ -1070,17 +1202,28 @@ proc CreateMainBoard { {w} } {
   CreateGameInfo
 
   ::board::new $w.board $::boardSize
-  ::board::showMarks $w.board 1
-  for {set i 0} {$i < $::boardCoords} {incr i} { ::board::coords $w.board }
+  ::board::showMarks $w.board $::gameInfo(showMarks)
+  ::board::coords $w.board $::boardCoords
+  ::board::bindEvalBar $w.board <ButtonRelease-1> "
+    tk_popup \[::createMainEvalBarMenu $w.board \] %X %Y
+  "
+  options.persistent ::showEvalBar($w) 1
+  options.persistent ::showMainEvalBarArrow 1
+  if {$::showEvalBar($w)} { ::board::toggleEvalBar $w.board }
   if {$::gameInfo(showMaterial)} { ::board::toggleMaterial $w.board }
 
   ::board::addNamesBar $w.board gamePlayers
   ::board::addInfoBar $w.board gameInfoBar
 
-  set ::gameInfoBar(tb_BD_Coords) "set ::boardCoords \[::board::coords $w.board\]"
   set ::gameInfoBar(tb_BD_Material) "set ::gameInfo(showMaterial) \[::board::toggleMaterial $w.board\]"
+  set ::gameInfoBar(tb_BD_Scorebar) [list apply {{w} {
+    set ::showEvalBar($w) [::board::toggleEvalBar $w.board]
+    unset -nocomplain ::mainEvalBarEngineID_
+    ::board::updateEvalBar .main.board ""
+    ::board::mark::DrawBestMove $w.board ""
+  }} $w]
 
-  menu .main.menuaddchoice -bg white -font font_Regular
+  menu .main.menuaddchoice
   .main.menuaddchoice add command -label " Undo" -image tb_BD_Undo -compound left \
       -command {undoFeature undo}
   .main.menuaddchoice add command -label " $::tr(ReplaceMove)" -image tb_BD_Replace -compound left \
@@ -1098,9 +1241,10 @@ proc CreateMainBoard { {w} } {
     ::board::bind $w.board $i <ButtonPress-1> "pressSquare $i"
     ::board::bind $w.board $i <Control-ButtonPress-1> "addMarker $w.board %X %Y"
     ::board::bind $w.board $i <Control-ButtonRelease-1> "addMarker $w.board %X %Y"
+    ::board::bind $w.board $i <ButtonPress-$::MB3> "addMarker $w.board %X %Y"
+    ::board::bind $w.board $i <ButtonRelease-$::MB3> "addMarker $w.board %X %Y"
     ::board::bind $w.board $i <B1-Motion> "::board::dragPiece $w.board %X %Y"
     ::board::bind $w.board $i <ButtonRelease-1> "releaseSquare $w.board %X %Y"
-    ::board::bind $w.board $i <ButtonPress-$::MB3> backSquare
   }
 
   foreach i {o q r n k O Q R B N K} {
@@ -1113,18 +1257,11 @@ proc CreateMainBoard { {w} } {
     bind $w <Alt-$i> { continue }
   }
 
-  bind $w <Control-BackSpace> backSquare
-  bind $w <Control-Delete> backSquare
   bind $w <BackSpace> moveEntry_Backspace
   bind $w <Delete> moveEntry_Backspace
   bind $w <space> moveEntry_Complete
   bind $w <ButtonRelease> "focus $w"
   bind $w <Configure> {+::resizeMainBoard }
-  bind $w <Return> { #TODO: improve this
-    if {[winfo exists .analysisWin1] && $analysis(analyzeMode1)} {
-        .analysisWin1.b1.move invoke
-    }
-  }
 
   bindMouseWheel $w "main_mousewheelHandler"
 
@@ -1136,6 +1273,7 @@ proc CreateMainBoard { {w} } {
   grid columnconfigure $w 0 -weight 1
   grid $w.board -row 2 -column 0 -sticky we ;# -padx 5 -pady 5
 
+  updateMainGame
   toggleGameInfo
   updateStatusBar
   updateMainToolbar
@@ -1145,64 +1283,55 @@ proc CreateMainBoard { {w} } {
 proc CreateGameInfo {} {
   # .gameInfo is the game information widget:
   #
-  autoscrollframe .main.gameInfo text .main.gameInfo.text
-  .main.gameInfo.text configure -width 20 -height 6 -fg black -bg white -wrap none -state disabled -cursor top_left_arrow -setgrid 1
+  autoscrollText y .main.gameInfo .main.gameInfo.text Treeview
+  .main.gameInfo.text configure -width 20 -height 6 -wrap none -state disabled -cursor top_left_arrow -setgrid 1
   ::htext::init .main.gameInfo.text
-  
+
   # Set up player photos:
-  label .main.photoW -background white -image photoW -anchor ne
-  label .main.photoB -background white -image photoB -anchor ne
+  ttk::label .main.photoW -image photoW -anchor ne
+  ttk::label .main.photoB -image photoB -anchor ne
   bind .main.photoW <ButtonPress-1> "togglePhotosSize"
   bind .main.photoB <ButtonPress-1> "togglePhotosSize"
-  
+
   # Right-mouse button menu for gameInfo frame:
   menu .main.gameInfo.menu -tearoff 0
-  
+
   .main.gameInfo.menu add checkbutton -label GInfoHideNext \
           -variable gameInfo(hideNextMove) -offvalue 0 -onvalue 1 -command updateBoard
-  
+
   .main.gameInfo.menu add checkbutton -label GInfoMaterial -variable gameInfo(showMaterial) -offvalue 0 -onvalue 1 \
           -command { toggleShowMaterial }
-  
+
   .main.gameInfo.menu add checkbutton -label GInfoFEN \
           -variable gameInfo(showFEN) -offvalue 0 -onvalue 1 -command updateBoard
-  
+
   .main.gameInfo.menu add checkbutton -label GInfoMarks \
-          -variable gameInfo(showMarks) -offvalue 0 -onvalue 1 -command updateBoard
-  
+          -variable gameInfo(showMarks) -offvalue 0 -onvalue 1 -command {
+              ::board::showMarks .main.board $gameInfo(showMarks)
+              updateBoard }
+
   .main.gameInfo.menu add checkbutton -label GInfoWrap \
           -variable gameInfo(wrap) -offvalue 0 -onvalue 1 -command updateBoard
-  
+
   .main.gameInfo.menu add checkbutton -label GInfoFullComment \
           -variable gameInfo(fullComment) -offvalue 0 -onvalue 1 -command updateBoard
-  
+
   .main.gameInfo.menu add checkbutton -label GInfoPhotos \
           -variable gameInfo(photos) -offvalue 0 -onvalue 1 \
           -command {togglePhotosSize 0}
-  
+
   .main.gameInfo.menu add separator
-  
-  .main.gameInfo.menu add radiobutton -label GInfoTBNothing \
-          -variable gameInfo(showTB) -value 0 -command updateBoard
-  
-  .main.gameInfo.menu add radiobutton -label GInfoTBResult \
-          -variable gameInfo(showTB) -value 1 -command updateBoard
-  
-  .main.gameInfo.menu add radiobutton -label GInfoTBAll \
-          -variable gameInfo(showTB) -value 2 -command updateBoard
-  
-  .main.gameInfo.menu add separator
-  
+
   .main.gameInfo.menu add command -label GInfoDelete -command {
       sc_base gameflag [sc_base current] [sc_game number] invert del
       ::notify::DatabaseModified [sc_base current]
   }
-  
+
   bind .main.gameInfo.text <ButtonPress-$::MB3> {
     tk_popup .main.gameInfo.menu %X %Y
   }
 
-  storeMenuLabels .main.gameInfo.menu
+  translateMenuLabels .main.gameInfo.menu
 }
 
 # Set toolbar help status messages:
@@ -1262,7 +1391,7 @@ proc InitToolbar {{tb}} {
 	ttk::button .main.tb.eco -image tb_eco -command ::windows::eco::OpenClose -padding {2 0}
 	ttk::button .main.tb.tree -image tb_tree -command ::tree::make -padding {2 0}
 	ttk::button .main.tb.crosstab -image tb_crosstab -command ::crosstab::OpenClose -padding {2 0}
-	ttk::button .main.tb.engine -image tb_engine -command makeAnalysisWin -padding {2 0}
+	ttk::button .main.tb.engine -image tb_engine -command ::enginewin::Open -padding {2 0}
 	ttk::button .main.tb.help -image tb_help -command {helpWindow Index} -padding {2 0}
 
 	foreach i {newdb open save closedb finder bkm newgame copy paste gprev gnext \
@@ -1283,13 +1412,20 @@ proc toggleToolbarButton { b i } {
 	set ::toolbar_temp($i) 1
 	$b.$i state pressed
     }
+    array set ::toolbar_state [array get ::toolbar_temp]
+    redrawToolbar
 }
 
-proc configToolbar {} {
-  set w .tbconfig
-  win::createDialog $w
-  wm title $w "Scid: [tr OptionsToolbar]"
+proc toggleAllToolbarButtons { b state } {
+    foreach i [array names ::toolbar_temp] {
+	set ::toolbar_temp($i) $state
+	if { $state } { $b.$i state pressed } else { $b.$i state !pressed }
+    }
+    array set ::toolbar_state [array get ::toolbar_temp]
+    redrawToolbar
+}
 
+proc ConfigToolbar { w } {
   array set ::toolbar_temp [array get ::toolbar_state]
   pack [ttk::frame $w.f] -side top -fill x
   set col 0
@@ -1306,23 +1442,10 @@ proc configToolbar {} {
   setToolbarTooltips $w.f
   addHorizontalRule $w
   pack [ttk::frame $w.b] -side bottom -fill x
-  ttk::button $w.on -text "+ [::utils::string::Capital $::tr(all)]" -command {
-      foreach i [array names toolbar_temp] { set toolbar_temp($i) 1; .tbconfig.f.$i state pressed }
-  }
-  ttk::button $w.off -text "- [::utils::string::Capital $::tr(all)]" -command {
-      foreach i [array names toolbar_temp] { set toolbar_temp($i) 0 ; .tbconfig.f.$i state !pressed }
-  }
-  ttk::button $w.ok -text "OK" -command {
-    array set ::toolbar_state [array get toolbar_temp]
-    catch {grab release .tbconfig}
-    destroy .tbconfig
-    redrawToolbar
-  }
-  ttk::button $w.cancel -text $::tr(Cancel) \
-      -command "catch {grab release $w}; destroy $w"
-  pack $w.cancel $w.ok -side right -padx 2 -pady "5 0"
+  ttk::button $w.on -text "+ [::utils::string::Capital $::tr(all)]" -command "toggleAllToolbarButtons $w.f 1"
+  ttk::button $w.off -text "- [::utils::string::Capital $::tr(all)]" -command "toggleAllToolbarButtons $w.f 0"
+
   pack $w.on $w.off -side left -padx 2 -pady "5 0"
-  catch {grab $w}
 }
 
 proc redrawToolbar {} {
