@@ -6,8 +6,6 @@
 ############################################################
 ### Main window menus:
 
-option add *Menu*TearOff 0
-
 menu .menu
 
 ## Mac Application menu has to be before any call to configure.
@@ -15,17 +13,16 @@ if { $macOS } {
   # Application menu:
   .menu add cascade -label Scid -menu .menu.apple
   menu .menu.apple
-  
+
   set m .menu.apple
-  
+
   $m add command -label HelpAbout -command helpAbout
-  
+
   $m add separator
-  
+
   # To Quit
-  bind all <Command-q> "exit"
-  bind all <Command-Q> "exit"
-  
+  proc ::tk::mac::Quit { args } { ::file::Exit }
+
   ## To get Help
   bind all <Command-?> {helpWindow Contents}
   bind all <Help> {helpWindow Contents}
@@ -53,10 +50,32 @@ $m add command -label FileExit -accelerator "Ctrl+Q" -command ::file::Exit
 
 ### Database menu:
 set m .menu.db
-menu $m
+menu $m -postcommand "updateMenuStates $m"
 .menu add cascade -label Database -menu $m
 $m add command -label FileClose -acc "Ctrl+W" -command ::file::Close
+$m add checkbutton -label LoadatStartup -variable ::autoLoadBases_currdb -command {
+  if {[::file::autoLoadBases.remove $::curr_db] == -1} {
+    ::file::autoLoadBases.add $::curr_db
+  }
+}
 $m add separator
+menu $m.copygames
+  $m.copygames add command -label FileNew -command {
+    set srcBase $::curr_db
+    set destBase [::file::New]
+    if {$destBase ne ""} {
+      foreach {tag value} [sc_base extra $srcBase] {
+        if {$tag ne "type"} {
+          # Try to copy the database info (may not be supported by a database type like PGN)
+          catch { sc_base extra $destBase $tag $value }
+        }
+      }
+      ::windows::gamelist::CopyGames {} $srcBase $destBase all false
+    }
+  }
+  $m.copygames add separator
+  set ::menuDBCopyGamesIdx [expr [$m.copygames index end] +1]
+$m add cascade -label CopyAllGames -menu $m.copygames
 menu $m.exportfilter
   $m.exportfilter add command -label ToolsExpFilterPGN \
       -command {exportGames filter PGN}
@@ -66,8 +85,6 @@ menu $m.exportfilter
       -command {::html::exportCurrentFilter}
   $m.exportfilter add command -label ToolsExpFilterLaTeX \
       -command {exportGames filter LaTeX}
-  $m.exportfilter add separator
-  set ::menuDbExportFilterIdx [expr [$m.exportfilter index end] +1]
 $m add cascade -label ToolsExpFilter -menu $m.exportfilter
 $m add command -label ToolsImportFile -command { importPgnFile $::curr_db }
 $m add separator
@@ -76,9 +93,12 @@ menu $m.utils
   $m.utils add command -label FileMaintCompact -command compactDB
   $m.utils add command -label FileMaintClass -command classifyAllGames
   $m.utils add checkbutton -label FileMaintNameEditor -command nameEditor -variable nameEditorWin -accelerator "Ctrl+Shift+N"
+  $m.utils add command -label StripTags -command stripTags
   $m.utils add separator
   $m.utils add command -label FileMaintDelete -state disabled -command markTwins
   $m.utils add command -label FileMaintTwin -command updateTwinChecker
+  $m.utils add separator
+  $m.utils add command -label Cleaner -command cleanerWin
 $m add cascade -label FileMaint -menu $m.utils
 menu $m.spell
   $m.spell add command -label FileMaintNamePlayer -command {openSpellCheckWin Player}
@@ -181,28 +201,6 @@ menu $m.training
   $m.training add command -label ToolsTrainReviewGame -command ::reviewgame::start
   $m.training add command -label ToolsTrainCalvar -command ::calvar::config
 $m add cascade -label ToolsTraining -menu $m.training
-$m add separator
-menu $m.correspondence
-  $m.correspondence add command -label CCConfigure   -command {::CorrespondenceChess::config}
-  $m.correspondence add command -label CCConfigRelay -command {::CorrespondenceChess::ConfigureRelay}
-  $m.correspondence add separator
-  $m.correspondence add command -label CCOpenDB      -command {::CorrespondenceChess::OpenCorrespondenceDB; ::CorrespondenceChess::ReadInbox} \
-      -accelerator "Ctrl+F12"
-  $m.correspondence add separator
-  $m.correspondence add command -label CCRetrieve    -command { ::CorrespondenceChess::FetchGames }
-  $m.correspondence add command -label CCInbox       -command { ::CorrespondenceChess::ReadInbox }
-  $m.correspondence add separator
-  $m.correspondence add command -label CCSend        -command {::CorrespondenceChess::SendMove 0 0 0 0}
-  $m.correspondence add command -label CCResign      -command {::CorrespondenceChess::SendMove 1 0 0 0}
-  $m.correspondence add command -label CCClaimDraw   -command {::CorrespondenceChess::SendMove 0 1 0 0}
-  $m.correspondence add command -label CCOfferDraw   -command {::CorrespondenceChess::SendMove 0 0 1 0}
-  $m.correspondence add command -label CCAcceptDraw  -command {::CorrespondenceChess::SendMove 0 0 0 1}
-  $m.correspondence add command -label CCGamePage    -command {::CorrespondenceChess::CallWWWGame}
-  $m.correspondence add separator
-  $m.correspondence add command -label CCNewMailGame -command {::CorrespondenceChess::newEMailGame}
-  $m.correspondence add command -label CCMailMove    -command {::CorrespondenceChess::eMailMove}
-$m add cascade -label CorrespondenceChess -menu $m.correspondence
-
 
 ### Windows menu:
 set m .menu.windows
@@ -218,27 +216,20 @@ $m add command -label ToolsCross -accelerator "Ctrl+Shift+X" -command ::crosstab
 $m add checkbutton -label WindowsECO -accelerator "Ctrl+Y" -variable ::windows::eco::isOpen -command {::windows::eco::OpenClose}
 $m add checkbutton -label WindowsStats -variable ::windows::stats::isOpen -accelerator "Ctrl+I" -command ::windows::stats::Open
 $m add checkbutton -label WindowsTree -variable treeWin -command ::tree::make -accelerator "Ctrl+T"
-$m add checkbutton -label WindowsTB -variable ::tb::isOpen -command ::tb::Open -accelerator "Ctrl+="
 $m add checkbutton -label WindowsBook -variable ::book::isOpen -command ::book::open -accelerator "F6"
-$m add checkbutton -label WindowsCorrChess -variable ::CorrespondenceChess::isOpen \
-    -command ::CorrespondenceChess::CCWindow -accelerator "F12"
 
 
 ### Tools menu:
 set m .menu.tools
 menu $m
 .menu add cascade -label Tools -menu $m
-$m  add command -label ToolsAnalysis \
-    -command makeAnalysisWin -accelerator "Ctrl+Shift+A"
-$m  add command -label ToolsAnalysis2 \
-    -command "makeAnalysisWin 2" -accelerator "Ctrl+Shift+2"
-$m  add checkbutton -label ToolsStartEngine1 -variable analysisWin1 \
-    -command "makeAnalysisWin 1 0" -accelerator "F2"
-$m  add checkbutton -label ToolsStartEngine2 -variable analysisWin2 \
-    -command "makeAnalysisWin 2 0" -accelerator "F3"
+$m  add command -label ToolsConfigureEngines -command ::enginelist::choose
+$m  add command -label ToolsStartEngine1 \
+    -command "::enginewin::start 1" -accelerator "F2"
+$m  add command -label ToolsStartEngine2 \
+    -command "::enginewin::start 2" -accelerator "F3"
+$m  add command -label ToolsAnalysis -command "makeAnalysisWin 1"
 $m add separator
-$m add checkbutton -label ToolsEmail \
-    -accelerator "Ctrl+Shift+E" -variable emailWin -command ::tools::email
 $m add checkbutton -label ToolsFilterGraph \
     -accelerator "Ctrl+Shift+G" -variable filterGraph -command tools::graphs::filter::Open
 $m add checkbutton -label ToolsAbsFilterGraph \
@@ -271,118 +262,31 @@ menu $m.language
   foreach l $::languages {
       $m.language add radiobutton -label $::langName($l) \
           -underline $::langUnderline($l) -variable language -value $l \
-          -command setLanguage
+          -command "setLanguage; ::notify::PosChanged pgnonly"
   }
 $m add cascade -label OptionsLanguage -menu $m.language
-menu $m.board
-  menu $m.board.bdsize
-  $m.board add cascade -label OptionsBoardSize -menu $m.board.bdsize
-  menu $m.board.pieces -tearoff 1
-  $m.board add cascade -label OptionsBoardPieces -menu $m.board.pieces
-  $m.board add command -label OptionsBoardColors -command chooseBoardColors
-$m add cascade -label OptionsBoard -menu $m.board
-menu $m.fonts
-  $m.fonts add command -label OptionsFontsRegular -command {chooseFont Regular}
-  $m.fonts add command -label OptionsFontsMenu    -command {chooseFont Menu}
-  $m.fonts add command -label OptionsFontsSmall   -command {chooseFont Small}
-  $m.fonts add command -label OptionsFontsTiny    -command {chooseFont Tiny}
-  $m.fonts add command -label OptionsFontsFixed   -command {chooseFont Fixed}
-$m add cascade -label OptionsFonts -menu $m.fonts
-$m add command -label OptionsMenuColor -command { ::appearance::menuConfigDialog }
-if { $::macOS } { $m entryconfigure end -state disabled }
-menu $m.numbers
-  foreach numeric {".,"   ". "   "."   ",."   ", "   ","} \
-          underline {  0     1      2     4      5      6} {
-      set decimal [string index $numeric 0]
-      set thousands [string index $numeric 1]
-      $m.numbers add radiobutton -label "12${thousands}345${decimal}67" \
-          -underline $underline \
-          -variable locale(numeric) -value $numeric -command updateLocale
-  }
-$m add cascade -label OptionsNumbers -menu $m.numbers
 menu $m.theme -tearoff 1
-$m.theme add command -label OptionsThemeDir -command setThemePkgFile
-$m.theme add separator
 set ::menuThemeListIdx [expr [$m.theme index end] +1]
 $m add cascade -label OptionsTheme -menu $m.theme
-menu $m.windows
-  $m.windows add checkbutton -label OptionsWindowsIconify -variable autoIconify
-  $m.windows add checkbutton -label OptionsWindowsRaise -variable autoRaise
-  $m.windows add checkbutton -label OptionsWindowsDock -variable windowsDock
-
-    menu $m.windows.savelayout
-    menu $m.windows.restorelayout
+menu $m.savelayout
+menu $m.restorelayout
     foreach i {"1 (default)" "2" "3"} slot {1 2 3} {
-      $m.windows.savelayout add command -label $i -command "::docking::layout_save $slot"
-      $m.windows.restorelayout add command -label $i -command "::docking::layout_restore $slot"
+      $m.savelayout add command -label $i -command "::docking::layout_save $slot"
+      $m.restorelayout add command -label $i -command "::docking::layout_restore $slot"
     }
-    $m.windows add cascade -label OptionsWindowsSaveLayout -menu $m.windows.savelayout
-    $m.windows add cascade -label OptionsWindowsRestoreLayout -menu $m.windows.restorelayout
-
-  menu $m.windows.startup
-    $m.windows.startup add checkbutton -label HelpTip -variable startup(tip)
-    $m.windows.startup add checkbutton -label FileFinder -variable startup(finder)
-    $m.windows.startup add checkbutton -label WindowsStats -variable startup(stats)
-  $m.windows add cascade -label OptionsStartup -menu $m.windows.startup
-$m add cascade -label OptionsWindows -menu $m.windows
-$m add command -label OptionsSounds -command ::utils::sound::OptionsDialog
-$m add command -label OptionsToolbar -command configToolbar
-$m add separator
-$m add command -label OptionsRecent -command ::recentFiles::configure
-$m add command -label GInfoInformant -command configInformant
+$m add command -label ConfigureScid -command { ::preferences::Open toggle }
+$m add command -label OptionsResources -command ::preferences::resources
 menu $m.export
   $m.export add command -label "PGN file text" -underline 0 -command "setExportText PGN"
   $m.export add command -label "HTML file text" -underline 0 -command "setExportText HTML"
   $m.export add command -label "LaTeX file text" -underline 0 -command "setExportText LaTeX"
 $m add cascade -label OptionsExport -menu $m.export
-menu $m.entry
-  $m.entry add checkbutton -label OptionsMovesAsk \
-      -variable askToReplaceMoves -offvalue 0 -onvalue 1
-  menu $m.entry.animate
-    foreach i {0 100 150 200 250 300 400 500 600 800 1000} {
-        $m.entry.animate add radiobutton -label "$i ms" \
-            -variable animateDelay -value $i
-    }
-  $m.entry add cascade -label OptionsMovesAnimate -menu $m.entry.animate
-  $m.entry add command -label OptionsMovesDelay -command setAutoplayDelay
-  $m.entry add checkbutton -label OptionsMovesCoord \
-      -variable moveEntry(Coord) -offvalue 0 -onvalue 1
-  $m.entry add checkbutton -label OptionsMovesKey \
-      -variable moveEntry(AutoExpand) -offvalue 0 -onvalue 1
-  $m.entry add checkbutton -label OptionsMovesSuggest \
-      -variable suggestMoves -offvalue 0 -onvalue 1
-  $m.entry add checkbutton -label OptionsShowVarPopup \
-      -variable showVarPopup -offvalue 0 -onvalue 1
-  $m.entry add checkbutton -label OptionsMovesSpace \
-      -variable ::pgn::moveNumberSpaces -offvalue 0 -onvalue 1
-  $m.entry add checkbutton -label OptionsMovesTranslatePieces \
-      -variable ::translatePieces -offvalue 0 -onvalue 1 -command setLanguage
-  menu $m.entry.highlightlastmove
-    $m.entry.highlightlastmove add checkbutton -label OptionsMovesHighlightLastMoveDisplay \
-        -variable ::highlightLastMove -command updateBoard
-    menu $m.entry.highlightlastmove.width
-      foreach i {1 2 3 4 5} {
-          $m.entry.highlightlastmove.width add radiobutton -label $i -value $i \
-              -variable ::highlightLastMoveWidth -command updateBoard
-      }
-    $m.entry.highlightlastmove add cascade -label OptionsMovesHighlightLastMoveWidth -menu $m.entry.highlightlastmove.width
-    $m.entry.highlightlastmove add command -label OptionsMovesHighlightLastMoveColor -command chooseHighlightColor
-    $m.entry.highlightlastmove add checkbutton -label OptionsMovesHighlightLastMoveArrow \
-        -variable ::arrowLastMove -command updateBoard
-  $m.entry add cascade -label OptionsMovesHighlightLastMove -menu  $m.entry.highlightlastmove
-  $m.entry add checkbutton -label OptionsMovesShowVarArrows \
-      -variable showVarArrows -offvalue 0 -onvalue 1
-  $m.entry add checkbutton -label OptionsMovesGlossOfDanger \
-      -variable glossOfDanger -offvalue 0 -onvalue 1 -command updateBoard
-$m add cascade -label OptionsMoves -menu $m.entry
 $m add separator
-$m add command -label OptionsECO -command ::readECOFile
-$m add command -label OptionsSpell -command readSpellCheckFile
-$m add command -label OptionsTable -command setTableBaseDir \
-    -state [expr {[sc_info tb] ? "normal" : "disabled"}]
-$m add command -label OptionsBooksDir -command setBooksDir
-$m add command -label OptionsTacticsBasesDir -command setTacticsBasesDir
-$m add command -label OptionsPhotosDir -command setPhotoDir
+$m add checkbutton -label FullScreen -variable optionFullScreen \
+  -command { wm attributes . -fullscreen [expr ![wm attributes . -fullscreen]] }
+$m add checkbutton -label OptionsWindowsDock -variable windowsDock
+$m add cascade -label OptionsWindowsSaveLayout -menu $m.savelayout
+$m add cascade -label OptionsWindowsRestoreLayout -menu $m.restorelayout
 $m add separator
 $m add command -label OptionsSave -command options.write
 $m add checkbutton -label OptionsAutoSave -variable optionsAutoSave \
@@ -408,9 +312,8 @@ $m  add command -label HelpAbout -command helpAbout
 ##################################################
 # Store menu labels for translations and help messages
 set ::menuHelpMessage {}
-proc storeMenuLabels {m} {
+proc translateMenuLabels {m} {
     bind $m <<MenuSelect>> {
-        set ::menuHelpMessage {}
         set idx [%W index active]
         if {$idx != "none"} {
             # Tcl/Tk seems to generate strange window names for menus that
@@ -420,22 +323,33 @@ proc storeMenuLabels {m} {
             # I have no idea why it does this, but to avoid it we
             # convert a window paths with hashes to its true value:
             regsub -all "\#" [winfo name %W] . win
+            set ::menuHelpMessage {}
             catch {
                 set lbl $::MenuLabels($win,$idx)
                 set ::menuHelpMessage $::helpMessage($::language,$lbl)
             }
+            updateStatusBar
+        } elseif {$::menuHelpMessage ne ""} {
+            set ::menuHelpMessage {}
+            updateStatusBar
         }
-        updateStatusBar
     }
 
     set n [$m index end]
     for {set i 0} {$n != "none" && $i <= $n} {incr i} {
         set type [$m type $i]
         if {$type != "separator" && $type != "tearoff"} {
-            set ::MenuLabels($m,$i) [$m entrycget $i -label]
+            set lbl [$m entrycget $i -label]
+            set ::MenuLabels($m,$i) $lbl
+            set under 0
+            catch { set under $::menuUnder($::language,$lbl) }
+            $m entryconfig $i -label [tr $lbl] -underline $under
         }
         if {$type == "cascade"} {
-            storeMenuLabels [$m entrycget $i -menu]
+            set submenu [$m entrycget $i -menu]
+            if {$submenu ne ".menu.options.language"} {
+                translateMenuLabels $submenu
+            }
         }
     }
 }
@@ -449,7 +363,7 @@ proc menuConfig {{m} {label} {cmd} args} {
         }
     }
 }
-storeMenuLabels .menu
+translateMenuLabels .menu
 set fileExitHack [.menu.file index end]
 set ::MenuLabels(.menu.file,end) $::MenuLabels(.menu.file,$fileExitHack)
 array unset ::MenuLabels ".menu.file,$fileExitHack"
@@ -476,6 +390,9 @@ proc updateMenuStates {{menuname}} {
         $m.file insert [expr $::menuFileRecentIdx + $nrecent] separator
       }
     }
+  {.menu.db} {
+      set ::autoLoadBases_currdb [expr {[::file::autoLoadBases.find $::curr_db] >= 0}]
+    }
   {.menu.play} {
       set n [$m.play index end]
       set st normal
@@ -492,25 +409,25 @@ proc updateMenuStates {{menuname}} {
     $m.game entryconfig [tr GameFirst] -state $state
     $m.game entryconfig [tr GameLast] -state $state
     $m.game entryconfig [tr GameRandom] -state $state
-    
+
     # Load previous button:
     if {[sc_filter previous]} {set state normal} else {set state disabled}
     $m.game entryconfig [tr GamePrev] -state $state
     .main.tb.gprev configure -state $state
-    
+
     # Reload button:
     if {[sc_game number]} {set state normal} else {set state disabled}
     $m.game entryconfig [tr GameReload] -state $state
-    
+
     # Load next button:
     if {[sc_filter next]} {set state normal} else {set state disabled}
     $m.game entryconfig [tr GameNext] -state $state
     .main.tb.gnext configure -state $state
-    
+
     # Save add button:
     set state normal
     $m.game entryconfig [tr GameAdd] -state $state
-    
+
     # Save replace button:
     set state normal
     if {[sc_game number] == 0  ||  $isReadOnly } {
@@ -518,6 +435,9 @@ proc updateMenuStates {{menuname}} {
     }
     $m.game entryconfig [tr GameReplace] -state $state
   }
+  {.menu.options} {
+    set ::optionsFullScreen [wm attributes . -fullscreen]
+  }
   }
 }
 
@@ -525,7 +445,7 @@ proc updateMenuStates {{menuname}} {
 proc menuUpdateBases {} {
   set ::currentSlot $::curr_db
   .menu.db delete $::menuDbSwitchIdx end
-  .menu.db.exportfilter delete $::menuDbExportFilterIdx end
+  .menu.db.copygames delete $::menuDBCopyGamesIdx end
 
   foreach i [sc_base list] {
     set fname [file tail [sc_base filename $i]]
@@ -536,8 +456,8 @@ proc menuUpdateBases {} {
         -command [list ::file::SwitchToBase $i]
 
     if {$i != $::curr_db && ![sc_base isReadOnly $i]} {
-        .menu.db.exportfilter add command -label "Base $i: $fname" \
-            -command "::windows::gamelist::CopyGames {} $::curr_db $i"
+        .menu.db.copygames add command -label "Base $i: $fname" \
+            -command "::windows::gamelist::CopyGames {} $::curr_db $i all"
     }
   }
 
@@ -548,8 +468,12 @@ proc menuUpdateBases {} {
   set notEmpty    [expr {[sc_base numGames $::curr_db] != 0 ? "normal" : "disabled"}]
 
   menuConfig .menu.db FileClose entryconfig -state $notClipbase
+  menuConfig .menu.db LoadatStartup entryconfig -state $notClipbase
+  menuConfig .menu.db CopyAllGames entryconfig -state $notEmpty
   menuConfig .menu.db ToolsExpFilter entryconfig -state $notEmpty
   menuConfig .menu.db FileMaintName entryconfig -state $canChange
+  menuConfig .menu.db.utils Cleaner          entryconfig -state $canChange
+  menuConfig .menu.db.utils StripTags        entryconfig -state $canChange
   menuConfig .menu.db.utils FileMaintDelete  entryconfig -state $canChange
   menuConfig .menu.db.utils FileMaintClass   entryconfig -state $canChange
   menuConfig .menu.db.utils FileMaintTwin    entryconfig -state $canChange
@@ -557,36 +481,6 @@ proc menuUpdateBases {} {
   menuConfig .menu.db.utils FileMaintNameEditor entryconfig -state $canChange
 }
 
-proc menuUpdateBoardSizes {} {
-  set count 0
-  set m .menu.options.board
-  $m.bdsize delete 0 end
-  set st normal
-  $m.bdsize add checkbutton -label "Auto" -variable ::autoResizeBoard \
-        -command "::resizeMainBoard; menuUpdateBoardSizes"
-  if {$::autoResizeBoard} { set st disabled }
-  foreach i $::boardSizes {
-    incr count
-    if {$count <= 9} {
-      set lbl "  $count"
-    } else {
-      set lbl " $count"
-    }
-    $m.bdsize add radio -label "$lbl" -variable boardSize -value $i -state $st\
-      -command "::board::resize .main.board $i "
-  }
-}
-
-proc menuUpdatePieces {} {
-  set m .menu
-  $m.options.board.pieces delete 0 end
-  foreach i $::boardStyles {
-    $m.options.board.pieces add radio -label $i \
-      -variable boardStyle -value $i \
-      -underline 0 -command "setPieceFont \"$i\"; updateBoard"
-  }
-}
-
 proc menuUpdateThemes {} {
   set m .menu.options.theme
   $m delete $::menuThemeListIdx end
@@ -614,19 +508,18 @@ proc configMenuText {menu entry tag lang} {
 proc setLanguageMenus {} {
   set lang $::language
   foreach {key lbl} [array get ::MenuLabels] {
-    foreach {m idx} [split $key ","] {
+      lassign [split $key ","] m idx
+      if {![winfo exists $m]} { continue }
       set under 0
       catch { set under $::menuUnder($lang,$lbl) }
       $m entryconfig $idx -label [tr $lbl] -underline $under
-    }
   }
 
-  ::pgn::ConfigMenus
-  ::tree::ConfigMenus
-  ::crosstab::ConfigMenus
   ::optable::ConfigMenus
   ::preport::ConfigMenus
-  
+  ::tools::graphs::score::ConfigMenus
+  ::tools::graphs::rating::ConfigMenus
+
   # Check for duplicate menu underline characters in this language:
   # set ::verifyMenus 1
   if {[info exists ::verifyMenus] && $::verifyMenus} {
@@ -669,26 +562,19 @@ proc checkMenuUnderline {menu} {
 ################################################################################
 #
 ################################################################################
-proc configInformant {} {
+proc configInformant { w } {
   global informant
-  
-  set w .configInformant
-  if {[winfo exists $w]} {
-    destroy $w
-  }
-  
-  win::createDialog $w
-  ::setTitle $w $::tr(ConfigureInformant)
-  setWinLocation $w
+
   ttk::frame $w.spinF
   set idx 0
   set row 0
-  
+
   foreach i [lsort [array names informant]] {
+    if {$i == "\"++-\""} { continue } ; # ignore old version: ++- from options.dat
     ttk::label $w.spinF.labelExpl$idx -text [ ::tr "Informant[ string trim $i "\""]" ]
     ttk::label $w.spinF.label$idx -text $i
      # Allow the configuration of "won game" up to "Mate found"
-     if {$i == "\"++-\""} {
+     if {$i == "\"+--\""} {
          ttk::spinbox $w.spinF.sp$idx -textvariable informant($i) -width 5 -from 0.0 -to 328.0 -increment 1.0 -validate all -validatecommand { regexp {^[0-9]\.[0-9]$} %P }
      } else {
          ttk::spinbox $w.spinF.sp$idx -textvariable informant($i) -width 5 -from 0.0 -to 9.9 -increment 0.1 -validate all -validatecommand { regexp {^[0-9]\.[0-9]$} %P }
@@ -696,182 +582,120 @@ proc configInformant {} {
     grid $w.spinF.labelExpl$idx -row $row -column 0 -sticky w
     incr row
     grid $w.spinF.label$idx -row $row -column 0 -sticky w
-    grid $w.spinF.sp$idx -row $row -column 1 -sticky w
+    grid $w.spinF.sp$idx -row $row -column 1 -sticky w -padx "0 5" -pady "0 5"
     incr row
     incr idx
   }
   pack $w.spinF
-#  addHorizontalRule $w
-  ttk::button $w.close -textvar ::tr(Close) -command "destroy $w"
-  packdlgbuttons $w.close
-  bind $w <Configure> "recordWinSize $w"
 }
 
-# ################################################################################
-# Set the delay between moves in options menu
-################################################################################
-proc setAutoplayDelay {} {
-    global autoplayDelay tempdelay
-    set tempdelay [expr {int($autoplayDelay / 1000.0)}]
-    set w .apdialog
-    if { [winfo exists $w] } { focus $w ; return }
-    win::createDialog $w
-    ::setTitle $w "Scid"
-    wm resizable $w 0 0
-    ttk::label $w.label -text $::tr(AnnotateTime:)
-    pack $w.label -side top -pady 5 -padx 5
-    ttk::spinbox $w.spDelay -background white -width 4 -textvariable tempdelay -from 1 -to 999 -increment 1 \
-        -validate key -validatecommand { return [string is digit %S] }
-    pack $w.spDelay -side top -pady 5
-    
-    set b [ttk::frame $w.buttons]
-    pack $b -side top -fill x
-    ttk::button $b.cancel -text $::tr(Cancel) -command {
-        destroy .apdialog
-        focus .
-    }
-    ttk::button $b.ok -text "OK" -command {
-        if {$tempdelay < 0.1} { set tempdelay 0.1 }
-        set autoplayDelay [expr {int($tempdelay * 1000)}]
-        destroy .apdialog
-        focus .
-    }
-    packdlgbuttons $b.cancel $b.ok
-    bind $w <Escape> { .apdialog.buttons.cancel invoke }
-    bind $w <Return> { .apdialog.buttons.ok invoke }
-    focus $w.spDelay
-}
-
-# setTableBaseDir:
-#    Prompt user to select a tablebase file; all the files in its
-#    directory will be used.
-#
-proc setTableBaseDir {} {
-  global initialDir tempDir
-  set ftype { { "Tablebase files" {".emd" ".nbw" ".nbb"} } }
-
-  set w .tbDialog
-  win::createDialog $w
-  ::setTitle $w Scid
-  ttk::label $w.title -text "Select up to 4 table base directories:"
-  pack $w.title -side top -fill x
-  foreach i {1 2 3 4} {
-    set tempDir(tablebase$i) $initialDir(tablebase$i)
-    pack [ttk::frame $w.f$i] -side top -fill x -expand yes
-    ttk::entry $w.f$i.e -width 30 -textvariable tempDir(tablebase$i)
-    bindFocusColors $w.f$i.e
-    ttk::button $w.f$i.b -text "..." -command [list chooseTableBaseDir $i]
-    pack $w.f$i.b -side right -padx 2
-    pack $w.f$i.e -side left -padx 2 -fill x -expand yes
-  }
-#  addHorizontalRule $w
-  pack [ttk::frame $w.b] -side top -fill x
-  ttk::button $w.b.ok -text "OK" \
-      -command "catch {grab release $w; destroy $w}; openTableBaseDirs"
-  ttk::button $w.b.cancel -text $::tr(Cancel) \
-      -command "catch {grab release $w; destroy $w}"
-  packdlgbuttons $w.b.cancel $w.b.ok
-  bind $w <Escape> "$w.b.cancel invoke"
-  wm resizable $w 1 0
-  grab $w
-}
-proc openTableBaseDirs {} {
-  global initialDir tempDir
-  set tableBaseDirs ""
-  foreach i {1 2 3 4} {
-    set tbDir [string trim $tempDir(tablebase$i)]
-    if {$tbDir != ""} {
-      if {$tableBaseDirs != ""} { append tableBaseDirs ";" }
-      append tableBaseDirs [file nativename $tbDir]
-    }
-  }
-
-  set npieces [sc_info tb $tableBaseDirs]
-  foreach i {1 2 3 4} {
-    set initialDir(tablebase$i) $tempDir(tablebase$i)
-  }
-  if {$npieces == 0} {
-    set msg "No tablebases were found."
-  } else {
-    set msg "Tablebases with up to $npieces pieces were found.\n\n"
-    append msg "If you want these tablebases be used whenever\n"
-    append msg "you start Scid, select \"Save Options\" from the\n"
-    append msg "Options menu before you exit Scid."
-  }
-  tk_messageBox -type ok -icon info -title "Scid: Tablebase results" \
-      -message $msg
-}
-proc chooseTableBaseDir {i} {
-  global tempDir
-
-  set idir $tempDir(tablebase$i)
-  if {$idir == ""} { set idir [pwd] }
-
-  set fullname [tk_chooseDirectory -initialdir $idir -mustexist 1 \
-      -title "Scid: Select a Tablebase directory"]
-  if {$fullname == ""} { return }
-
-  set tempDir(tablebase$i) $fullname
-}
 ################################################################################
 
-proc setBooksDir {} {
+proc getBooksDir { widget } {
   global scidBooksDir
-  set dir [tk_chooseDirectory -initialdir $scidBooksDir -mustexist 1]
-  if {$dir == ""} {
-    return
-  } else {
-    set scidBooksDir $dir
+  set dir [tk_chooseDirectory -initialdir $scidBooksDir -parent [winfo toplevel $widget] -mustexist 1]
+  if {$dir != ""} {
+      setBooksDir $dir
+      $widget delete 0 end
+      $widget insert end $dir
   }
 }
 
-proc setTacticsBasesDir {} {
+proc setBooksDir { dir } {
+  global scidBooksDir
+  set scidBooksDir $dir
+}
+
+proc getTacticsBasesDir { widget } {
   global scidBasesDir
-  set dir [tk_chooseDirectory -initialdir $scidBasesDir -mustexist 1]
-  if {$dir == ""} {
-    return
-  } else {
-    set scidBasesDir $dir
+  set dir [tk_chooseDirectory -initialdir $scidBasesDir -parent [winfo toplevel $widget] -mustexist 1]
+  if {$dir != ""} {
+      setTacticsBasesDir $dir
+      $widget delete 0 end
+      $widget insert end $dir
   }
 }
 
-proc setPhotoDir {} {
-  set dir [tk_chooseDirectory -initialdir $::scidExeDir -mustexist 1]
-  if {$dir == ""} {
-    return
-  } else {
+proc setTacticsBasesDir { dir } {
+  global scidBasesDir
+  set scidBasesDir $dir
+}
+
+proc getPhotoDir { widget } {
+  set idir [pwd]
+  if { [info exists ::scidPhotoDir] } { set idir $::scidPhotoDir }
+  set dir [tk_chooseDirectory -initialdir $idir -parent [winfo toplevel $widget] -mustexist 1]
+  if {$dir != ""} {
+      if { [setPhotoDir $dir] } {
+          $widget delete 0 end
+          $widget insert end $dir
+      }
+  }
+}
+
+proc setPhotoDir { dir } {
     set ::scidPhotoDir $dir
     options.save ::scidPhotoDir
     set n [loadPlayersPhoto]
-    tk_messageBox -message "Found [lindex $n 0] images in [lindex $n 1] file(s)"
+    set ret [lindex $n 0]
+    tk_messageBox -parent .resDialog -message "Found $ret images in [lindex $n 1] file(s)"
     ::notify::GameChanged
-  }
+    return $ret
 }
 
-proc setThemePkgFile {} {
+proc getThemePkgFile { widget} {
   global initialDir
-  set f [tk_getOpenFile -title "Select a pkgIndex.tcl file for themes" -initialfile $::ThemePackageFile \
+  set fullname [tk_getOpenFile -parent [winfo toplevel $widget] -title "Select a pkgIndex.tcl file for themes" -initialdir [file dirname $::ThemePackageFile] -initialfile $::ThemePackageFile \
 	       -filetypes { {Theme "pkgIndex.tcl"} }]
-  if {$f ne ""} {
-      ::safeSourceStyle $f
-      menuUpdateThemes
-      set ::ThemePackageFile $f
+  if { $fullname != "" && $fullname != $::ThemePackageFile && ! [readThemePkgFile $fullname] } {
+      $widget delete 0 end
+      $widget insert end $fullname
   }
 }
 
-proc readECOFile {} {
+proc readThemePkgFile { fullname } {
+    if {$fullname ne "" && $fullname != $::ThemePackageFile } {
+        set count [llength [ttk::style theme names]]
+        set ret [ catch { ::safeSourceStyle $fullname } ]
+        set newthemes [expr [llength [ttk::style theme names]] - $count]
+        if { $ret == 0 && $newthemes > 0  } {
+            menuUpdateThemes
+            set ::ThemePackageFile $fullname
+        }
+        tk_messageBox -parent .resDialog -message "$newthemes new theme(s) found."
+    } else {
+        set ::ThemePackageFile $fullname
+        tk_messageBox -parent .resDialog -message "No new themes loaded."
+        set ret 0
+    }
+    return $ret
+}
+
+proc getECOFile { widget } {
+  global ecoFile
   set ftype { { "Scid ECO files" {".eco"} } }
-  set fullname [tk_getOpenFile -initialdir [pwd] -filetypes $ftype -title "Load ECO file"]
+  set fullname [tk_getOpenFile -parent [winfo toplevel $widget] -initialdir [file dirname $ecoFile] -filetypes $ftype -title "Load ECO file"]
+  if { [readECOFile $fullname] } {
+      $widget delete 0 end
+      $widget insert end $fullname
+  }
+}
+
+proc readECOFile { fullname } {
+  global ecoFile
   if {[string compare $fullname ""]} {
     if {[catch {sc_eco read $fullname} result]} {
-      tk_messageBox -title "Scid" -type ok \
-          -icon warning -message $result
+      tk_messageBox -title "Scid" -type ok -icon warning -message $result -parent .resDialog
     } else {
       set ecoFile $fullname
-      tk_messageBox -title "Scid: ECO file loaded." -type ok -icon info \
+      tk_messageBox -title "Scid: ECO file loaded." -type ok -icon info -parent .resDialog \
           -message "ECO file $fullname loaded: $result positions.\n\nTo have this file automatically loaded when you start Scid, select \"Save Options\" from the Options menu before exiting."
+      return 1
     }
+  } else {
+      set ecoFile $fullname
   }
+  return 0
 }
 
 proc updateLocale {} {
@@ -881,32 +705,6 @@ proc updateLocale {} {
   updateTitle
 }
 
-proc chooseFont {fType} {
-  global fontOptions
-  set fontOptions(temp) [FontDialog font_$fType $fontOptions($fType)]
-  if {$fontOptions(temp) != ""} { set fontOptions($fType) $fontOptions(temp) }
-  switch $fType {
-    {Regular} {
-      set font [font configure font_Regular -family]
-      set fontsize [font configure font_Regular -size]
-      font configure font_Bold -family $font -size $fontsize
-      font configure font_Italic -family $font -size $fontsize
-      font configure font_BoldItalic -family $font -size $fontsize
-      font configure font_H1 -family $font -size [expr {$fontsize + 8} ]
-      font configure font_H2 -family $font -size [expr {$fontsize + 6} ]
-      font configure font_H3 -family $font -size [expr {$fontsize + 4} ]
-      font configure font_H4 -family $font -size [expr {$fontsize + 2} ]
-      font configure font_H5 -family $font -size [expr {$fontsize + 0} ]
-    }
-    {Small} {
-      set font [font configure font_Small -family]
-      set fontsize [font configure font_Small -size]
-      font configure font_SmallBold -family $font -size $fontsize
-      font configure font_SmallItalic -family $font -size $fontsize
-    }
-  }
-}
-
 proc chooseHighlightColor {} {
   set col [ tk_chooseColor -initialcolor $::highlightLastMoveColor -title "Scid"]
   if { $col != "" } {
