@@ -33,13 +33,11 @@ exec `dirname $0`/tkscid "$0" "$@"
 
 ############################################################
 
-package require Tcl 8.5
-package require Tk  8.5
-if {$tcl_version == 8.5} { catch {package require img::png} }
+package require Tk  8.6
 
 set scidVersion [sc_info version]
 set scidVersionDate [sc_info version date]
-set scidVersionExpected "4.7.0"
+set scidVersionExpected "5.0.2"
 
 # Check that the version of c++ code matches the version of tcl code
 #
@@ -110,38 +108,10 @@ proc InitDirs {} {
   set scidBasesDir [file nativename [file join $scidShareDir "bases"]]
   set ecoFile [file nativename [file join $scidShareDir "scid.eco"]]
 
-  proc moveOldConfigFiles {} {
-    # Moves configuration files from the old (3.4 and earlier) names
-    # to the new file names used since Scid 3.5.
-    global scidUserDir scidConfigDir
-
-    # Since the options file used to be ".scid", rename it:
-    if {[file isfile $scidUserDir]} {
-      file rename -force $scidUserDir "$scidUserDir.old"
-    }
-
-    # Rename old "~/.scid_sent_emails" if necessary:
-    if {[file isfile [file nativename "~/.scid_sent_emails"]]} {
-      catch {file rename [file nativename "~/.scid_sent_emails"] $email(logfile)}
-    }
-
-    foreach {oldname newname} {
-      scidrc options.dat
-      scid.opt options.dat
-      scid.bkm bookmarks.dat
-      scid.rfl recentfiles.dat
-      engines.lis engines.dat
-    } {
-      set oldpath [file nativename [file join $scidUserDir $oldname]]
-      set newpath [file nativename [file join $scidConfigDir $newname]]
-      if {[file readable $oldpath]  &&  ![file readable $newpath]} {
-        if {[catch {file rename $oldpath $newpath} err]} {
-          tk_messageBox -message "Error moving $oldpath to $newpath: $err"
-        }
-      }
-    }
+  set ::scidEnginesDir [file normalize [file join $::scidExeDir "../engines"]]
+  if {! [file isdirectory $::scidEnginesDir]} {
+    set ::scidEnginesDir $::scidExeDir
   }
-  moveOldConfigFiles
 
   # Create the config, data and log directories if they do not exist:
   proc makeScidDir {dir} {
@@ -156,6 +126,57 @@ proc InitDirs {} {
 }
 InitDirs
 
+
+proc InitImg {} {
+	global scidImgDir boardStyle boardStyles textureSquare
+
+	#Set app icon
+	set scidIconFile [file nativename [file join $scidImgDir "scid.gif"]]
+	if {[file readable $scidIconFile]} {
+		wm iconphoto . -default [image create photo -file "$scidIconFile"]
+	}
+
+	#Load all img/buttons/_filename_.gif
+	set dname [file join $::scidImgDir buttons]
+	foreach {fname} [glob -directory $dname *.gif] {
+		set iname [string range [file tail $fname] 0 end-4]
+		image create photo $iname -file $fname
+	}
+
+	#Load all img/buttons/_filename_.png
+	set dname [file join $::scidImgDir buttons]
+	foreach {fname} [glob -directory $dname *.png] {
+		set iname [string range [file tail $fname] 0 end-4]
+		image create photo $iname -format png -file $fname
+	}
+
+	#Load all img/boards/_filename_.gif
+	set textureSquare {}
+	set dname [file join $::scidImgDir boards]
+	foreach {fname} [glob -directory $dname *.gif] {
+		set iname [string range [file tail $fname] 0 end-4]
+		image create photo $iname -file $fname
+		if {[string range $iname end-1 end] == "-l"} {
+			lappend textureSquare [string range $iname 0 end-2]
+		}
+	}
+
+	#Search available piece sets
+	set boardStyles {}
+	set dname [file join $::scidImgDir pieces]
+	foreach {piecetype} [glob -directory $dname *] {
+		if {[file isdirectory $piecetype] == 1} {
+			lappend boardStyles [file tail $piecetype]
+		}
+	}
+}
+if {[catch {InitImg}]} {
+	tk_messageBox -type ok -icon error -title "Scid: Error" \
+		-message "Cannot load images.\n$::errorCode\n\n$::errorInfo"
+	exit
+}
+
+
 #############################################################
 #
 # NAMESPACES
@@ -182,7 +203,7 @@ foreach ns {
   ::windows::switcher ::windows::eco ::crosstab ::pgn ::book
   ::windows::commenteditor
   ::tools
-  ::tools::analysis ::tools::email
+  ::tools::analysis
   ::tools::graphs
   ::tools::graphs::filter ::tools::graphs::absfilter ::tools::graphs::rating ::tools::graphs::score
   ::tb ::optable
@@ -241,10 +262,12 @@ proc safeSource {filename args} {
   set f [file nativename "$filename"]
   set d [file dirname $f]
   set n [file tail $f]
+  set vdir [::safe::interpAddToAccessPath $::safeInterp $d]
+  interp alias $::safeInterp image {} ::safeImage $::safeInterp [list $vdir $d]
   foreach {varname value} $args {
     $::safeInterp eval [list set $varname $value]
   }
-  $::safeInterp eval [list set vdir [::safe::interpAddToAccessPath $::safeInterp $d]]
+  $::safeInterp eval [list set vdir $vdir]
   $::safeInterp eval "source \$vdir/$n"
   foreach {varname value} $args {
     $::safeInterp eval [list unset $varname]
@@ -284,6 +307,7 @@ proc safeSourceStyle {filename} {
   interp alias $safeInterp package {} ::safePackage $safeInterp
   interp alias $safeInterp image {} ::safeImage $safeInterp [list $vdir $dir]
   interp alias $safeInterp ttk::style {} ::safeStyle $safeInterp
+  interp alias $safeInterp ::styleOption {} ::safeStyleOption $safeInterp
 
   $safeInterp eval [list set vdir $vdir]
   $safeInterp eval "source \$vdir/[file tail $filename]"
@@ -313,6 +337,10 @@ proc safeImage {interp dir_map args} {
 	return [image {*}$args]
 }
 
+proc safeStyleOption {interp args} {
+    styleOption {*}$args
+}
+
 # Evaluate ttk::style commands invoked inside the restricted script.
 # If the command includes a script (ttk::style theme settings or ttk::style theme create)
 # it is evaluated using the safe interpreter.
@@ -343,84 +371,221 @@ proc safeStyle {interp args} {
 # Load default/saved values
 source [file nativename [file join $::scidTclDir "options.tcl"]]
 
+proc calculateGlistRowHeight { } {
+    set ::glistRowHeight [expr { round(1.4 * [font metrics font_Small -linespace]) }]
+    ttk::style configure Gamelist.Treeview -rowheight $::glistRowHeight
+}
 
-# Check for old (single-directory) tablebase option:
-if {[info exists initialDir(tablebase)]} {
-  set initialDir(tablebase1) $initialDir(tablebase)
+proc updateFonts {font_name} {
+  switch $font_name {
+    {font_Regular} {
+      set font [font actual $font_name -family]
+      set fontsize [font actual $font_name -size]
+      font configure font_Bold       -family $font -size $fontsize -weight bold
+      font configure font_Italic     -family $font -size $fontsize -slant italic
+      font configure font_BoldItalic -family $font -size $fontsize -weight bold -slant italic
+      font configure font_H1 -family $font -size [expr {$fontsize + 8} ] -weight bold
+      font configure font_H2 -family $font -size [expr {$fontsize + 6} ] -weight bold
+      font configure font_H3 -family $font -size [expr {$fontsize + 4} ] -weight bold
+      font configure font_H4 -family $font -size [expr {$fontsize + 2} ] -weight bold
+      font configure font_H5 -family $font -size [expr {$fontsize + 0} ] -weight bold
+    }
+    {font_Small} {
+      set font [font actual $font_name -family]
+      set fontsize [font actual $font_name -size]
+      font configure font_SmallBold -family $font -size $fontsize -weight bold
+      font configure font_SmallItalic -family $font -size $fontsize -slant italic
+      calculateGlistRowHeight
+    }
+  }
 }
 
 proc createFonts {} {
-  foreach name {Regular Menu Small Tiny Fixed} {
-    set opts $::fontOptions($name)
-    font create font_$name \
-      -family [lindex $opts 0] -size [lindex $opts 1] \
-      -weight [lindex $opts 2] -slant [lindex $opts 3]
+  font create font_Bold
+  font create font_BoldItalic
+  font create font_Italic
+  font create font_H1
+  font create font_H2
+  font create font_H3
+  font create font_H4
+  font create font_H5
+
+  font create font_SmallBold
+  font create font_SmallItalic
+
+  foreach {name value} [array get ::fontOptions] {
+    lassign $value f sz w s
+    if {$f ne ""} {
+      font create font_$name -family $f -size $sz -weight $w -slant $s
+    } else {
+      font create font_$name
+      if {$name eq "Small"} {
+        font configure font_$name -size [expr {int([font actual font_$name -size] * 0.85)}]
+      } elseif {$name eq "Tiny"} {
+        font configure font_$name -size [expr {int([font actual font_$name -size] * 0.7)}]
+      }
+    }
+    updateFonts font_$name
   }
 
-  set fontsize [font configure font_Regular -size]
-  set font [font configure font_Regular -family]
-  font create font_Bold -family $font -size $fontsize -weight bold
-  font create font_BoldItalic -family $font -size $fontsize -weight bold -slant italic
-  font create font_Italic -family $font -size $fontsize -slant italic
-  font create font_H1 -family $font -size [expr {$fontsize + 8} ] -weight bold
-  font create font_H2 -family $font -size [expr {$fontsize + 6} ] -weight bold
-  font create font_H3 -family $font -size [expr {$fontsize + 4} ] -weight bold
-  font create font_H4 -family $font -size [expr {$fontsize + 2} ] -weight bold
-  font create font_H5 -family $font -size [expr {$fontsize + 0} ] -weight bold
-
-  set fontsize [font configure font_Small -size]
-  set font [font configure font_Small -family]
-  font create font_SmallBold -family $font -size $fontsize -weight bold
-  font create font_SmallItalic -family $font -size $fontsize -slant italic
-
   set ::utils::tooltip::font font_Small
 }
 createFonts
 
-# Load theme
+# Workaround: set the options of ttkEntry.c widgets that don't work with ttk::style
+set ::themeOptions {}
+proc styleOption {themeName pattern value} {
+  lappend ::themeOptions [list $themeName $pattern $value]
+}
+
+# Load darktheme, must load here to have it in place if used
+source -encoding utf-8 [file nativename [file join $::scidTclDir "darktheme.tcl"]]
+# Load more theme
 if { [file exists $::ThemePackageFile] } {
   catch { ::safeSourceStyle $::ThemePackageFile }
 }
+
+# The font for ttkEntry.c widgets cannot be set with ttk::style
+option add *TCombobox*font font_Regular
+option add *TEntry.font font_Regular
+option add *TSpinbox.font font_Regular
+
+# Set the menu options
+# This options are used only when a menu is created. If the theme is changed,
+# it is necessary to restart the program to show the new colors.
+proc configure_menus {} {
+  option add *Menu*TearOff 0
+  if {[llength $::fontOptions(Menu)] == 4} { option add *Menu*Font font_Menu }
+
+  if {$::unixOS} {
+    option add *Menu.background [ttk::style lookup . -background] startupFile
+    option add *Menu.activeBackground [ttk::style lookup . -background active] startupFile
+    option add *Menu.disabledBackground [ttk::style lookup . -background disabled] startupFile
+    option add *Menu.foreground [ttk::style lookup . -foreground] startupFile
+    option add *Menu.selectColor [ttk::style lookup . -foreground] startupFile
+    option add *Menu.activeForeground [ttk::style lookup . -foreground active] startupFile
+    option add *Menu.disabledForeground [ttk::style lookup . -foreground disabled] startupFile
+  }
+
+  foreach col [array names ::menuColor] {
+    option add *Menu.$col $::menuColor($col)
+  }
+}
+
+proc configure_style {} {
+  # Use default font everywhere
+  ttk::style configure . -font font_Regular
+  ttk::style configure Heading -font font_Regular
+
+  # Style definitions
+  ttk::style configure Bold.TCheckbutton -font font_Bold
+  ttk::style configure Small.TCheckbutton -font font_Small
+
+  ttk::style configure Small.TButton -font font_Small
+  ttk::style configure Bold.TButton -font font_Bold
+  ttk::style configure Pad0.Small.TButton -padding 0
+
+  ttk::style configure Small.TRadiobutton -font font_Small
+  ttk::style configure Bold.TRadiobutton -font font_Bold
+  ttk::style configure SmallBold.TRadiobutton -font font_SmallBold
+
+  ttk::style configure pad0.TMenubutton -padding 0 -indicatorwidth 0 -indicatorheight 0  -font font_Small
+
+  ttk::style configure fieldbg.TLabel -background [ttk::style lookup . -fieldbackground "" white]
+
+  ttk::style configure Switch.Toolbutton -padding 0
+
+  # Some themes (e.g. vista and xpnative) use custom field elements and ignore -fieldbackground
+  if {[regexp {(Combobox|Entry|Spinbox)\.(field|background)} [ttk::style element names]]} {
+      ttk::style configure Error.TCombobox -foreground #b80f0a
+      ttk::style configure Error.TEntry -foreground #b80f0a
+      ttk::style configure Error.TSpinbox -foreground #b80f0a
+  } else {
+      ttk::style configure Error.TCombobox -fieldbackground #b80f0a
+      ttk::style configure Error.TEntry -fieldbackground #b80f0a
+      ttk::style configure Error.TSpinbox -fieldbackground #b80f0a
+  }
+
+  calculateGlistRowHeight
+
+  # The ttk::combobox popdown listbox cannot be configured using ttk::style
+  option add *TCombobox*Listbox.background [ttk::style lookup . -fieldbackground "" white] startupFile
+  option add *TCombobox*Listbox.foreground [ttk::style lookup . -foreground] startupFile
+  option add *TCombobox*Listbox.selectBackground [ttk::style lookup . -selectbackground] startupFile
+  option add *TCombobox*Listbox.selectForeground [ttk::style lookup . -selectforeground] startupFile
+
+  # Add the theme's specific options
+  foreach elem [lsearch -all -inline -exact -index 0 $::themeOptions [ttk::style theme use]] {
+    option add [lindex $elem 1] [lindex $elem 2]
+  }
+}
+bind . <<ThemeChanged>> { if {"%W" eq "."} { configure_style } }
+
 catch { ttk::style theme use $::lookTheme }
+configure_menus
 
-#TODO: all the style configurations should be re-applied when the theme is changed
-# Use default font everywhere
-ttk::style configure TLabel -font font_Regular
-ttk::style configure TButton -font font_Regular
-ttk::style configure TRadiobutton -font font_Regular
-ttk::style configure TCheckbutton -font font_Regular
-ttk::style configure TMenubutton -font font_Regular
-ttk::style configure TCombobox -font font_Regular
-ttk::style configure TEntry -font font_Regular
-ttk::style configure TNotebook.Tab -font font_Regular
 
-# Style definitions
-ttk::style configure Bold.TCheckbutton -font font_Bold
-ttk::style configure Small.TCheckbutton -font font_Small
+# Uses the circle and full circle unicode characters to simulate a switch button.
+# Based on a ttk::checkbutton, update -text to reflect its state.
+# Example:
+#     ttk::checkbutton widget_name -style Switch.Toolbutton \
+#         -command "::update_switch_btn widget_name"
+#     ::update_switch_btn widget_name initial_value
+# Return the value of the variable associated with the widget.
+proc ::update_switch_btn {widget {set_value ""}} {
+    set varname [$widget cget -variable]
+    if {$set_value ne ""} {
+        set ::$varname $set_value
+    }
+    if {[$widget instate selected]} {
+        set full_circle [expr $::windowsOS ?"\u2B24":"\u25CF"]
+        $widget configure -text "       $full_circle"
+    } else {
+        $widget configure -text "\u25EF       "
+    }
+    return [set ::$varname]
+}
 
-ttk::style configure Small.TButton -font font_Small
-ttk::style configure Bold.TButton -font font_Bold
-ttk::style configure Pad0.Small.TButton -padding 0
+proc autoscrollText {bars frame widget style} {
+  ttk::frame $frame
+  text $widget -cursor arrow -state disabled -highlightthickness 0 -font font_Regular
+  $widget tag configure header -font font_Bold
+  applyThemeStyle $style $widget
+  autoscrollBars $bars $frame $widget
+}
 
-ttk::style configure Small.TRadiobutton -font font_Small
-ttk::style configure Bold.TRadiobutton -font font_Bold
-ttk::style configure SmallBold.TRadiobutton -font font_SmallBold
+# Create a text widget and apply to it the current ttk style.
+# It also creates a tag "header" in the text widget.
+proc ttk_text {pathName {args ""}} {
+  set style Treeview
+  if {[set idx [lsearch $args "-style"]] >=0} {
+    set style [lindex $args [expr $idx + 1]]
+    set args [lreplace $args $idx [expr $idx + 1]]
+  }
+  set res [text $pathName -cursor arrow -highlightthickness 0 -font font_Regular]
+  if {[llength $args] > 0} {
+    $pathName configure {*}$args
+  }
+  $pathName tag configure header -font font_Bold
+  ::applyThemeStyle $style $pathName
+  return $res
+}
 
-ttk::style configure pad0.TMenubutton -padding 0 -indicatorwidth 0 -indicatorheight 0  -font font_Small
+# Create a canvas and apply to it the current ttk style.
+proc ttk_canvas {pathName args} {
+  set res [canvas $pathName {*}$args]
+  ::applyThemeStyle Treeview $pathName
+  return $res
+}
 
-#TODO: recalculate the value if font_Small is changed
-set ::glistRowHeight [expr { round(1.4 * [font metrics font_Small -linespace]) }]
-ttk::style configure Gamelist.Treeview -rowheight $::glistRowHeight
-
-# font_Regular is the default font for widgets:
-option add *Font font_Regular
-
-# Use font_Menu for menu entries:
-option add *Menu*Font font_Menu
-
-# Use custom menu colors (if they exists)
-foreach col [array names ::menuColor] {
-  option add *Menu.$col $::menuColor($col)
+# Create an item into a widget (i.e. a canvas) and apply to it the current ttk style.
+# TODO: find a better way to do this and re-apply when <<ThemeChanged>>
+proc ttk_create {pathName type x y args} {
+  if {"-fill" ni $args} {
+    lappend args "-fill"
+    lappend args [ttk::style lookup Treeview -foreground "" black]
+  }
+  $pathName create $type $x $y {*}$args
 }
 
 # Apply the theme's background color to a widget
@@ -432,67 +597,41 @@ proc applyThemeColor_background { widget } {
 
 # Apply a ttk style to a tk widget
 proc applyThemeStyle {style widget} {
-  $widget configure -background [ttk::style lookup $style -background "" #d9d9d9]
-  $widget configure -foreground [ttk::style lookup $style -foreground "" black]
-  $widget configure -relief [ttk::style lookup $style -relief "" flat]
-  $widget configure {*}[ttk::style configure $style]
+  set exclude [list "-font"]
+  set options [ttk::style configure .]
+  lappend options {*}[ttk::style configure $style]
+
+  foreach {option value} $options {
+    if {$option in $exclude} { continue }
+    catch { $widget configure $option $value }
+  }
   bind $widget <<ThemeChanged>> "::applyThemeStyle $style $widget"
 }
 
-proc InitImg {} {
-	global scidImgDir boardStyle boardStyles textureSquare
-
-	#Set app icon
-	set scidIconFile [file nativename [file join $scidImgDir "scid.gif"]]
-	if {[file readable $scidIconFile]} {
-		wm iconphoto . -default [image create photo -file "$scidIconFile"]
-	}
-
-	#Load all img/buttons/_filename_.gif
-	set dname [file join $::scidImgDir buttons]
-	foreach {fname} [glob -directory $dname *.gif] {
-		set iname [string range [file tail $fname] 0 end-4]
-		image create photo $iname -file $fname
-	}
-
-	#Load all img/buttons/_filename_.png
-	set dname [file join $::scidImgDir buttons]
-	foreach {fname} [glob -directory $dname *.png] {
-		set iname [string range [file tail $fname] 0 end-4]
-		image create photo $iname -format png -file $fname
-	}
-
-	#Load all img/boards/_filename_.gif
-	set textureSquare {}
-	set dname [file join $::scidImgDir boards]
-	foreach {fname} [glob -directory $dname *.gif] {
-		set iname [string range [file tail $fname] 0 end-4]
-		image create photo $iname -file $fname
-		if {[string range $iname end-1 end] == "-l"} {
-			lappend textureSquare [string range $iname 0 end-2]
-		}
-	}
-	
-	#Search available piece sets
-	set boardStyles {}
-	set dname [file join $::scidImgDir pieces]
-	foreach {piecetype} [glob -directory $dname *] {
-		if {[file isdirectory $piecetype] == 1} {
-			lappend boardStyles [file tail $piecetype]
-		}
-	}
-
-	#Load all img/flags/_filename_.gif
-	set dname [file join $::scidImgDir flags]
-	foreach {fname} [glob -directory $dname *.gif] {
-		set iname [string range [file tail $fname] 0 end-4]
-		image create photo $iname -file $fname
-	}
+image create photo flag_unknown -data {
+      iVBORw0KGgoAAAANSUhEUgAAABgAAAAMCAYAAAB4MH11AAAABmJLR0QA/wD/AP+gvaeTAAAACXBIWXMAAC4jAAAuIw
+      F4pT92AAAAB3RJTUUH4wQHCTMzcDliXAAAABJJREFUOMtjYBgFo2AUjIKBBwAEjAABIobxpQAAAABJRU5ErkJggg==
 }
-if {[catch {InitImg}]} {
-	tk_messageBox -type ok -icon error -title "Scid: Error" \
-		-message "Cannot load images.\n$::errorCode\n\n$::errorInfo"
-	exit
+
+proc getFlagImage { countryID { returnUnknowFlag no } } {
+  set cflag "flag_[string tolower [string range $countryID 0 2]]"
+  # preset unkown flag (empty transparent image 24x12)
+  set country flag_unknown
+  if { $cflag eq [info commands $cflag] } {
+    # flag exists, use it
+    set country $cflag
+  } else {
+    # flag does not exist, try to load it
+    set dname [file join $::scidImgDir flags $cflag.gif]
+    if { [file exists $dname] } {
+      image create photo $cflag -file $dname
+      set country $cflag
+    } elseif { $returnUnknowFlag == "no" } {
+      #no flag is needed, return nothing
+      set country ""
+    }
+  }
+  return $country
 }
 
 # Set numeric format
@@ -518,6 +657,8 @@ utils/string.tcl
 utils/tooltip.tcl
 utils/validate.tcl
 utils/win.tcl
+enginecfg.tcl
+enginecomm.tcl
 misc.tcl
 htext.tcl
 file.tcl
@@ -532,9 +673,11 @@ windows.tcl
 windows/browser.tcl
 windows/gamelist.tcl
 windows/pgn.tcl
+windows/preferences.tcl
 windows/book.tcl
 windows/comment.tcl
 windows/eco.tcl
+windows/engine.tcl
 windows/stats.tcl
 windows/tree.tcl
 windows/crosstab.tcl
@@ -546,7 +689,6 @@ search/board.tcl
 search/header.tcl
 search/material.tcl
 contrib/ezsmtp/ezsmtp.tcl
-tools/email.tcl
 tools/import.tcl
 tools/optable.tcl
 tools/preport.tcl
@@ -554,7 +696,6 @@ tools/pinfo.tcl
 tools/analysis.tcl
 tools/wbdetect.tcl
 tools/graphs.tcl
-tools/tablebase.tcl
 tools/ptracker.tcl
 help/help.tcl
 help/tips.tcl
@@ -564,7 +705,6 @@ menus.tcl
 board.tcl
 move.tcl
 main.tcl
-tools/correspondence.tcl
 tools/uci.tcl
 end.tcl
 tools/tacgame.tcl
