@@ -1,4 +1,3 @@
-
 ###
 ### fics.tcl: part of Scid.
 ### Copyright (C) 2007  Pascal Georges
@@ -6,7 +5,7 @@
 
 namespace eval fics {
   set server "freechess.org"
-  set sockchan 0
+  set sockchan ""
   set seeklist {}
   set observedGame -1
   set playing 0
@@ -16,6 +15,12 @@ namespace eval fics {
   set silence 1
   set sought 0
   set soughtlist {}
+  set games 0
+  set gameSelection 0
+  set gamesList {}
+  set player 0
+  set playerSelection ""
+  set playerList {}
   set width 300
   set height 300
   set off 20
@@ -41,6 +46,17 @@ namespace eval fics {
   set premoveSq1 -1
   set premoveSq2 -1
 
+  set showRatedGames 1
+  set showUnratedGames 1
+  set showStandardGames 1
+  set showBlitzGames 1
+  set showLightningGames 1
+  set showOnlyRegisteredPlayer 0
+  set showOnlyFreePlayer 0
+  set sortGamesColumn 0 ;# sort game number
+  set sortGamesOrder "-increasing" ;# sort order
+  set sortPlayersColumn 4 ;# sort blitz rating
+  set sortPlayersOrder "-decreasing" ;# sort blitz rating
   ################################################################################
   #
   ################################################################################
@@ -235,6 +251,72 @@ namespace eval fics {
       if { [sc_pos side] == "white" } {set side 2 }
       ::gameclock::storeTimeComment $side
   }
+  proc arrangeClocks { } {
+      set w .fics.f.bottom.left
+      pack forget $w.clock1 $w.clock2
+      if { [::board::isFlipped .main.board] } {
+          pack $w.clock1 $w.clock2
+      } else {
+          pack $w.clock2 $w.clock1
+      }
+  }
+  ################################################################################
+  #
+  ################################################################################
+  proc gamespopupmenu {{w} {x} {y} {abs_x} {abs_y} } {
+      lassign [$w identify $x $y] what
+      if {$what == "heading"} { return }
+      set item [.fics.f.top.fgames.glist identify item $x $y]
+      .fics.f.top.fgames.glist selection set $item
+      $w.menu delete 0 end
+      set wplayer [.fics.f.top.fgames.glist set $item 2]
+      set bplayer [.fics.f.top.fgames.glist set $item 4]
+      set game [.fics.f.top.fgames.glist set $item 0]
+      set ::fics::gameSelection $game
+      $w.menu add command -label [tr FICSObserve] -command "if { $::fics::observedGame != -1 } { \
+        ::fics::writechan \"unobserve\" \"echo\"
+        }
+        ::fics::writechan \"observe $game\""
+      $w.menu add separator
+      $w.menu add checkbutton -label [tr FICSRatedGames] -variable ::fics::showRatedGames -command ::fics::updateGames
+      $w.menu add checkbutton -label [tr FICSUnratedGames] -variable ::fics::showUnratedGames -command ::fics::updateGames
+      $w.menu add separator
+      $w.menu add checkbutton -label "Lightning" -variable ::fics::showLightningGames -command ::fics::updateGames
+      $w.menu add checkbutton -label "Blitz" -variable ::fics::showBlitzGames -command ::fics::updateGames
+      $w.menu add checkbutton -label "Standard" -variable ::fics::showStandardGames -command ::fics::updateGames
+      $w.menu add separator
+      $w.menu add command -label "Finger $wplayer" -command "::fics::writechan \"finger $wplayer\""
+      $w.menu add command -label "Finger $bplayer" -command "::fics::writechan \"finger $bplayer\""
+      tk_popup $w.menu $abs_x $abs_y
+  }
+  ################################################################################
+  #
+  ################################################################################
+  proc playerpopupmenu {{w} {x} {y} {abs_x} {abs_y} } {
+      lassign [$w identify $x $y] what
+      if {$what == "heading"} { return }
+      set item [.fics.f.top.fplayer.plist identify item $x $y]
+      .fics.f.top.fplayer.plist selection set $item
+      $w.menu delete 0 end
+      set player [.fics.f.top.fplayer.plist set $item 1]
+      set state [.fics.f.top.fplayer.plist set $item 2]
+      set ::fics::playerSelection $player
+      set matchparameter "$::fics::findopponent(rated) $::fics::findopponent(initTime) \
+         $::fics::findopponent(incTime) $::fics::findopponent(color)"
+      $w.menu add command -label "Finger $player" -command "::fics::writechan \"finger $player\""
+      if { [string first "p" $state] >= 0 } {
+          $w.menu add command -label "[tr FICSObserve] $player" -command "::fics::writechan \"observe $player\""
+      } elseif {  [string first "X" $state] == -1 } {
+          $w.menu add command -label "[tr FICSChallenge] $player" \
+              -command "::fics::writechan \"match $player $matchparameter\""
+      }
+      $w.menu add separator
+      $w.menu add checkbutton -label [tr FICSRegisteredPlayer] -variable ::fics::showOnlyRegisteredPlayer \
+          -command ::fics::updatePlayer
+      $w.menu add checkbutton -label [tr FICSFreePlayer] -variable ::fics::showOnlyFreePlayer \
+          -command ::fics::updatePlayer
+      tk_popup $w.menu $abs_x $abs_y
+  }
   ################################################################################
   #
   ################################################################################
@@ -278,8 +360,12 @@ namespace eval fics {
     ttk::frame $w.f.top.fconsole.f2
 
     ttk::frame $w.f.top.foffers
+    ttk::frame $w.f.top.fgames
+    ttk::frame $w.f.top.fplayer
     $w.f.top add $w.f.top.fconsole -sticky nsew -text [::tr "FICSConsole"]
     $w.f.top add $w.f.top.foffers -sticky nsew -text [::tr "FICSOffers"]
+    $w.f.top add $w.f.top.fgames -sticky nsw -text [::tr "FICSGames"]
+    $w.f.top add $w.f.top.fplayer -sticky nws -text [::tr "TmtSortPlayers"]
 
     grid $w.f.top.fconsole.f1 -sticky news
     grid $w.f.top.fconsole.f2 -sticky news
@@ -292,7 +378,77 @@ namespace eval fics {
 
     ttk::frame $w.f.bottom.left
     ttk::frame $w.f.bottom.right
-    grid $w.f.bottom.left $w.f.bottom.right -sticky news
+    grid $w.f.bottom.left $w.f.bottom.right -sticky news -padx 5
+
+    # games
+    grid rowconfigure $w.f.top.fgames 0 -weight 1
+    grid columnconfigure $w.f.top.fgames 0 -weight 1
+    ttk::treeview $w.f.top.fgames.glist -columns { "Game" "WElo" "White" "BElo" "Black" "Type" "Rated" "Time" } \
+        -show headings -selectmode browse -yscrollcommand "$w.f.top.fgames.ybar set"
+
+    set i 0
+    set wid [font measure font_Regular W]
+    foreach { width name anchor } { 3 Game e 4 GlistWElo e 10 White w 4 GlistBElo e 10 Black w \
+                                        6 FinderSortType w 5 Rated w 5 Time e} {
+        $w.f.top.fgames.glist column $i -width [expr $width * $wid] -anchor $anchor -stretch 1
+        $w.f.top.fgames.glist heading $i -text [tr $name]
+        incr i
+    }
+    set inc "-increasing"
+    set dec "-decreasing"
+    set nosort "nosort"
+    set layout [list $inc $dec $inc $dec $inc $inc $nosort $nosort]
+    bind $w.f.top.fgames.glist <ButtonRelease-1> "::fics::clickGames %W %x %y {$layout}"
+    bind $w.f.top.fgames.glist <KeyPress-Return> {
+        set ::fics::gameSelection [.fics.f.top.fgames.glist set [.fics.f.top.fgames.glist selection] 0]
+        ::fics::writechan "observe $::fics::gameSelection"
+    }
+    bind $w.f.top.fgames.glist <<TreeviewSelect>> {
+        set ::fics::gameSelection [.fics.f.top.fgames.glist set [.fics.f.top.fgames.glist selection] 0]
+    }
+    bind $w.f.top.fgames.glist <Double-ButtonRelease-1> {
+        set ::fics::gameSelection [.fics.f.top.fgames.glist set [.fics.f.top.fgames.glist identify row %x %y] 0]
+        ::fics::writechan "observe $::fics::gameSelection"
+    }
+    menu $w.f.top.fgames.glist.menu -borderwidth 1
+    bind $w.f.top.fgames.glist <ButtonPress-$::MB3> "fics::gamespopupmenu %W %x %y %X %Y"
+
+    ttk::scrollbar $w.f.top.fgames.ybar -command "$w.f.top.fgames.glist yview"
+    grid $w.f.top.fgames.glist -column 0 -row 0 -sticky ns
+    grid $w.f.top.fgames.ybar -column 1 -row 0 -sticky news
+
+    # player
+    grid rowconfigure $w.f.top.fplayer 0 -weight 1
+    grid columnconfigure $w.f.top.fplayer 0 -weight 1
+    ttk::treeview $w.f.top.fplayer.plist -columns { "Typ" "Name" "Status" "Blitz" "Lightning" "Standard" "onfor" "idle" } \
+        -show headings -selectmode browse -yscrollcommand "$w.f.top.fplayer.ybar set"
+    set i 0
+    foreach { width name anchor } { 4 Typ w 10 Name w 3 Status w 4 Blitz e 4 Lightning e 4 Standard e 5 OnFor e 4 Idle e } {
+        $w.f.top.fplayer.plist column $i -width [expr $width * $wid] -anchor $anchor
+        $w.f.top.fplayer.plist heading $i -text [tr $name]
+        incr i
+    }
+    set layout [list $inc $inc $inc $dec $dec $dec $inc $inc]
+    bind $w.f.top.fplayer.plist <ButtonRelease-1> "::fics::clickPlayers %W %x %y {$layout}"
+    $w.f.top.fplayer.plist column 6 -anchor e
+    $w.f.top.fplayer.plist column 7 -anchor e
+    bind $w.f.top.fplayer.plist <KeyPress-Return> {
+        set ::fics::playerSelection [.fics.f.top.fplayer.plist set [.fics.f.top.fplayer.plist selection] 1]
+        ::fics::writechan "finger $::fics::playerSelection"
+    }
+    bind $w.f.top.fplayer.plist <<TreeviewSelect>> {
+        set ::fics::playerSelection [.fics.f.top.fplayer.plist set [.fics.f.top.fplayer.plist selection] 1]
+    }
+    bind $w.f.top.fplayer.plist <Double-ButtonRelease-1> {
+        set ::fics::playerSelection [.fics.f.top.fplayer.plist set [.fics.f.top.fplayer.plist identify row %x %y] 1]
+        ::fics::writechan "finger $::fics::playerSelection"
+    }
+    menu $w.f.top.fplayer.plist.menu -borderwidth 1
+    bind $w.f.top.fplayer.plist <ButtonPress-$::MB3> "fics::playerpopupmenu %W %x %y %X %Y"
+
+    ttk::scrollbar $w.f.top.fplayer.ybar -command "$w.f.top.fplayer.plist yview"
+    grid $w.f.top.fplayer.plist -column 0 -row 0 -sticky ns
+    grid $w.f.top.fplayer.ybar -column 1 -row 0 -sticky nwes
 
     # graph
     canvas $w.f.top.foffers.c -background white -width $width -height $height -relief solid
@@ -318,14 +474,13 @@ namespace eval fics {
     bind $w.f.top.fconsole.f2.cmd <Return> { ::fics::cmd }
     bind $w.f.top.fconsole.f2.cmd <Up> { ::fics::cmdHistory up ; break }
     bind $w.f.top.fconsole.f2.cmd <Down> { ::fics::cmdHistory down ; break }
-    bind $w.f.top.fconsole.f2.cmd <Left> " [bind TEntry <Left>] ; break "
-    bind $w.f.top.fconsole.f2.cmd <Right> " [bind TEntry <Right>] ; break "
     grid $w.f.top.fconsole.f2.cmd $w.f.top.fconsole.f2.send -sticky news
     grid columnconfigure $w.f.top.fconsole.f2 0 -weight 1
 
     # clock 1 is white
     ::gameclock::new $w.f.bottom.left 1 100 0
     ::gameclock::new $w.f.bottom.left 2 100 0
+    arrangeClocks
 
     set row 0
     ttk::checkbutton $w.f.bottom.right.silence -image FICSsilence -variable ::fics::silence -onvalue 0 -offvalue 1 -command {
@@ -391,7 +546,6 @@ namespace eval fics {
     bind $w.f.top.fconsole.f1.console <ButtonPress-1> { ::fics::consoleClick %x %y %W }
     ::createToplevelFinalize $w
 
-
     # all widgets must be visible
     update
     set x [winfo reqwidth $w]
@@ -423,7 +577,7 @@ namespace eval fics {
     updateConsole "Socket opening"
 
     if { [catch { set sockchan [socket $server $port] } ] } {
-      tk_messageBox -title "Error" -icon error -type ok -message "Network error\nCan't connect to $server $port" -parent .fics
+      tk_messageBox -title "FICS" -icon error -type ok -message "[tr FICSNetError] $server $port" -parent .fics
       return
     }
 
@@ -481,9 +635,9 @@ namespace eval fics {
     ttk::frame $w.f
     pack $w.f -side top -anchor w -fill x
     ttk::label $w.f.linit -text [::tr "FICSInitialTime"]
-    ttk::spinbox $w.f.sbTime1 -background white -width 3 -textvariable ::fics::findopponent(initTime) -from 0 -to 120 -increment 1 -validate all -validatecommand { regexp {^[0-9]+$} %P }
+    ttk::spinbox $w.f.sbTime1 -width 3 -textvariable ::fics::findopponent(initTime) -from 0 -to 120 -increment 1 -validate all -validatecommand { regexp {^[0-9]+$} %P }
     ttk::label $w.f.linc -text [::tr "FICSIncrement"]
-    ttk::spinbox $w.f.sbTime2 -background white -width 3 -textvariable ::fics::findopponent(incTime) -from 0 -to 120 -increment 1 -validate all -validatecommand { regexp {^[0-9]+$} %P }
+    ttk::spinbox $w.f.sbTime2 -width 3 -textvariable ::fics::findopponent(incTime) -from 0 -to 120 -increment 1 -validate all -validatecommand { regexp {^[0-9]+$} %P }
     grid $w.f.linit -column 0 -row 0 -sticky w
     grid $w.f.sbTime1 -column 1 -row 0 -sticky w -pady "0 2"
     grid $w.f.linc -column 0 -row 1 -sticky w
@@ -500,8 +654,8 @@ namespace eval fics {
     pack $w.f.rb1 $w.f.rb2 $w.f.rb3 -side top -anchor w -in $w.f.color
 
     ttk::checkbutton $w.f.cblimitrating -text [::tr "RatingRange"] -variable ::fics::findopponent(limitrating)
-    ttk::spinbox $w.f.sbrating1 -background white -width 4 -textvariable ::fics::findopponent(rating1) -from 1000 -to 3000 -increment 50 -validate all -validatecommand { regexp {^[0-9]+$} %P }
-    ttk::spinbox $w.f.sbrating2 -background white -width 4 -textvariable ::fics::findopponent(rating2) -from 1000 -to 3000 -increment 50 -validate all -validatecommand { regexp {^[0-9]+$} %P }
+    ttk::spinbox $w.f.sbrating1 -width 4 -textvariable ::fics::findopponent(rating1) -from 1000 -to 3000 -increment 50 -validate all -validatecommand { regexp {^[0-9]+$} %P }
+    ttk::spinbox $w.f.sbrating2 -width 4 -textvariable ::fics::findopponent(rating2) -from 1000 -to 3000 -increment 50 -validate all -validatecommand { regexp {^[0-9]+$} %P }
     grid $w.f.cblimitrating -column 0 -row 5 -columnspan 2 -sticky ew
     grid $w.f.sbrating1 -column 0 -row 6 -sticky w
     grid $w.f.sbrating2 -column 1 -row 6 -sticky w
@@ -605,6 +759,69 @@ namespace eval fics {
     return 1
   }
   ################################################################################
+  # Appends an array to gamesList if the parameter is correct
+  # returns 0 if the line is not parsed and so it is still pending for use
+  ################################################################################
+  proc parseGamesLine { l } {
+    # it seems that the first offer starts with a prompt
+    set ret 0
+    if {[string match "fics% *" $l]} {
+      set l [string range $l 6 end]
+    }
+    set anz [scan $l "%d %s %s %s %s \[%s %d %d" nr welo p1 belo p2 type t1 t2]
+    if { $anz == 8 } {
+        if { [string length $type] < 3 } {
+            set type " $type"
+        }
+        lappend ::fics::gamesList [list $nr $welo $p1 $belo $p2 $type "$t1 $t2"]
+        set ret 1
+    }
+    return $ret
+  }
+  ################################################################################
+  # Appends an array to playerList if the parameter is correct
+  # returns 0 if the line is not parsed and so it is still pending for use
+  ################################################################################
+  proc parseWhoLine { l } {
+    # it seems that the first offer starts with a prompt
+    if {[string match "fics% *" $l]} {
+      set l [string range $l 6 end]
+    }
+    if { [string index $l 1] == "+"} {
+        # ignore frame around list
+        return 1
+    }
+    if { [string index $l 1] != "|"} {
+        return 0
+    }
+    #Status: X=not open for playing p=playing U=unregistered o=observing a game
+    set state [string range $l 5 8]
+    set game [string range $l 2 4]
+    set l [string range $l 9 end]
+    if { [scan $l "%s %s %s %s %s %s" name standard blitz lightning onfor idle] != 6} {
+        return 1
+    }
+    if { $name == "User" } {
+        return 1
+    }
+    set typ ""
+    set typ_found [string first "(" $name ]
+    if { $typ_found != -1 } {
+        set typ [string range $name $typ_found end]
+        incr typ_found -1
+        set name [string range $name 0 $typ_found]
+    }
+    if { [string is digit [string index $game 2]] } {
+        #set status player is playing
+        append state "p"
+    }
+    if { [string index $idle 0] == "|" } {
+        set idle ""
+    }
+    lappend ::fics::playerList [list $typ $name $state $standard $blitz $lightning $onfor $idle]
+    return 1
+  }
+  ################################################################################
   #
   ################################################################################
   proc readparse {line} {
@@ -624,6 +841,32 @@ namespace eval fics {
         return
       }
     }
+    if { $::fics::games } {
+      if {[string match "* ga* displayed." $line]} {
+        set ::fics::games 0
+        catch {
+            sortGames $::fics::sortGamesColumn $::fics::sortGamesOrder
+            displayGames
+        }
+        return
+      }
+      if { [ parseGamesLine $line ] } {
+        return
+      }
+    }
+    if { $::fics::player } {
+      if {[string first "Players Displayed" $line] > 0 } {
+        set ::fics::player 0
+        catch {
+            sortPlayers $::fics::sortPlayersColumn $::fics::sortPlayersOrder
+            displayPlayers
+        }
+        return
+      }
+      if { [ parseWhoLine $line ] } {
+        return
+      }
+    }
 
     if {[string match "login: " $line]} {
       writechan $::fics::reallogin
@@ -696,6 +939,7 @@ namespace eval fics {
       } else {
         if { [ string match -nocase $black $::fics::reallogin ] } { ::board::flip .main.board }
       }
+      arrangeClocks
       ::notify::GameChanged
       set ::fics::rated [string equal [lindex $line 5] "rated"]
       # display the win / draw / loss score
@@ -713,9 +957,9 @@ namespace eval fics {
       set res [lindex $line end]
       set comment [lrange [lindex $line 0] 2 end]
       set n [string first {)} $comment]
-	if {$n > -1} {
-	  set comment [string range $comment $n+2 end]
-	}
+      if {$n > -1} {
+          set comment [string range $comment $n+2 end]
+      }
       sc_pos setComment "[sc_pos getComment]$comment"
       if {$num == $::fics::observedGame} {
         if {[string match "1/2*" $res]} {
@@ -792,13 +1036,13 @@ namespace eval fics {
       }
       catch { sc_move addSan $m1 }
       if {$t2 != ""} {
-	  storeEmtComment 0 $t2 $t3
+          storeEmtComment 0 $t2 $t3
       }
       if {$m2 != ""} {
         catch { sc_move addSan $m2 }
       }
       if {$t4 != ""} {
-	  storeEmtComment 0 $t4 $t5
+          storeEmtComment 0 $t4 $t5
       }
 
       if {[sc_pos fen] == $::fics::waitForMoves } {
@@ -807,11 +1051,10 @@ namespace eval fics {
     }
 
     if {[string match "Challenge:*" $line]} {
-      set ans [tk_dialog .challenge [::tr "FICSChallenge"] $line "" 0 [::tr "FICSAccept"] [::tr "FICSDecline"]]
-      if {$ans == 0} {
-        writechan "accept"
-      } else {
-        writechan "decline"
+      set ans [tk_messageBox -title [::tr "FICSChallenge"] -icon question -type yesno -message "$line\n\n[tr FICSAccept]" ]
+      switch -- $ans {
+        yes {writechan "accept"}
+        no  {writechan "decline"}
       }
     }
 
@@ -821,7 +1064,7 @@ namespace eval fics {
     # to avoid "denial of play" attack by the opponent constantly issuing such a request
     # (because  tk_messageBox  "waits for the user to select one of the buttons")
     if {[string match "* would like to abort the game;*" $line] && $::fics::showabortreq} {
-      set ans [tk_messageBox -title [::tr "Abort"] -icon question -type yesnocancel -message "$line\nDo you accept ?" ]
+      set ans [tk_messageBox -title [::tr Abort] -icon question -type yesnocancel -message "$line\n\n[tr FICSAccept]" ]
       switch -- $ans {
         yes {writechan "accept"}
         no  {writechan "decline"}
@@ -831,7 +1074,7 @@ namespace eval fics {
 
     # takeback
     if {[string match "* would like to take back *" $line] && $::fics::showtakebackreq} {
-      set ans [tk_messageBox -title "Abort" -icon question -type yesnocancel -message "$line\nDo you accept ?" ]
+      set ans [tk_messageBox -title [tr FICSTakeback] -icon question -type yesnocancel -message "$line\n\n[tr FICSAccept]" ]
       switch -- $ans {
         yes {writechan "accept"}
         no  {writechan "decline"}
@@ -841,7 +1084,7 @@ namespace eval fics {
 
     # draw
     if {[string match "*offers you a draw*" $line] && $::fics::showdrawreq} {
-      set ans [tk_messageBox -title "Abort" -icon question -type yesnocancel -message "$line\nDo you accept ?" ]
+      set ans [tk_messageBox -title [tr Draw] -icon question -type yesnocancel -message "$line\n\n[tr FICSAccept]" ]
       switch -- $ans {
         yes {writechan "accept"}
         no  {writechan "decline"}
@@ -851,7 +1094,7 @@ namespace eval fics {
 
     # adjourn
     if {[string match "*would like to adjourn the game*" $line] && $::fics::showadjournreq} {
-      set ans [tk_messageBox -title "Abort" -icon question -type yesnocancel -message "$line\nDo you accept ?" ]
+      set ans [tk_messageBox -title "Abort" -icon question -type yesnocancel -message "$line\n[tr FICSAccept]" ]
       switch -- $ans {
         yes {writechan "accept"}
         no  {writechan "decline"}
@@ -888,8 +1131,12 @@ namespace eval fics {
 
     if {$state == "normal" } {
       $w.f.top add $w.f.top.foffers
+      $w.f.top add $w.f.top.fgames
+      $w.f.top add $w.f.top.fplayer
     } else  {
       $w.f.top hide $w.f.top.foffers
+      $w.f.top hide $w.f.top.fgames
+      $w.f.top hide $w.f.top.fplayer
     }
   }
   ################################################################################
@@ -1045,14 +1292,14 @@ namespace eval fics {
         if { [catch { sc_move addSan $moveSan } err ] } {
           puts "error $err"
         } else {
-	    if {  $::fics::playing == 1 } {
-		::fics::storeTime
-	    } else {
-		set t1 ""; set t2 ""
-		if { [scan $moveTime "(%d:%d)" t1 t2] == 2} {
-		    storeEmtComment 0 $t1 $t2
-		}
-	    }
+          if {  $::fics::playing == 1 } {
+              ::fics::storeTime
+          } else {
+              set t1 ""; set t2 ""
+              if { [scan $moveTime "(%d:%d)" t1 t2] == 2} {
+                  storeEmtComment 0 $t1 $t2
+              }
+          }
           if { $::novag::connected } {
             set m $verbose_move
             if { [string index $m 1] == "/" } { set m [string range $m 2 end] }
@@ -1139,6 +1386,35 @@ namespace eval fics {
   ################################################################################
   #
   ################################################################################
+  proc updateGames { } {
+    if { ![winfo exists .fics] ||
+         [ .fics.f.top select ] != ".fics.f.top.fgames" } { return }
+    set ::fics::games 1
+    set ::fics::gamesList {}
+    ::fics::writechan "games"
+    vwaitTimed ::fics::games 5000 "nowarn"
+    after 20000 ::fics::updateGames
+  }
+  ################################################################################
+  #
+  ################################################################################
+  proc updatePlayer { } {
+    if { ![winfo exists .fics] ||
+         [ .fics.f.top select ] != ".fics.f.top.fplayer" } { return }
+    set ::fics::player 1
+    set ::fics::playerList {}
+    if { $::fics::showOnlyRegisteredPlayer } {
+        set command "who Rv"
+    } else {
+        set command "who v"
+    }
+    writechan $command
+    vwaitTimed ::fics::player 5000 "nowarn"
+    after 40000 ::fics::updatePlayer
+  }
+  ################################################################################
+  #
+  ################################################################################
   proc configureCanvas {} {
     set w .fics.f.top.foffers
     set ::fics::height [winfo height $w]
@@ -1223,6 +1499,104 @@ namespace eval fics {
 
   }
   ################################################################################
+  #
+  ################################################################################
+  proc clickGames {{w} {x} {y} {layout}} {
+      lassign [$w identify $x $y] what
+      if {$what == "heading"} {
+          set col [string index [$w identify column $x $y] 1]
+          incr col -1
+          set sort [lindex $layout $col]
+          if { $sort ne "nosort" } {
+              sortGames $col $sort
+              displayGames
+          }
+      }
+  }
+
+  proc sortGames { column sort } {
+      set ::fics::sortGamesColumn $column
+      set ::fics::sortGamesOrder $sort
+      set ::fics::gamesList [lsort -dictionary $::fics::sortGamesOrder -index $::fics::sortGamesColumn $::fics::gamesList]
+  }
+
+  proc displayGames { } {
+      set w .fics.f.top.fgames
+      set i 1
+      $w.glist delete [$w.glist children {}]
+      foreach game $::fics::gamesList {
+          set nr [lindex $game 0]
+          set type [lindex $game 5]
+          set show_ru 0
+          set ru [string index $type 2]
+          if { ( $::fics::showRatedGames && $ru == "r") ||
+               ( $::fics::showUnratedGames && $ru == "u" ) } {
+              set show_ru 1
+          }
+          set show_sbl 0
+          set sbl [string index $type 1]
+          if { ( $::fics::showStandardGames && $sbl == "s" ) ||
+               ( $::fics::showBlitzGames && $sbl == "b" ) ||
+               ( $::fics::showLightningGames && $sbl == "l" ) } {
+              set show_sbl 1
+          }
+          if { $show_ru && $show_sbl } {
+              if { $ru == "r" } {
+                  set rated [tr FICSRated]
+              } else {
+                  set rated [tr FICSUnrated]
+              }
+              switch -- $sbl {
+                  s { set type "Standard"}
+                  b { set type "Blitz"}
+                  l { set type "Lightning"}
+              }
+              lset game 5 $type
+              set game [linsert $game 6 $rated]
+              $w.glist insert {} end -id $i -values $game
+              if { $nr == $::fics::gameSelection } { $w.glist selection set $i }
+              incr i
+          }
+      }
+  }
+  ################################################################################
+  #
+  ################################################################################
+  proc clickPlayers {{w} {x} {y} {layout}} {
+      lassign [$w identify $x $y] what
+      if {$what == "heading"} {
+          set col [string index [$w identify column $x $y] 1]
+          incr col -1
+          set sort [lindex $layout $col]
+          sortPlayers $col $sort
+          displayPlayers
+      }
+  }
+
+  proc sortPlayers { column sort } {
+      set ::fics::sortPlayersColumn $column
+      set ::fics::sortPlayersOrder $sort
+      set ::fics::playerList [lsort -dictionary $::fics::sortPlayersOrder -index $::fics::sortPlayersColumn $::fics::playerList]
+  }
+
+  proc displayPlayers { } {
+      set w .fics.f.top.fplayer
+      set i 1
+      $w.plist delete [$w.plist children {}]
+      foreach player $::fics::playerList {
+          set state [lindex $player 2]
+          if { ! $::fics::showOnlyFreePlayer || ! ([string first "X" $state] >= 0 || [string first "p" $state] >= 0 ) } {
+              set typ [lindex $player 0]
+              set name [lindex $player 1]
+              #remove braces around a typ e.g. (C) -> C
+              lset player 0 [string map { ")(" " " "(" "" ")" " "} $typ]
+              $w.plist insert {} end -id $i -values $player
+              if { $name == $::fics::playerSelection } { $w.plist selection set $i }
+              incr i
+          }
+      }
+  }
+  ################################################################################
   # Play the selected game
   ################################################################################
   proc getOffersGame { idx } {
@@ -1272,6 +1646,7 @@ namespace eval fics {
   #
   ################################################################################
   proc writechan {line {echo "noecho"}} {
+    if { $::fics::sockchan == "" } { return }
     after cancel ::fics::stayConnected
     if {[eof $::fics::sockchan]} {
       tk_messageBox -title "FICS" -icon error -type ok -message "Network error writing channel"
@@ -1328,10 +1703,10 @@ namespace eval fics {
 
     if { $::fics::playing == 1 } { return 1 }
 
-    if { $::fics::premoveEnabled && $::fics::playing == -1 } { 
+    if { $::fics::premoveEnabled && $::fics::playing == -1 } {
         .main.board.bd delete mark
         set ::fics::premoveSq1 -1
-        return 1 
+        return 1
     }
     return 0
   }
@@ -1347,12 +1722,12 @@ namespace eval fics {
     }
     set elt [$win get $l.0 $l.end]
 
-    if { $elt ==  "Click or type \[next\] to see next page." } {
+    if { $elt == "Click or type \[next\] to see next page." } {
       writechan "next"
       return
     }
 
-    regsub -all {\s+} $elt " " elt
+    regsub -all {\s+} [string trim $elt] " " elt
     set elt [split $elt " "]
     set found 0
 
@@ -1402,15 +1777,24 @@ namespace eval fics {
   # updates the offers view if it is visible
   ################################################################################
   proc tabchanged {} {
-    set nb .fics.f.top
-    set w .fics.f.top.foffers
-
-    if { [ $nb select ] == $w } {
-      updateOffers
-      set ::fics::graphon 1
-    } else  {
-      after cancel ::fics::updateOffers
-      set ::fics::graphon 0
+    after cancel ::fics::updateGames
+    after cancel ::fics::updateOffers
+    after cancel ::fics::updatePlayer
+    set ::fics::graphon 0
+    set ::fics::sought 0
+    set ::fics::games 0
+    set ::fics::player 0
+    switch [ .fics.f.top select ] {
+      .fics.f.top.fgames {
+          updateGames
+      }
+      .fics.f.top.fplayer {
+          updatePlayer
+      }
+      .fics.f.top.foffers {
+          updateOffers
+          set ::fics::graphon 1
+      }
     }
   }
   ################################################################################
@@ -1420,9 +1804,13 @@ namespace eval fics {
     variable logged
     # stop recursive call
     bind .fics <Destroy> {}
+    # avoid error on closing via x-Button
+    .fics.f.top.fconsole.f1.console configure -yscrollcommand ""
 
     set ::fics::sought 0
     after cancel ::fics::updateOffers
+    after cancel ::fics::updateGames
+    after cancel ::fics::updatePlayer
     after cancel ::fics::stayConnected
     set logged 0
 
@@ -1431,8 +1819,13 @@ namespace eval fics {
     }
 
     set ::fics::playing 0
+    set ::fics::games 0
+    set ::fics::player 0
     set ::fics::observedGame -1
-    ::close $::fics::sockchan
+    if { $::fics::sockchan ne "" } {
+        ::close $::fics::sockchan
+        set ::fics::sockchan ""
+    }
     if { ! $::windowsOS } { catch { exec -- kill -s INT [ $::fics::timeseal_pid ] }  }
     ::win::closeWindow .fics
   }
