@@ -1,5 +1,64 @@
 ### graph.tcl: part of Scid.
 
+# TODO: find a better position in this file for this function  
+# search for valid score in comment. Cut to maxY. if no score is found returns an empty string 
+proc getScorefromComment { comment maxY } {
+    set maxY [expr $maxY - 0.01 ]
+    set minY [expr 0.0 - $maxY]
+	set evalExp {.*?\[%eval\s*(.*?)\s*\].*}
+	set eval ""
+	set score ""
+	regexp $evalExp $comment -> eval
+    if { $eval != "" } { # check for [%eval 1.23]
+        if { [scan $eval "%f" score ] == 1 } {
+            if { $score > $maxY } { set score $maxY }
+            if { $score < $minY } { set score $minY }
+            return $score
+        }
+
+        # Mate found in %eval #N oder #-N
+        if { [string first "#" $eval] != -1 } {
+            set score $maxY
+            if { [string first "-" $eval] > 0 } { set score $minY }
+            return $score
+        }
+    }
+
+	set foundIndex [string first ":M" $comment]
+	# check for Mate :M5 or :M-3
+	if { $foundIndex >= 0 } {
+	    if { [scan [string range $comment [expr $foundIndex+2] end] "%f" score] == 1 } {
+            # change Mate in x to +/$minY
+            if { $score >= 1 } { set score $maxY }
+            if { $score <= -1 } { set score $minY }
+	    }
+	} else {
+	    set f 1
+	    set foundIndex [string first "+M" $comment]
+	    if { $foundIndex < 0 } { set foundIndex [string first "-M" $comment]; set f -1 }
+	    # check for Mate +M5 or -M3 (Annotation from Arena GUI)
+	    if { $foundIndex >= 0 } {
+            if { [scan [string range $comment [expr $foundIndex+2] end] "%f" score] == 1 } {
+                # change Mate in x to +/- maxY
+                set score [expr $f * $score]
+                if { $score >= 1 } { set score $maxY }
+                if { $score <= -1 } { set score $minY }
+            }
+	    } else {
+            # check for scores +1.23 or -1.23, find the first apperance in the comment
+            set foundIndex [string first "+" $comment]
+            if { $foundIndex < 0 } { set foundIndex [string first "-" $comment] }
+            if { $foundIndex >= 0 } {
+                if { [scan [string range $comment $foundIndex end] "%f" score] == 1 } {
+                    if { $score > $maxY } { set score $maxY }
+                    if { $score < $minY } { set score $minY }
+                }
+            }
+	    }
+	}
+    return $score
+}
+
 # ::tools::graphs::Save
 #
 #   Saves a graph (e.g. tree graph, filter graph, rating graph) to a
@@ -90,23 +149,27 @@ proc configureFilterGraph {} {
   if { [winfo exists .statsWin]} {
       ttk::labelframe $w.filterold -text "Config StatYear StatElo OldYear OldElo"
       foreach { i h v s } { Elo OprepStatBoth r* "+" Year OprepStatSince y* ".01.01" } {
-	  ttk::frame $w.filterold.old$i
-	  ttk::label $w.filterold.old$i.label -textvariable ::tr($h) -font font_Bold
-	  ttk::scrollbar $w.filterold.old$i.ybar -command "$w.filterold.old$i.list yview"
-	  listbox $w.filterold.old$i.list -yscrollcommand "$w.filterold.old$i.ybar set" \
-	      -height 7 -width 10 -selectmode multiple -exportselection 0
-	  pack $w.filterold.old$i.label -side top -anchor w
-	  pack $w.filterold.old$i.ybar -side right -fill y
-	  pack $w.filterold.old$i.list -side left -fill both -expand 1
-	  set j 0
-	  foreach y [lsort -decreasing [array names ::windows::stats::display $v]] {
-	      set value [string range $y 1 end]
-	      $w.filterold.old$i.list insert end "$value$s"
-	      if { $::windows::stats::display($y) } {
-	      $w.filterold.old$i.list selection set $j
-	      }
-	      incr j
-	  }
+         ttk::frame $w.filterold.old$i
+         ttk::label $w.filterold.old$i.label -textvariable ::tr($h) -font font_Bold
+         ttk::treeview $w.filterold.old$i.list -columns {0} -show {} -selectmode extended \
+             -yscrollcommand "$w.filterold.old$i.ybar set"
+         $w.filterold.old$i.list column 0 -width 100
+         $w.filterold.old$i.list configure -height 7
+         ttk::scrollbar $w.filterold.old$i.ybar -command "$w.filterold.old$i.list yview"
+         pack $w.filterold.old$i.label -side top -anchor w
+         pack $w.filterold.old$i.ybar -side right -fill y
+         pack $w.filterold.old$i.list -side left -fill both -expand 1
+         set j 0
+         set il {}
+         foreach y [lsort -decreasing [array names ::windows::stats::display $v]] {
+             set value [string range $y 1 end]
+             $w.filterold.old$i.list insert {} end -id $j -values "$value$s"
+             if { $::windows::stats::display($y) } {
+                 lappend il $j
+             }
+             incr j
+         }
+         $w.filterold.old$i.list selection set $il
       }
       pack $w.filterold.oldElo -side left -expand 1 -in $w.filterold -fill both -padx "0 10"
       pack $w.filterold.oldYear -side left -expand 1 -fill both -in $w.filterold
@@ -130,24 +193,32 @@ proc configureFilterGraph {} {
   }
   if { [winfo exists .statsWin]} {
      ttk::button $w.buttons.update -textvar ::tr(Update) -command { checkConfigFilterGraph
-	  set j 0
-	  foreach i [lsort -decreasing [array names ::windows::stats::display y*]] {
-	      set ::windows::stats::display($i) [.configFilterGraph.filterold.oldYear.list selection includes $j]
-	      incr j
-	  }
-	  set j 0
-	  foreach i [lsort -decreasing [array names ::windows::stats::display r*]] {
-	      set ::windows::stats::display($i) [.configFilterGraph.filterold.oldElo.list selection includes $j]
-	      incr j
-	  }
-	 ::tools::graphs::absfilter::Refresh;
-	 ::tools::graphs::filter::Refresh
-	 ::windows::stats::refresh_wnd
+       set j 0
+       set sel [.configFilterGraph.filterold.oldYear.list selection]
+       foreach i [lsort -decreasing [array names ::windows::stats::display y*]] {
+           set ::windows::stats::display($i) 0
+           incr j
+       }
+       foreach i $sel {
+           set ::windows::stats::display(y[string range [.configFilterGraph.filterold.oldYear.list set $i 0] 0 3]) 1
+       }
+       set j 0
+       set sel [.configFilterGraph.filterold.oldElo.list selection]
+       foreach i [lsort -decreasing [array names ::windows::stats::display r*]] {
+           set ::windows::stats::display($i) 0
+           incr j
+       }
+       foreach i $sel {
+           set ::windows::stats::display(r[string range [.configFilterGraph.filterold.oldElo.list set $i 0] 0 3]) 1
+       }
+       ::tools::graphs::absfilter::Refresh;
+       ::tools::graphs::filter::Refresh
+       ::windows::stats::refresh_wnd
      }
   } else {
      ttk::button $w.buttons.update -textvar ::tr(Update) -command { checkConfigFilterGraph
-	 ::tools::graphs::absfilter::Refresh;
-	 ::tools::graphs::filter::Refresh
+        ::tools::graphs::absfilter::Refresh;
+        ::tools::graphs::filter::Refresh
      }
   }
   
@@ -199,7 +270,7 @@ proc tools::graphs::filter::Open {} {
   pack $w.b -side top -fill x
   ttk::label $w.b.status -width 1 -font font_Small -anchor w
   
-  canvas $w.c -width 600 -height 400 -selectforeground [ttk::style lookup . -foreground] -background [ttk::style lookup . -background]
+  canvas $w.c -width 600 -height 400
   $w.c create text 25 5 -tag title -justify center -width 1 \
       -font font_Small -anchor n
   $w.c create text 250 295 -tag type -justify center -width 1 \
@@ -402,9 +473,10 @@ proc ::tools::graphs::filter::Refresh {} {
 #Invert white/black Score in Score graph, switches for display move time and adding time
 set ::tools::graphs::score::White 0
 set ::tools::graphs::score::Black 0
-set ::tools::graphs::score::ThinkTime 0
-set ::tools::graphs::score::Both 1
-set ::tools::graphs::score::TimeSum 1
+set ::tools::graphs::score::Scores 1
+set ::tools::graphs::score::Times 1
+set ::tools::graphs::score::TimeSum 0
+set ::tools::graphs::score::MaxY 6
 
 ###########################
 # Game score and time graph
@@ -478,7 +550,7 @@ proc MoveTimeList {color add} {
 		    }
 		    if { $ok == 1 } {
 			set f [expr { $ho*3600.0 + $mi*60 + $sec}]
-			if { $add == 1 } {
+			if { $add } {
 			    # add move times and scale to minutes
 			    set f [expr { $f/60.0 + $sum }]
 			    set sum $f
@@ -493,7 +565,7 @@ proc MoveTimeList {color add} {
     return $movetimes
 }
 
-# MoveScoreList
+# ::tools::graphs::MoveScoreList
 #    Returns a Tcl list of the numeric move scores, as found
 #    in the commment for each move.
 #    A score is a number with the format
@@ -504,7 +576,7 @@ proc MoveTimeList {color add} {
 #    The list returned should be read in pairs of values: the first is the
 #    move (0.0 = start, 0.5 after White's first move, 1.0 after Black's
 #    first move, etc) and the second is the value found.
-proc MoveScoreList { invw invb } {
+proc ::tools::graphs::MoveScoreList { invw invb } {
     set moveScores { }
     set mainline { }
     set base [sc_base current]
@@ -513,75 +585,27 @@ proc MoveScoreList { invw invb } {
     set n [llength $game]
     set movenr 0
     for {set i 0} { $i < $n} { incr i } {
-	set RAVd [lindex [lindex $game $i] 0]
-	set RAVn [lindex [lindex $game $i] 1]
-	# only search in the mainline
-	if { $RAVd == 0 && $RAVn == 0} {
-	    lappend mainline [lindex [lindex $game $i] 4]
-	}
+        set RAVd [lindex [lindex $game $i] 0]
+        set RAVn [lindex [lindex $game $i] 1]
+        # only search in the mainline
+        if { $RAVd == 0 && $RAVn == 0} {
+            lappend mainline [lindex [lindex $game $i] 4]
+        }
     }
     set movenr 0.0
     set side 0
     for {set i 1} { $i < $n} { incr i } {
-	set comment [lindex $mainline $i]
-	set evalExp {.*?\[%eval\s*(.*?)\s*\].*}
-	set eval ""
-	#little trick to check for valid score
-	set score -20.0
-	regexp $evalExp $comment -> eval
-	if { $eval != "" } { # check for [%eval 1.23]
-	    scan $eval "%f" score
-	    if { [scan $eval "%f" score ] == 1 } {
-		if { $score > 10 } { set score 9.9 }
-		if { $score < -10 } { set score -9.9 }
-	    } else {
-		# Mate found in %eval #N oder #-N
-		if { [string first "#" $eval] != -1 } {
-		    set score 9.9
-		    if { [string first "-" $eval] > 0 } { set score -9.9 }
-		}
-	    }
-	}
-	set foundIndex [string first ":M" $comment]
-	# check for Mate :M5 or :M-3
-	if { $foundIndex >= 0 } {
-	    if { [scan [string range $comment [expr $foundIndex+2] end] "%f" score] == 1 } {
-		# change Mate in x to +/-9.9
-		if { $score >= 1 } { set score 9.9 }
-		if { $score <= -1 } { set score -9.9 }
-	    }
-	} else {
-	    set f 1
-	    set foundIndex [string first "+M" $comment]
-	    if { $foundIndex < 0 } { set foundIndex [string first "-M" $comment]; set f -1 }
-	    # check for Mate +M5 or -M3 (Annotation from Arena GUI)
-	    if { $foundIndex >= 0 } {
-		if { [scan [string range $comment [expr $foundIndex+2] end] "%f" score] == 1 } {
-		    # change Mate in x to +/-9.9
-		    set score [expr $f * $score]
-		    if { $score >= 1 } { set score 9.9 }
-		    if { $score <= -1 } { set score -9.9 }
-		}
-	    } else {
-		# check for scores +1.23 or -1.23, find the first apperance in the comment
-		set foundIndex [string first "+" $comment]
-		if { $foundIndex < 0 } { set foundIndex [string first "-" $comment] }
-		if { $foundIndex >= 0 } {
-		    if { [scan [string range $comment $foundIndex end] "%f" score] == 1 } {
-			if { $score > 10 } { set score 9.9 }
-			if { $score < -10 } { set score -9.9 }
-		    }
-		}
-	    }
-	}
-	if { $score != -20.0 } {
-	    # we have found something valid, check if the score should be inverted
-	    if { $invw == 1 &&  $side == 1 } { set score [expr 0.0 - $score] }
-	    if { $invb == 1 &&  $side == 0 } { set score [expr 0.0 - $score] }
-	    lappend moveScores $movenr $score
-	}
-	set movenr [expr $movenr + 0.5]
-	if { $side == 0 } { set side 1 } else { set side 0 }
+        set comment [lindex $mainline $i]
+        set score [getScorefromComment $comment $::tools::graphs::score::MaxY]
+
+        if { $score ne "" } {
+            # we have found something valid, check if the score should be inverted
+            if { $invw == 1 &&  $side == 1 } { set score [expr 0.0 - $score] }
+            if { $invb == 1 &&  $side == 0 } { set score [expr 0.0 - $score] }
+            lappend moveScores $movenr $score
+        }
+        set movenr [expr $movenr + 0.5]
+        if { $side == 0 } { set side 1 } else { set side 0 }
     }
     return $moveScores
 }
@@ -613,7 +637,7 @@ proc ::tools::graphs::score::Refresh { {docreate 1 }} {
     $w.menu add command -label Help -accelerator F1 -command {helpWindow Graphs Score}
     #Checkbuttons for Invert white/black Score in Score graph
     menu $w.menu.options
-    foreach i {White Black Both ThinkTime TimeSum } {
+    foreach i {White Black} {
       $w.menu.options add checkbutton -label GraphOptions$i \
           -variable ::tools::graphs::score::$i -offvalue "0" -onvalue "1" \
           -command "::tools::graphs::score::Refresh"
@@ -622,6 +646,19 @@ proc ::tools::graphs::score::Refresh { {docreate 1 }} {
 
     $w.c create text 25 5 -tag text -justify center -width 1 \
         -font font_Regular -anchor n
+    ttk::frame $w.fbuttons
+    ttk::checkbutton $w.fbuttons.score -text [tr ToolsScore] -variable ::tools::graphs::score::Scores \
+        -command "::tools::graphs::score::Refresh"
+    ttk::checkbutton $w.fbuttons.time -text [tr Time] -variable ::tools::graphs::score::Times \
+        -command "::tools::graphs::score::Refresh"
+    ttk::checkbutton $w.fbuttons.timesum -text $::tr(AnnotateTime) -variable ::tools::graphs::score::TimeSum \
+        -command "::tools::graphs::score::Refresh" -offvalue "1" -onvalue "0"
+    # TODO translate
+    ttk::label $w.fbuttons.labelm -text "Max Score:"
+    ttk::spinbox $w.fbuttons.maxy -textvariable ::tools::graphs::score::MaxY -justify right -from 1 -to 12 -width 2 -command ::tools::graphs::score::Refresh
+    pack $w.fbuttons.timesum $w.fbuttons.time $w.fbuttons.score -side right -padx 6 -pady 0
+    pack $w.fbuttons.maxy $w.fbuttons.labelm -side right
+    pack $w.fbuttons -side bottom -fill both
     pack $w.c -side top -expand yes -fill both
     bind $w <F1> {helpWindow Graphs Score}
     bind $w <Configure> {
@@ -643,8 +680,7 @@ proc ::tools::graphs::score::Refresh { {docreate 1 }} {
   set height [expr {[winfo height $w.c] - 50} ]
   set width [expr {[winfo width $w.c] - 40} ]
   set yticks 1
-  if { $::tools::graphs::score::Both == 1 || $::tools::graphs::score::ThinkTime == 1} {
-      ::setTitle $w "Scid: [tr ToolsScore] & [tr Time]"
+  if { $::tools::graphs::score::Times } {
       set max 0
       # Find max Value of time, then set the tick value vor horizontal lines
       foreach j { "w" "b"} {
@@ -660,8 +696,6 @@ proc ::tools::graphs::score::Refresh { {docreate 1 }} {
       if {$max > 50} { set yticks 10 }
       if {$max > 100} { set yticks 20 }
   }
-  if { $::tools::graphs::score::ThinkTime == 1 &&  $::tools::graphs::score::Both == 0 } {
-      ::setTitle $w "Scid: [tr Time]" }
 
   ::utils::graph::create score -width $width -height $height -xtop 25 -ytop 25 \
       -ytick $yticks -xtick 5 -font font_Small -canvas $w.c -textcolor black \
@@ -680,18 +714,18 @@ proc ::tools::graphs::score::Refresh { {docreate 1 }} {
   busyCursor $w
   update
 
-  if { $::tools::graphs::score::Both || $::tools::graphs::score::ThinkTime } {
+  if { $::tools::graphs::score::Times } {
       # draw move time
       catch {::utils::graph::data score data1 -color $firstColor -points 0 -lines 1\
 		  -key [sc_game info white] -linewidth $linewidth -radius $psize -outline $firstColor -coords $coordsw }
       catch {::utils::graph::data score data2 -color $secondColor -points 0 -lines 1 \
 		 -linewidth $linewidth -radius $psize -outline $secondColor -coords $coordsb}
   }
-  if { $::tools::graphs::score::Both || $::tools::graphs::score::ThinkTime == 0 } {
+  if { $::tools::graphs::score::Scores } {
       # draw score bars
       catch {::utils::graph::data score data -color $linecolor -points 0 -lines 0 -bars 2 \
 		 -linewidth $linewidth -radius $psize -outline $linecolor \
-		 -coords [MoveScoreList $::tools::graphs::score::White $::tools::graphs::score::Black]}
+		 -coords [::tools::graphs::MoveScoreList $::tools::graphs::score::White $::tools::graphs::score::Black]}
   }
 
   ::utils::graph::redraw score
@@ -709,14 +743,10 @@ proc ::tools::graphs::score::ConfigMenus {{lang ""}} {
   foreach idx {0 1 3} tag {Color Grey Close} {
     configMenuText $m.file $idx GraphFile$tag $lang
   }
-  foreach idx {0 1 2} tag {White Black Both} {
-    configMenuText $m.options $idx GraphOptions$tag $lang
+  foreach idx {0 1} tag {GraphOptionsWhite GraphOptionsBlack} {
+    configMenuText $m.options $idx $tag $lang
   }
-  #add option to show used Time and toggle between "Sum of time" (in min) and "Time per move" (in sec)
   $m entryconfig 2 -label $::tr(Help)
-  $m.options entryconfig 3 -label $::tr(Time)
-  $m.options entryconfig 4 -label $::tr(Total)
-
 }
 
 proc ::tools::graphs::score::Move {xc} {
@@ -912,7 +942,7 @@ proc tools::graphs::absfilter::Open {} {
   pack $w.b -side top -fill x
   ttk::label $w.b.status -width 1 -font font_Small -anchor w
   
-  canvas $w.c -width 600 -height 400 -selectforeground [ttk::style lookup . -foreground] -background [ttk::style lookup . -background]
+  canvas $w.c -width 600 -height 400
   $w.c create text 25 5 -tag title -justify center -width 1 \
       -font font_Small -anchor n
   $w.c create text 250 295 -tag type -justify center -width 1 \
