@@ -57,26 +57,30 @@ namespace eval sergame {
     
     # builds the list of UCI engines
     ttk::frame $w.fengines.fEnginesList
-    listbox $w.fengines.fEnginesList.lbEngines -yscrollcommand "$w.fengines.fEnginesList.ybar set" \
-        -height 5 -width 20 -exportselection 0
+    ttk::treeview $w.fengines.fEnginesList.lbEngines -columns {0} -show {} -selectmode browse \
+        -yscrollcommand "$w.fengines.fEnginesList.ybar set"
+    $w.fengines.fEnginesList.lbEngines column 0 -width 100
+    $w.fengines.fEnginesList.lbEngines configure -height 5
     ttk::scrollbar $w.fengines.fEnginesList.ybar -command "$w.fengines.fEnginesList.lbEngines yview"
     pack $w.fengines.fEnginesList.ybar -side right -fill y
     pack $w.fengines.fEnginesList.lbEngines -side left -fill x -expand 1
     pack $w.fengines.fEnginesList -expand yes -fill x -side top
+
+
     set i 0
     set idx 0
     foreach e $::engines(list) {
       if { [lindex $e 7] != 1} { incr idx ; continue }
       set ::sergame::engineListBox($i) $idx
       set name [lindex $e 0]
-      $w.fengines.fEnginesList.lbEngines insert end $name
+      $w.fengines.fEnginesList.lbEngines insert {} end -id $idx -values [list $name]
       incr i
       incr idx
     }
     
     # Engine configuration (limit strength for example)
     ttk::button $w.fengines.bEngineConfig -text $::tr(ConfigureUCIengine) -command {
-      set sel [.configSerGameWin.fengines.fEnginesList.lbEngines curselection]
+      set sel [.configSerGameWin.fengines.fEnginesList.lbEngines selection]
       set index $::sergame::engineListBox($sel)
       set engineData [lindex $::engines(list) $index]
       set name [lindex $engineData 0]
@@ -84,8 +88,6 @@ namespace eval sergame {
       set args [lindex $engineData 2]
       set dir [ toAbsPath [lindex $engineData 3] ]
       set options [lindex $engineData 8]
-      set ::uci::autoSaveOptionsIndex $index
-      set ::uci::autoSaveOptions 1
       ::uci::uciConfig 3 [ toAbsPath $cmd ] $args [ toAbsPath $dir ] $options
     }
     pack $w.fengines.bEngineConfig -side top -pady 5 -anchor e -padx 4
@@ -208,8 +210,16 @@ namespace eval sergame {
     # choose a specific opening
     ttk::checkbutton $w.fopening.cbOpening -text $::tr(SpecificOpening) -variable ::sergame::isOpening
     ttk::frame $w.fopening.fOpeningList
-    listbox $w.fopening.fOpeningList.lbOpening -yscrollcommand "$w.fopening.fOpeningList.ybar set" \
-        -height 5 -width 36 -list ::tacgame::openingList -exportselection 0
+    ttk::treeview $w.fopening.fOpeningList.lbOpening -columns {0} -show {} -selectmode browse \
+        -yscrollcommand "$w.fopening.fOpeningList.ybar set"
+    $w.fopening.fOpeningList.lbOpening column 0 -width 250
+    $w.fopening.fOpeningList.lbOpening configure -height 5
+    set idx 0
+    foreach o $::tacgame::openingList {
+        $w.fopening.fOpeningList.lbOpening insert {} end -id $idx -values [list $o]
+        incr idx
+    }
+
     $w.fopening.fOpeningList.lbOpening selection set $::sergame::chosenOpening
     $w.fopening.fOpeningList.lbOpening see $::sergame::chosenOpening
     
@@ -221,9 +231,9 @@ namespace eval sergame {
     
     ttk::button $w.fbuttons.close -text $::tr(Play) -command {
       focus .
-      set ::sergame::chosenEngine [.configSerGameWin.fengines.fEnginesList.lbEngines curselection]
-      set ::sergame::engineName [.configSerGameWin.fengines.fEnginesList.lbEngines get $::sergame::chosenEngine]
-      set ::sergame::chosenOpening [.configSerGameWin.fopening.fOpeningList.lbOpening curselection]
+      set ::sergame::chosenEngine [.configSerGameWin.fengines.fEnginesList.lbEngines selection]
+      set ::sergame::engineName [.configSerGameWin.fengines.fEnginesList.lbEngines set $::sergame::chosenEngine 0]
+      set ::sergame::chosenOpening [.configSerGameWin.fopening.fOpeningList.lbOpening selection]
       if {$::sergame::useBook} {
         set ::sergame::bookToUse [.configSerGameWin.fconfig.combo get]
         if {$::sergame::bookToUse == "" } {
@@ -237,7 +247,7 @@ namespace eval sergame {
       set ::uci::uciInfo(fixeddepth3) [.configSerGameWin.ftime.depth.value get]
       set ::uci::uciInfo(fixednodes3) [expr [.configSerGameWin.ftime.nodes.value get]*1000]
       set ::uci::uciInfo(movetime3) [expr [.configSerGameWin.ftime.movetime.value get]*1000]
-      
+
       destroy .configSerGameWin
       ::sergame::play $::sergame::chosenEngine
     }
@@ -267,7 +277,10 @@ namespace eval sergame {
     
     ::uci::startEngine $::sergame::engineListBox($engine) $n
     set engineData [lindex $::engines(list) $::sergame::engineListBox($engine)]
-    ::uci::sendUCIoptions $n [ lindex $engineData 8 ]
+    foreach {option} [lindex $engineData 8] {
+      array set ::uciOptions$n $option
+    }
+    ::uci::sendUCIoptions $n
     
     set ::uci::uciInfo(prevscore$n) 0.0
     set ::uci::uciInfo(score$n) 0.0
@@ -537,9 +550,9 @@ namespace eval sergame {
       ::sergame::sendToEngine $n "isready"
       vwait ::analysis(waitForReadyOk$n)
       ::sergame::sendToEngine $n "position fen [sc_pos fen]"
-      set wtime [expr [::gameclock::getSec 1] * 1000 ]
-      set btime [expr [::gameclock::getSec 2] * 1000 ]
       if {$timeMode == "timebonus"} {
+        set wtime [expr [::gameclock::getSec 1] * 1000 ]
+        set btime [expr [::gameclock::getSec 2] * 1000 ]
         ::sergame::sendToEngine $n "go wtime $wtime btime $btime winc $::uci::uciInfo(winc$n) binc $::uci::uciInfo(binc$n)"
       } elseif {$timeMode == "depth"} {
         ::sergame::sendToEngine $n "go depth $::uci::uciInfo(fixeddepth$n)"
