@@ -12,6 +12,7 @@ set crosstab(ages) "+ages"
 set crosstab(colors) "+colors"
 set crosstab(ratings) "+ratings"
 set crosstab(countries) "+countries"
+set crosstab(flags) "-flags"
 set crosstab(titles) "+titles"
 set crosstab(groups) "-groups"
 set crosstab(breaks) "-breaks"
@@ -19,34 +20,6 @@ set crosstab(deleted) "-deleted"
 set crosstab(cnumbers) "-numcolumns"
 set crosstab(text) hypertext
 
-proc ::crosstab::ConfigMenus {{lang ""}} {
-  set m $::crosstab::win.menu
-  if {! [winfo exists $m] } { return }
-
-  if {$lang == ""} { set lang $::language }
-  foreach idx {0 1 2 3 4 5} tag {File Edit Opt Sort Color Help} {
-    configMenuText $m $idx Crosstab$tag $lang
-  }
-  foreach idx {0 1 2 4} tag {Text Html LaTeX Close} {
-    configMenuText $m.file $idx CrosstabFile$tag $lang
-  }
-  foreach idx {0 1 2} tag {Event Site Date} {
-    configMenuText $m.edit $idx CrosstabEdit$tag $lang
-  }
-  foreach idx {0 1 2 3 5 6 7 8 9 10 12 13 15} tag {All Swiss Knockout Auto Ages Nats Ratings Titles Breaks Deleted Colors ColumnNumbers Group} {
-    configMenuText $m.opt $idx CrosstabOpt$tag $lang
-  }
-  foreach idx {0 1 2} tag {Name Rating Score} {
-    configMenuText $m.sort $idx CrosstabSort$tag $lang
-  }
-  foreach idx {0 1} tag {Plain Hyper} {
-    configMenuText $m.color $idx CrosstabColor$tag $lang
-  }
-  foreach idx {0 1} tag {Cross Index} {
-    configMenuText $m.helpmenu $idx CrosstabHelp$tag $lang
-  }
-}
-
 proc ::crosstab::OpenClose {} {
   if {[winfo exists $::crosstab::win]} {
     ::win::closeWindow $::crosstab::win
@@ -75,7 +48,7 @@ proc ::crosstab::Open {} {
   foreach i {file edit opt sort color helpmenu} {
     menu $w.menu.$i -tearoff 0
   }
-  
+
   $w.menu.file add command -label CrosstabFileText -command {
     set ftype {
       { "Text files" {".txt"} }
@@ -105,7 +78,7 @@ proc ::crosstab::Open {} {
         tk_messageBox -title "Scid: Error saving file" -type ok -icon warning -message "Unable to save the file: $fname\n\n"
       } else {
         catch {sc_game crosstable html $crosstab(sort) $crosstab(type) \
-              $crosstab(ratings) $crosstab(countries) $crosstab(titles) \
+              $crosstab(ratings) $crosstab(countries) $crosstab(flags) $crosstab(titles) \
               $crosstab(colors) $crosstab(groups) $crosstab(ages) \
               $crosstab(breaks) $crosstab(cnumbers) $crosstab(deleted)} \
             result
@@ -130,7 +103,7 @@ proc ::crosstab::Open {} {
             -message "Unable to save the file: $fname\n\n"
       } else {
         catch {sc_game crosstable latex $crosstab(sort) $crosstab(type) \
-              $crosstab(ratings) $crosstab(countries) $crosstab(titles) \
+              $crosstab(ratings) $crosstab(countries) $crosstab(flags) $crosstab(titles) \
               $crosstab(colors) $crosstab(groups) $crosstab(ages) \
               $crosstab(breaks) $crosstab(cnumbers) $crosstab(deleted)} \
             result
@@ -142,7 +115,7 @@ proc ::crosstab::Open {} {
   $w.menu.file add separator
   $w.menu.file add command -label CrosstabFileClose \
       -command "::win::closeWindow $w"
-  
+
   $w.menu.edit add command -label CrosstabEditEvent -command {
     makeNameEditor
     setNameEditorType event
@@ -165,7 +138,7 @@ proc ::crosstab::Open {} {
     set editDateNew [sc_game info date]
     set editNameSelect crosstable
   }
-  
+
   $w.menu.opt add radiobutton -label CrosstabOptAll \
       -variable crosstab(type) -value allplay -command crosstab::Refresh
   $w.menu.opt add radiobutton -label CrosstabOptSwiss \
@@ -181,6 +154,9 @@ proc ::crosstab::Open {} {
   $w.menu.opt add checkbutton -label CrosstabOptNats \
       -variable crosstab(countries) -onvalue "+countries" \
       -offvalue "-countries" -command crosstab::Refresh
+  $w.menu.opt add checkbutton -label "Flag" \
+      -variable crosstab(flags) -onvalue "+flags" \
+      -offvalue "-flags" -command crosstab::Refresh
   $w.menu.opt add checkbutton -label CrosstabOptRatings \
       -variable crosstab(ratings) -onvalue "+ratings" -offvalue "-ratings" \
       -command crosstab::Refresh
@@ -204,34 +180,30 @@ proc ::crosstab::Open {} {
   $w.menu.opt add checkbutton -label CrosstabOptGroup \
       -underline 0 -variable crosstab(groups) \
       -onvalue "+groups" -offvalue "-groups" -command crosstab::Refresh
-  
+
   $w.menu.sort add radiobutton -label CrosstabSortName \
       -variable crosstab(sort) -value name -command crosstab::Refresh
   $w.menu.sort add radiobutton -label CrosstabSortRating \
       -variable crosstab(sort) -value rating -command crosstab::Refresh
   $w.menu.sort add radiobutton -label CrosstabSortScore \
       -variable crosstab(sort) -value score -command crosstab::Refresh
-  
+
   $w.menu.color add radiobutton -label CrosstabColorPlain \
       -variable crosstab(text) -value plain -command crosstab::Refresh
   $w.menu.color add radiobutton -label CrosstabColorHyper \
       -variable crosstab(text) -value hypertext -command crosstab::Refresh
-  
+
   $w.menu.helpmenu add command -label CrosstabHelpCross \
       -command {helpWindow Crosstable}
   $w.menu.helpmenu add command -label CrosstabHelpIndex \
       -command {helpWindow Index}
-  
-  ::crosstab::ConfigMenus
-  
+
+  translateMenuLabels $w.menu
+
   ttk::frame $w.b
-  ttk::frame $w.f
-  text $w.f.text \
-      -wrap none -font font_Fixed \
-      -background white -cursor top_left_arrow
+  autoscrollText both $w.f $w.f.text Treeview
+  $w.f.text configure -wrap none -font font_Fixed -state normal
   ::htext::init $w.f.text
-  $w.f.text tag configure bgGray -background gray95
-  autoscrollframe $w.f "" $w.f.text
   ttk::button $w.b.stop -textvar ::tr(Stop) -state disabled \
       -command { set ::htext::interrupt 1 }
   ttk::menubutton $w.b.type -text "" -menu $w.b.type.menu
@@ -258,7 +230,7 @@ proc ::crosstab::Open {} {
   pack $w.b.setfilter $w.b.addfilter -side left -pady 3 -padx 5
   pack $w.b -side bottom -fill x
   pack $w.f -side top -fill both -expand true
-  
+
   # Take input focus even if -state is disabled
   bind $w.f.text <ButtonPress-1> "focus %W"
 
@@ -277,7 +249,7 @@ proc ::crosstab::Refresh {} {
   global crosstab
   set w $::crosstab::win
   if {! [winfo exists $w]} { return }
-  
+
   switch $crosstab(type) {
     allplay  { $w.b.type configure -text [tr CrosstabOptAll] }
     swiss    { $w.b.type configure -text [tr CrosstabOptSwiss] }
@@ -298,7 +270,7 @@ proc ::crosstab::Refresh {} {
   update
   set ::crosstab::dbase_ [sc_base current]
   catch {sc_game crosstable $crosstab(text) $crosstab(sort) $crosstab(type) \
-        $crosstab(ratings) $crosstab(countries) $crosstab(titles) \
+        $crosstab(ratings) $crosstab(countries) $crosstab(flags) $crosstab(titles) \
         $crosstab(colors) $crosstab(groups) $crosstab(ages) \
         $crosstab(breaks) $crosstab(cnumbers) $crosstab(deleted)} result
   $w.f.text configure -state normal
@@ -307,11 +279,6 @@ proc ::crosstab::Refresh {} {
   } else {
     ::htext::display $w.f.text $result
   }
-  # Shade every second line to help readability:
-  set lastLineNum [expr {int([$w.f.text index end])}]
-  for {set i 2} {$i <= $lastLineNum} {incr i 2} {
-    $w.f.text tag add bgGray $i.0 "$i.0 lineend +1c"
-  }
   unbusyCursor .
   catch {grab release $w.b.stop}
   $w.b.stop configure -state disabled
